(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    418361,      12730]*)
(*NotebookOutlinePosition[    431097,      13095]*)
(*  CellTagsIndexPosition[    430739,      13078]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Controlling a Distillation Column\[LongDash]A Case Study of an \
Industrial Application\
\>", "Section",
  CellTags->{"2.0", "c:1"}],

Cell[TextData[{
  StyleBox["Polynomial Control Systems",
    FontSlant->"Italic"],
  " implements a variety of new and topical model representations, analysis \
tools, and design and synthesis methods for linear control systems described \
by polynomial matrix equations or matrices with rational polynomial elements. \
For multivariable systems, these polynomial-based algorithms often provide \
the designer with more informative and meaningful answers than the \
established state-space based methods. This example gives a quick reference \
to some new facilities illustrated in a case study of the control of a \
distillation column. "
}], "Text",
  CellTags->"2.0"],

Cell[CellGroupData[{

Cell["The Transfer-Function Model", "Subsection",
  CellTags->{"2.1", "c:2"}],

Cell[TextData[{
  "The modeling, analysis, and design of a control system for a distillation \
column illustrates the practical application of the tools implemented in",
  StyleBox[" Polynomial Control Systems",
    FontSlant->"Italic"],
  ". The case study starts with examining the stability of the open-loop \
system and its time-domain behavior. Then, some of the new analysis tools are \
demonstrated using the transformation of the original transfer-function \
matrix to the corresponding left and right matrix-fraction forms and the \
polynomial system matrix model. Next, as an example of controller synthesis, \
a new full-rank state-feedback pole assignment algorithm is applied to a \
state-space model of the system to speed up the slower open-loop system \
modes. Finally, after determining the relative gain array to ensure that the \
best individual inputs are being used to control the system outputs, the use \
of the Nyquist array as a design tool is demonstrated, and one of the new \
frequency-domain compensator design methods is applied to determine a simple \
controller that significantly reduces the interaction present in the system. \
"
}], "Text",
  CellTags->"2.1"],

Cell["Make sure the application is loaded.", "MathCaption",
  CellTags->"2.1"],

Cell[BoxData[
    \(<< PolynomialControlSystems`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->"2.1"],

Cell["\<\
This is a transfer-function matrix representation of a distillation \
column, where output 1 is the change in the top temperature of the column in \
degrees C and output 2 is the change in the bottom temperature in degrees C. \
Input 1 is the change in reflux flow in kg/hr at the top of the column and \
input 2 is the change in steam flow into the reboiler in kg/hr at the bottom \
of the column.\
\>", "MathCaption",
  CellTags->"2.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(tf = 
      TransferFunction[
        s, {{\(-\(0.252\/\(\((1 + 3.3\ s)\)\^3\ \((1 + 1800\ s)\)\)\)\), 
            0.43\/\(\((1 + 12\ s)\)\ \((1 + 1800\ s)\)\)}, \
{\(-\(0.0435\/\(\((1 + 25.3\ s)\)\^3\ \((1 + 360\ s)\)\)\)\), 
            0.097\/\(\((1 + 12\ s)\)\ \((1 + 360\ s)\)\)}}]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->"2.1"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-\(0.252`\/\(\((3.3`\ \[ScriptS] + 1)\)\^3\ \((1800\ \
\[ScriptS] + 1)\)\)\)\), \(0.43`\/\(\((12\ \[ScriptS] + 
                                1)\)\ \((1800\ \[ScriptS] + 1)\)\)\)},
                    {\(-\(0.0435`\/\(\((25.3`\ \[ScriptS] + 1)\)\^3\ \((360\ \
\[ScriptS] + 1)\)\)\)\), \(0.097`\/\(\((12\ \[ScriptS] + 
                                1)\)\ \((360\ \[ScriptS] + 1)\)\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"2.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 System Poles, Stability, and Responses", "Subsection",
  CellTags->{"2.2", "c:3"}],

Cell[TextData[{
  "Here is a quick look at the system properties using the tools provided in \
",
  StyleBox["Control System Professional",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"2.2"],

Cell["\<\
Among the transfer-function matrix elements, there are a total of \
12 stable poles with a very wide spread of time constants.\
\>", "MathCaption",\

  CellTags->"2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(poles\  = \ Sort[Flatten[Poles[tf]]]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"2.2"],

Cell[BoxData[
    \({\(-0.30303030303030304`\), \(-0.30303030303030304`\), \
\(-0.30303030303030304`\), \(-0.08333333333333333`\), \(-0.08333333333333333`\
\), \(-0.039525691699604744`\), \(-0.039525691699604744`\), \
\(-0.039525691699604744`\), \(-0.002777777777777778`\), \
\(-0.002777777777777778`\), \(-0.0005555555555555556`\), \
\(-0.0005555555555555556`\)}\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->"2.2"]
}, Open  ]],

Cell["\<\
This is the ratio of the largest time-constant to the smallest \
time-constant in the system.\
\>", "MathCaption",
  CellTags->"2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(First[poles]/Last[poles]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->"2.2"],

Cell[BoxData[
    \(545.4545454545455`\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->"2.2"]
}, Open  ]],

Cell["\<\
These are the variations in the top temperature (solid line) and \
the bottom temperature (dashed line) for separate unit-step changes applied \
to each input.\
\>", "MathCaption",
  CellTags->"2.2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[tf, 
        UnitStep[1], {t, 
          10000}, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[ .001], 
            Dashing[{0.015}]}];\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"2.2"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-05 0.603319 2.34484 [
[.21429 .59082 -9.6 -7.2 ]
[.21429 .59082 9.6 0 ]
[.40476 .59082 -9.6 -7.2 ]
[.40476 .59082 9.6 0 ]
[.59524 .59082 -9.6 -7.2 ]
[.59524 .59082 9.6 0 ]
[.78571 .59082 -9.6 -7.2 ]
[.78571 .59082 9.6 0 ]
[.97619 .59082 -12 -7.2 ]
[.97619 .59082 12 0 ]
[.01131 .01711 -24 -3.6 ]
[.01131 .01711 0 3.6 ]
[.01131 .13435 -19.2 -3.6 ]
[.01131 .13435 0 3.6 ]
[.01131 .25159 -24 -3.6 ]
[.01131 .25159 0 3.6 ]
[.01131 .36883 -19.2 -3.6 ]
[.01131 .36883 0 3.6 ]
[.01131 .48608 -24 -3.6 ]
[.01131 .48608 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(2000)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(4000)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(6000)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(8000)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(10000)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .01711 m
.03006 .01711 L
s
[(-0.25)] .01131 .01711 1 0 Mshowa
.02381 .13435 m
.03006 .13435 L
s
[(-0.2)] .01131 .13435 1 0 Mshowa
.02381 .25159 m
.03006 .25159 L
s
[(-0.15)] .01131 .25159 1 0 Mshowa
.02381 .36883 m
.03006 .36883 L
s
[(-0.1)] .01131 .36883 1 0 Mshowa
.02381 .48608 m
.03006 .48608 L
s
[(-0.05)] .01131 .48608 1 0 Mshowa
.125 Mabswid
.02381 .04056 m
.02756 .04056 L
s
.02381 .064 m
.02756 .064 L
s
.02381 .08745 m
.02756 .08745 L
s
.02381 .1109 m
.02756 .1109 L
s
.02381 .1578 m
.02756 .1578 L
s
.02381 .18125 m
.02756 .18125 L
s
.02381 .2047 m
.02756 .2047 L
s
.02381 .22814 m
.02756 .22814 L
s
.02381 .27504 m
.02756 .27504 L
s
.02381 .29849 m
.02756 .29849 L
s
.02381 .32194 m
.02756 .32194 L
s
.02381 .34539 m
.02756 .34539 L
s
.02381 .39228 m
.02756 .39228 L
s
.02381 .41573 m
.02756 .41573 L
s
.02381 .43918 m
.02756 .43918 L
s
.02381 .46263 m
.02756 .46263 L
s
.02381 .50953 m
.02756 .50953 L
s
.02381 .53297 m
.02756 .53297 L
s
.02381 .55642 m
.02756 .55642 L
s
.02381 .57987 m
.02756 .57987 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .60332 m
.06244 .48669 L
.10458 .38334 L
.14415 .30688 L
.18221 .24826 L
.22272 .19863 L
.26171 .16074 L
.30316 .12889 L
.34309 .10469 L
.3815 .08616 L
.42237 .07052 L
.46172 .0586 L
.49955 .04946 L
.53984 .0417 L
.57861 .03577 L
.61984 .03078 L
.65954 .02698 L
.69774 .02408 L
.73838 .02161 L
.77751 .01974 L
.81909 .01816 L
.85916 .01696 L
.89771 .01605 L
.93871 .01528 L
.97619 .01472 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .60332 m
.04262 .5745 L
.0522 .55677 L
.06244 .54245 L
.07286 .53168 L
.08255 .5242 L
.09409 .51766 L
.10458 .51335 L
.11454 .51032 L
.12373 .5082 L
.13381 .50645 L
.14451 .50507 L
.15392 .50417 L
.16404 .50344 L
.1736 .50293 L
.18234 .50256 L
.19219 .50225 L
.20133 .50203 L
.21136 .50185 L
.22205 .50171 L
.23234 .50161 L
.24346 .50153 L
.25397 .50147 L
.26364 .50143 L
.27337 .50141 L
.28246 .50139 L
.29243 .50137 L
.30312 .50135 L
.3133 .50135 L
.32436 .50134 L
.33481 .50133 L
.34448 .50133 L
.35411 .50133 L
.36315 .50132 L
.37306 .50132 L
.38375 .50132 L
.39332 .50132 L
.40379 .50132 L
.41472 .50132 L
.42489 .50132 L
.43541 .50132 L
.44535 .50132 L
.45427 .50132 L
.46394 .50132 L
.4734 .50132 L
.48381 .50132 L
.49468 .50132 L
.50485 .50132 L
.51526 .50132 L
.52514 .50132 L
Mistroke
.53401 .50132 L
.54368 .50132 L
.55402 .50132 L
.56339 .50132 L
.5742 .50132 L
.58438 .50132 L
.59417 .50132 L
.60449 .50132 L
.61331 .50132 L
.62298 .50132 L
.63321 .50132 L
.64253 .50132 L
.65328 .50132 L
.66346 .50132 L
.67313 .50132 L
.6834 .50132 L
.69217 .50132 L
.70184 .50132 L
.71196 .50132 L
.72122 .50132 L
.7314 .50132 L
.74209 .50132 L
.75166 .50132 L
.76187 .50132 L
.77151 .50132 L
.78025 .50132 L
.79026 .50132 L
.79948 .50132 L
.80959 .50132 L
.82029 .50132 L
.82975 .50132 L
.8399 .50132 L
.84948 .50132 L
.85823 .50132 L
.86812 .50132 L
.87729 .50132 L
.88735 .50132 L
.89804 .50132 L
.90739 .50132 L
.91749 .50132 L
.92701 .50132 L
.93576 .50132 L
.94555 .50132 L
.95466 .50132 L
.96466 .50132 L
.97535 .50132 L
.97619 .50132 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo000Kooooo`03o`000?oooooooooo0?oo
oooo0oooool001_ooooo00?o0000ooooooooool0ooooool3ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool3o`0000Cooooo00?o0000ooooooooool0
ooooool3ooooo`001?l000001?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool2o`000=;ooooo9Ol0000<ooooo`001Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00?o00001?ooool00ol0003oooooooooo`2loooooaGo0000<Ooo
ool000Gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooooooo0:Oooooo5Ol00016ooooo`001_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool3
o`0000Cooooo00?o0000ooooooooool0WOooool:o`0005_ooooo000Kooooo`03o`000?oooooooooo
09?ooooo2_l0001Uooooo`006oooool00ol0003oooooooooo`2;ooooo`So0000Koooool001_ooooo
00?o0000ooooooooool0Q_ooool5o`0007Oooooo000Kooooo`;o0000P_ooool5o`0007cooooo000K
ooooo`03o`000?oooooooooo07cooooo1Ol00021ooooo`006oooool00ol0003oooooooooo`1goooo
o`Go0000Q_ooool001_ooooo00?o0000ooooooooool0L_ooool5o`0008_ooooo000Kooooo`03o`00
0?oooooooooo06gooooo1Ol0002@ooooo`006oooool00ol0003oooooooooo`1Yooooo`Co0000UOoo
ool001_ooooo0_l0001Wooooo`?o0000VOooool001_ooooo00?o0000ooooooooool0Hoooool3o`00
09cooooo000Kooooo`03o`000?oooooooooo063ooooo0ol0002Oooooo`006oooool00ol0003ooooo
ooooo`1Nooooo`;o0000X_ooool001_ooooo00?o0000ooooooooool0Foooool3o`000:Cooooo000K
ooooo`03o`000?oooooooooo05Wooooo0_l0002Wooooo`006oooool2o`0005Sooooo0_l0002Yoooo
o`006oooool00ol0003oooooooooo`1Eooooo`;o0000Zoooool001_ooooo00?o0000ooooooooool0
Doooool2o`000:gooooo000Kooooo`03o`000?oooooooooo057ooooo0_l0002_ooooo`006oooool0
0ol0003oooooooooo`1?ooooo`;o0000/Oooool001_ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`2aooooo`006oooool2o`0004gooooo0_l0002dooooo`006oooool00ol0003ooooo
ooooo`1:ooooo`;o0000]_ooool001_ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`2fooooo`006oooool00ol0003oooooooooo`17ooooo`;o0000^Oooool001_ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`2iooooo`002oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`14ooooo`;o0000_?ooool000Go
oooo1?l000001?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00?ooooo0_l00014oooo
o`03o`000?oooooooooo0;cooooo000:ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0;gooooo000:ooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo0;kooooo000;ooooo`03o`000?oooooooooo00Kooooo0ol00004ooooo`03o`000?oo
oooooooo03oooooo0_l00031ooooo`006oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo0<7ooooo000Kooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0`_ooool001_o
oooo0_l0000mooooo`03o`000?oooooooooo0<?ooooo000Kooooo`03o`000?oooooooooo03[ooooo
0_l00036ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0<Kooooo000K
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0aoooool001_ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`38ooooo`006oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo0<Wooooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`3:ooooo`006ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<_ooooo000Kooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0c?ooool001_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`3=ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0<ko
oooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0coooool001_ooooo0_l0
000aooooo`03o`000?oooooooooo0<oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0d?ooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3Aoooo
o`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0=;ooooo000Kooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0d_ooool001_ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`3Cooooo`006oooool2o`0002cooooo00?o0000ooooooooool0e?ooool0
01_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3Eooooo`006oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo0=Kooooo000Kooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0e_ooool001_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`3Gooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_oo
ool3o`0000Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3Hooooo`001?l00000
1?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool2o`0002Oooooo00?o0000ooooooooool0fOooool000Gooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooooooool3o`0000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`3Iooooo`001Oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0=[ooooo0006ooooo`03o`000?oooooo
oooo00Kooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo0=_ooooo000Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0foooool001_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3Looooo`006oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo0=gooooo000Kooooo`;o00008oooool00ol0003ooooooooo
o`3Mooooo`006oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0=kooooo000Koooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0goooool001_ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`3Oooooo`006oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo0>3ooooo000Kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0hOoo
ool001_ooooo0_l0000Oooooo`03o`000?oooooooooo0>7ooooo000Kooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0h_ooool001_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3Sooooo`006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0>?ooooo
000Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0i?ooool001_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`3Tooooo`006oooool2o`0001_ooooo00?o0000oooo
ooooool0iOooool001_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Uooooo`00
6oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0>Kooooo000Kooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0i_ooool001_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`3Wooooo`006oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
0>Oooooo000Kooooo`;o00006?ooool00ol0003oooooooooo`3Xooooo`006oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo0>Sooooo000Kooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0jOooool001_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3Y
ooooo`006oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>[ooooo000;ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00004ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0j_ooool000Gooooo1?l000001?oooooo0000ooooool00008oooo
o`03o`000?oooooooooo00?ooooo0_l0000Eooooo`03o`000?oooooooooo0>_ooooo000:ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0>_ooooo000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0>cooooo000;ooooo`03o`000?oo
oooooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0k?oo
ool001_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3]ooooo`006oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0>gooooo000Kooooo`;o00004_ooool00ol0003o
ooooooooo`3^ooooo`006oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0>kooooo
000Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0k_ooool001_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3_ooooo`006oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0>oooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0l?ooool001_ooooo0_l0000@ooooo`03o`000?oooooooooo0?3ooooo000Kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0l?ooool001_ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3aooooo`006oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0?7ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0l_ooool001_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`3booooo`006oooool2o`0000gooooo00?o
0000ooooooooool0loooool001_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3c
ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0??ooooo000Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0m?ooool001_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3dooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo0?Gooooo000Kooooo`;o00002oooool00ol0003oooooooooo`3eooooo`006oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0m_ooool001_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3fooooo`006oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?Oooooo0006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool3o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3gooooo`001?l00000
1?oooooo0000ooooool00007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_oo
ool2o`0000Wooooo00?o0000ooooooooool0moooool000Gooooo00?o0000ooooool000001oooool0
0ol0003oooooo`000002ooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?Sooooo0005ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0n?ooool000Ko
oooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool3o`0000Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3iooooo`006oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02gooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go
00000oooool5o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1ol00002ooooo`Go
00000oooool5o`0000?ooooo1Ol00003ooooo`Go00000oooool5o`0000?ooooo1?l00003ooooo`Go
00000oooool5o`0000?ooooo1Ol00003ooooo`Go00000oooool4o`0000?ooooo1Ol00003ooooo`Go
00000oooool5o`0000?ooooo0ol0000<ooooo`006oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Kooooo1Ol00002ooooo`Go00000oooool5o`000<oooooo000Kooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03oooool5o`000>Kooooo000Kooooo`;o00001_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0>cooooo000Kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool2o`000>oooooo000Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool2o`000?7ooooo000Kooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3cooooo`006oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool001_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?Gooooo000Koooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?Kooooo000Kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0o?ooool001_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3mooooo`006oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000noooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo00000?_ooooo000Kooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`3jooooo`006oooool2o`0000;ooooo00Co0000oooooooooooo0000oOooool001_ooooo00Go
0000ooooooooooooooooo`00003oooooo`7ooooo000Kooooo`04o`000?ooooooooooo`000?oooooo
0_ooool001_ooooo00Ko0000oooooooooooo0000ooooool0003oooooo`006oooool01_l0003ooooo
ooooool0003oooooo`0002;ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`?o00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool3
o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00Oooool001_ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`0Qooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000008?ooool3o`0000;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooo000001oooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000008?oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`00000Nooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`00
6oooool3o`000003ooooool0003ooooo02Cooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooool000008?ooool00ol0003oooooo`000002oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Ooooo
o`?o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000008Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooo000001kooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo000Kooooo`04o`000?oooooo0000o`0002Kooooo00Ko0000oooooooooooo0000ooooool00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000008Oooool2o`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001oooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000008?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`00000Nooooo`07o`000?ooooooooooooooool0003ooooo
o`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
o`000002ooooo`006oooool2o`0002Kooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`?o0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00Oooool001_ooooo0_l0003oooooo`Cooooo000K
ooooo`;o0000ooooool4ooooo`006oooool2o`000?oooooo1?ooool001Goooooool00006o`0000Ko
oooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0ooooool3ooooo`006oooool00ol0
003oooooooooo`3oooooo`?ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo002@ooooo`?o0000SOooool0097ooooo00?o0000ooooooooool0S?ooool008Oooooo
0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`?o00000_ooool3o`0000Kooooo
0ol0001iooooo`00R?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003o
ooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Sooooo0028ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`00
0?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0N?ooool008Sooooo00?o0000ooooooooool01?l000000ooooooo0000o`000002o`00
0006ooooool0003o0000ooooool0003ooooo1?l00007ooooo`03o`000?oooooooooo07Sooooo0027
ooooo`?o00004Oooool00ol0003oooooooooo`06ooooo`;o0000N_ooool00?oooooo8Oooool00?oo
oooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1100.03, -0.259686, \
40.3639, 0.00163942}},
  CellTags->"2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-05 0.0147151 1.37419 [
[.21429 .00222 -9.6 -7.2 ]
[.21429 .00222 9.6 0 ]
[.40476 .00222 -9.6 -7.2 ]
[.40476 .00222 9.6 0 ]
[.59524 .00222 -9.6 -7.2 ]
[.59524 .00222 9.6 0 ]
[.78571 .00222 -9.6 -7.2 ]
[.78571 .00222 9.6 0 ]
[.97619 .00222 -12 -7.2 ]
[.97619 .00222 12 0 ]
[.01131 .15213 -14.4 -3.6 ]
[.01131 .15213 0 3.6 ]
[.01131 .28955 -14.4 -3.6 ]
[.01131 .28955 0 3.6 ]
[.01131 .42697 -14.4 -3.6 ]
[.01131 .42697 0 3.6 ]
[.01131 .56439 -14.4 -3.6 ]
[.01131 .56439 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2000)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4000)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6000)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8000)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15213 m
.03006 .15213 L
s
[(0.1)] .01131 .15213 1 0 Mshowa
.02381 .28955 m
.03006 .28955 L
s
[(0.2)] .01131 .28955 1 0 Mshowa
.02381 .42697 m
.03006 .42697 L
s
[(0.3)] .01131 .42697 1 0 Mshowa
.02381 .56439 m
.03006 .56439 L
s
[(0.4)] .01131 .56439 1 0 Mshowa
.125 Mabswid
.02381 .0422 m
.02756 .0422 L
s
.02381 .06968 m
.02756 .06968 L
s
.02381 .09717 m
.02756 .09717 L
s
.02381 .12465 m
.02756 .12465 L
s
.02381 .17962 m
.02756 .17962 L
s
.02381 .2071 m
.02756 .2071 L
s
.02381 .23459 m
.02756 .23459 L
s
.02381 .26207 m
.02756 .26207 L
s
.02381 .31704 m
.02756 .31704 L
s
.02381 .34452 m
.02756 .34452 L
s
.02381 .37201 m
.02756 .37201 L
s
.02381 .39949 m
.02756 .39949 L
s
.02381 .45446 m
.02756 .45446 L
s
.02381 .48194 m
.02756 .48194 L
s
.02381 .50943 m
.02756 .50943 L
s
.02381 .53691 m
.02756 .53691 L
s
.02381 .59188 m
.02756 .59188 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01472 m
.06244 .13078 L
.10458 .23425 L
.14415 .3108 L
.18221 .3695 L
.22272 .41919 L
.26171 .45712 L
.30316 .48901 L
.34309 .51324 L
.3815 .53178 L
.42237 .54745 L
.46172 .55938 L
.49955 .56853 L
.53984 .5763 L
.57861 .58224 L
.61984 .58723 L
.65954 .59104 L
.69774 .59395 L
.73838 .59641 L
.77751 .59829 L
.81909 .59987 L
.85916 .60107 L
.89771 .60198 L
.93871 .60276 L
.97619 .60332 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .01472 m
.03279 .04188 L
.04262 .06834 L
.05288 .08895 L
.06244 .10333 L
.0731 .11527 L
.0828 .12334 L
.094 .13021 L
.10458 .13494 L
.11428 .13816 L
.12455 .14071 L
.13333 .14236 L
.14299 .14375 L
.15313 .14484 L
.1624 .14559 L
.17311 .14624 L
.18328 .1467 L
.19287 .14702 L
.20309 .14727 L
.21273 .14745 L
.22147 .14758 L
.2315 .14769 L
.24072 .14777 L
.25085 .14783 L
.26154 .14788 L
.27102 .14791 L
.28118 .14794 L
.29077 .14795 L
.29951 .14797 L
.30943 .14798 L
.3186 .14799 L
.32866 .14799 L
.33936 .148 L
.34873 .148 L
.35883 .148 L
.36837 .14801 L
.37711 .14801 L
.38691 .14801 L
.39603 .14801 L
.40604 .14801 L
.41673 .14801 L
.42698 .14801 L
.43808 .14801 L
.44856 .14801 L
.45823 .14801 L
.46792 .14801 L
.47699 .14801 L
.48694 .14801 L
.49763 .14801 L
.50776 .14801 L
Mistroke
.51881 .14801 L
.52924 .14801 L
.53891 .14801 L
.5495 .14801 L
.55947 .14801 L
.56842 .14801 L
.57809 .14801 L
.58762 .14801 L
.59807 .14801 L
.60898 .14801 L
.61915 .14801 L
.62963 .14801 L
.63954 .14801 L
.64844 .14801 L
.65811 .14801 L
.66753 .14801 L
.67792 .14801 L
.68877 .14801 L
.69894 .14801 L
.7088 .14801 L
.71916 .14801 L
.72801 .14801 L
.73768 .14801 L
.74798 .14801 L
.75733 .14801 L
.76812 .14801 L
.7783 .14801 L
.78804 .14801 L
.79835 .14801 L
.80715 .14801 L
.81681 .14801 L
.827 .14801 L
.8363 .14801 L
.84703 .14801 L
.85721 .14801 L
.86684 .14801 L
.87709 .14801 L
.88584 .14801 L
.8955 .14801 L
.90558 .14801 L
.91483 .14801 L
.92498 .14801 L
.93567 .14801 L
.9452 .14801 L
.95539 .14801 L
.96501 .14801 L
.97375 .14801 L
.97619 .14801 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`00@Oooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001oooooo0ol00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000N
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001kooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000007Oooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooool000002_ooool004;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000007oooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Nooooo`?o
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00007oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001gooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000[ooooo
0012ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo0000023ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001kooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00007Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000002_ooool001Wooooo00?o0000oooo
ooooool09?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo000Iooooo`03
o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000ooooooooool0ooooool5ooooo`004ooo
ooooo`0000kooooo000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Booooo`006Oooool2o`0002kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Booooo`006Oooool2o`000?oooooo1_ooool001Wooooo0_l0003oooooo`Kooooo
000Iooooo`?o0000ooooool5ooooo`006Oooool00ol0003oooooo`00003oooooo`Gooooo000Ioooo
o`?o0000ooooool5ooooo`006Oooool01?l0003oooooooooool0003oooooo`Cooooo000Iooooo`04
o`000?ooooooooooo`000?oooooo1?ooool001Wooooo00Co0000oooooooooooo0000ooooool4oooo
o`006Oooool00ol0003oooooooooo`02o`000?oooooo0oooool001Wooooo00?o0000ooooooooool0
0_l0003oooooo`?ooooo000Iooooo`05o`000?ooooooooooooooool00000ooooool3ooooo`006Ooo
ool2o`0000?ooooo00?o0000ooooooooool0ooooool001Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0o_ooool001Wooooo
00?o0000ooooooooool00oooool2o`000?oooooo000Iooooo`03o`000?oooooooooo00?ooooo0_l0
003oooooo`006Oooool00ol0003oooooooooo`04ooooo`;o0000o_ooool001Wooooo0_l00005oooo
o`03o`000?oooooo00000?gooooo000Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oOooool001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3looooo`006Ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?_ooooo000Iooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo0000noooool001Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`000?Wooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3fooooo`006Oooool2o`0000Oooooo00?o0000oooo
ooooool0noooool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o
0000m?ooool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?7ooooo000Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3`ooooo`006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo1Ol0003Zooooo`006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo1Ol00003ooooo`Go0000foooool000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Loooo
o`04o`000?ooooooooooooooo`Co00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5
o`0000?ooooo1?l00003ooooo`Go00000oooool5o`0000?ooooo1?l00003ooooo`Go00000oooool0
1?l0003oooooooooooooool4o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol0
0003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Co00000oooool5o`0000?ooooo1Ol0
0002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool2o`0001Cooooo0008
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool0n?ooool000Sooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0n?ooool000Sooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0moooool000Wooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3gooooo`006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0?Kooooo000Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0m_ooool0
01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3fooooo`006Oooool2o`0000go
oooo00?o0000ooooooooool0mOooool001Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`3eooooo`006Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?Gooooo000I
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0m?ooool001Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3dooooo`006Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0?Cooooo000Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
loooool001Wooooo0_l0000?ooooo`03o`000?oooooooooo0??ooooo000Iooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0l_ooool001Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`3booooo`006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?;o
oooo000Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0lOooool001Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3aooooo`006Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0?7ooooo000Iooooo`;o00004_ooool00ol0003oooooooooo`3`oooo
o`006Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?3ooooo000Iooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0koooool001Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`3_ooooo`006Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0>kooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0k_ooool001Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3]ooooo`006Oooool2o`0001Gooooo
00?o0000ooooooooool0kOooool001Wooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3/ooooo`006Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>cooooo000Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0joooool001Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`3Zooooo`006Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo0>[ooooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo
0ol00004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0jOooool000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`;o00006Oooool00ol0003ooooooooo
o`3Yooooo`002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`3Xooooo`002?ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Xoooo
o`002Oooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo0>Oooooo000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
ioooool001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3Vooooo`006Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>Kooooo000Iooooo`;o00007Oooool00ol0
003oooooooooo`3Uooooo`006Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0>Co
oooo000Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0i?ooool001Wooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`3Sooooo`006Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo0>;ooooo000Iooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0h_ooool001Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3Qooooo`00
6Oooool2o`0002;ooooo00?o0000ooooooooool0h?ooool001Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`3Pooooo`006Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo0=oooooo000Iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0g_ooool001Wo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3Nooooo`006Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0=gooooo000Iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0g?ooool001Wooooo0_l0000Vooooo`03o`000?oooooooooo0=cooooo000Ioooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0foooool001Wooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`3Jooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0=Wooooo000Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0fOoo
ool001Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3Hooooo`006Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0=Oooooo000Iooooo`;o0000;?ooool00ol0003o
ooooooooo`3Fooooo`006Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0=Gooooo
000Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0eOooool001Wooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`3Dooooo`006Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo0=?ooooo000Iooooo`03o`000?oooooooooo02oooooo0_l0003Cooooo`00
2Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0=3ooooo0008ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool00_ooool2o`0003?ooooo00?o0000ooooooooool0coooool000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0c_ooool000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0cOooool000Wooooo00?o0000oooo
ooooool01_ooool3o`0000Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3<oooo
o`006Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0<_ooooo000Iooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0b_ooool001Wooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`39ooooo`006Oooool2o`0003[ooooo0_l00039ooooo`006Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0<Kooooo000Iooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0aOooool001Wooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`34ooooo`006Oooool00ol0003oooooooooo`0nooooo`;o0000a?ooool001Wooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`31ooooo`006Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo0<3ooooo000Iooooo`;o0000@oooool00ol0003oooooooooo`2oooooo`00
6Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;kooooo000Iooooo`03o`000?oo
oooooooo04Cooooo0_l0002nooooo`006Oooool00ol0003oooooooooo`16ooooo`;o0000_?ooool0
01Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2iooooo`006Oooool00ol0003o
ooooooooo`19ooooo`;o0000^Oooool001Wooooo00?o0000ooooooooool0Boooool2o`000;Oooooo
000Iooooo`;o0000C_ooool00ol0003oooooooooo`2dooooo`006Oooool00ol0003oooooooooo`1>
ooooo`;o0000]?ooool001Wooooo00?o0000ooooooooool0D?ooool3o`000;7ooooo000Iooooo`03
o`000?oooooooooo05?ooooo0_l0002_ooooo`006Oooool00ol0003oooooooooo`1Eooooo`?o0000
[?ooool001Wooooo00?o0000ooooooooool0F?ooool2o`000:[ooooo000Iooooo`03o`000?oooooo
oooo05[ooooo0ol0002Wooooo`006Oooool2o`0005kooooo0_l0002Uooooo`006Oooool00ol0003o
ooooooooo`1Oooooo`?o0000X_ooool001Wooooo00?o0000ooooooooool0H_ooool3o`0009oooooo
000Iooooo`03o`000?oooooooooo06Gooooo0ol0002Looooo`006Oooool00ol0003oooooooooo`1X
ooooo`?o0000VOooool001Wooooo00?o0000ooooooooool0Joooool4o`0009Gooooo0009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06oooooo0ol0002Booooo`002?ooool00ol0003oooooo`000007ooooo`?o0000
1?ooool2o`0007?ooooo0ol0002?ooooo`002?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool0MOooool5o`0008[ooooo0008ooooo`03o`000?oooooo
000000Sooooo0_l00004ooooo`03o`000?oooooooooo07[ooooo1Ol00025ooooo`002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool7o`00
07kooooo000Iooooo`03o`000?oooooooooo08Kooooo2_l0001dooooo`006Oooool00ol0003ooooo
ooooo`2@ooooo`[o0000J_ooool001Wooooo00?o0000ooooooooool0V_ooool:o`00063ooooo000I
ooooo`;o0000YOooool:o`0005Kooooo000Iooooo`03o`000?oooooooooo0:kooooo5Ol00011oooo
o`006Oooool00ol0003oooooooooo`33ooooobSo00006Oooool001Wooooo00?o0000ooooooooool0
joooool5o`0001Cooooo000Iooooo`03o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000
ooooooooool0ooooool5ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo002;ooooo`?o0000T_ooool008co
oooo00?o0000ooooooooool0TOooool008;ooooo0ol00002ooooo`03o`000?oooooo000000;ooooo
0ol00002ooooo`?o00000_ooool3o`0000Kooooo0ol0001nooooo`00Poooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07gooooo0023ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O?ooool008?ooooo00?o0000oooo
ooooool01?l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l0
0008ooooo`03o`000?oooooooooo07cooooo0022ooooo`?o00004Oooool00ol0003oooooooooo`06
ooooo`?o0000O_ooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1041.88, -0.029704, 41.301, \
0.00286236}},
  CellTags->"2.2"]
}, Open  ]]
}, Open  ]],

Cell["\<\
While these plots confirm that the open-loop system is stable, with \
the individual loop responses behaving as expected from the poles of the \
transfer-function matrix model elements, an improvement in the speed of \
response of the top temperature would be beneficial.\
\>", "Text",
  CellTags->"2.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 Analysis Using Alternative Models", "Subsection",
  CellTags->{"2.3", "c:4"}],

Cell[TextData[{
  "Many modern control techniques, such as the H-infinity robustness \
methodology, require the system model to be put into the form of a coprime \
matrix fraction representation. Functions to generate left and right \
matrix-fraction models have been implemented in ",
  StyleBox["Polynomial Control Systems",
    FontSlant->"Italic"],
  " (see ",
  ButtonBox["Section\[NonBreakingSpace]3.4.1 ",
    ButtonData:>"PCS3.4.1",
    ButtonStyle->"AddOnsLinkText"],
  "and ",
  ButtonBox["Section\[NonBreakingSpace]3.4.2",
    ButtonData:>"PCS3.4.2",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "Text",
  CellTags->"2.3"],

Cell["\<\
This generates a right matrix-fraction model of the distillation \
column.\
\>", "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightMatrixFraction[tf]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          StyleBox[
            RowBox[{"\[AutoLeftMatch]", 
              RowBox[{
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(\(-0.252`\)\ \((25.3`\ \[ScriptS] + 1.`)\)\^3\ \
\((360.`\ \[ScriptS] + 1.`)\)\), \(154.8`\ \[ScriptS] + 0.43`\)},
                      {\(\(-0.0435`\)\ \((3.3`\ \[ScriptS] + 1.`)\)\^3\ \
\((1800.`\ \[ScriptS] + 1.`)\)\), \(174.6`\ \[ScriptS] + 0.097`\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}], 
                "\[InvisibleSpace]", 
                SuperscriptBox[
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(\((3.3`\ \[ScriptS] + 1.`)\)\^3\ \((25.3`\ \
\[ScriptS] + 1.`)\)\^3\ \((360.`\ \[ScriptS] + 
                                1.`)\)\ \((1800.`\ \[ScriptS] + 1.`)\)\), 
                          "0"},
                        {
                          "0", \(\((12.`\ \[ScriptS] + 
                                1.`)\)\ \((360.`\ \[ScriptS] + 
                                1.`)\)\ \((1800.`\ \[ScriptS] + 1.`)\)\)}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left},
                      AllowScriptLevelChange->False], "\[NoBreak]", 
                    ")"}], \(-1\)]}], 
              SubsuperscriptBox[
                FormBox[
                  StyleBox["\[RightBracketingBar]",
                    SpanMaxSize->Infinity],
                  "TraditionalForm"], 
                FormBox[
                  StyleBox["\<\"\[InvisibleSpace]\"\>",
                    ShowStringCharacters->False],
                  "TraditionalForm"], 
                FormBox[
                  StyleBox["\<\"\[ScriptCapitalR]\"\>",
                    Editable->False,
                    ShowStringCharacters->False],
                  "TraditionalForm"],
                MultilineFunction->None]}],
            SpanMaxSize->Infinity],
          "TraditionalForm"],
        (RightMatrixFraction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[6]=",
  CellTags->"2.3"]
}, Open  ]],

Cell["This is a left matrix-fraction model of the same system.", "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftMatrixFraction[tf]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          StyleBox[
            RowBox[{"\[AutoLeftMatch]", 
              RowBox[{
                SuperscriptBox[
                  RowBox[{"(", "\[NoBreak]", GridBox[{
                        {\(\((3.3`\ \[ScriptS] + 1.`)\)\^3\ \((12.`\ \
\[ScriptS] + 1.`)\)\ \((1800.`\ \[ScriptS] + 1.`)\)\), "0"},
                        {
                          "0", \(\((12.`\ \[ScriptS] + 
                                1.`)\)\ \((25.3`\ \[ScriptS] + 1.`)\)\^3\ \
\((360.`\ \[ScriptS] + 1.`)\)\)}
                        },
                      RowSpacings->1,
                      ColumnSpacings->1,
                      ColumnAlignments->{Left},
                      AllowScriptLevelChange->False], "\[NoBreak]", 
                    ")"}], \(-1\)], "\[InvisibleSpace]", 
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(\(-3.024`\)\ \[ScriptS] - 
                          0.252`\), \(0.43`\ \((3.3`\ \[ScriptS] + \
1.`)\)\^3\)},
                      {\(\(-0.522`\)\ \[ScriptS] - 
                          0.0435`\), \(0.097`\ \((25.3`\ \[ScriptS] + \
1.`)\)\^3\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}]}], 
              SubsuperscriptBox[
                FormBox[
                  StyleBox["\[RightBracketingBar]",
                    SpanMaxSize->Infinity],
                  "TraditionalForm"], 
                FormBox[
                  StyleBox["\<\"\[InvisibleSpace]\"\>",
                    ShowStringCharacters->False],
                  "TraditionalForm"], 
                FormBox[
                  StyleBox["\<\"\[ScriptCapitalL]\"\>",
                    Editable->False,
                    ShowStringCharacters->False],
                  "TraditionalForm"],
                MultilineFunction->None]}],
            SpanMaxSize->Infinity],
          "TraditionalForm"],
        (LeftMatrixFraction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[7]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "The denominator and numerator matrices in this left matrix-fraction model \
are coprime (see ",
  ButtonBox["Section\[NonBreakingSpace]4.3.1",
    ButtonData:>"PCS4.3.1",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftCoprime[%]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "There are many system matrix models that correspond to the same \
transfer-function matrix. Given a ",
  StyleBox["TransferFunction", "MR"],
  " model as input, ",
  StyleBox["SystemMatrix", "MR"],
  ", by default, constructs the right matrix-fraction form of the system \
matrix in polynomial form (see ",
  ButtonBox["Section\[NonBreakingSpace]3.3.1",
    ButtonData:>"PCS3.3.1",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "Text",
  CellTags->"2.3"],

Cell[TextData[{
  "Here is an initial ",
  Cell[BoxData[
      \(TraditionalForm\`11\^th\)]],
  "-order system matrix model of the distillation column in polynomial form."
}], "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ps\  = \ SystemMatrix[tf]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "1", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "1", "0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "1", "0", "0", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", 
                      "0", "0"},
                    {"0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", \(\((3.3`\ \[ScriptS] + 1)\)\^3\ \((25.3`\ \
\[ScriptS] + 1)\)\^3\ \((360\ \[ScriptS] + 1)\)\ \((1800\ \[ScriptS] + 1)\)\),
                       "0", "1", "0"},
                    {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", \(\((12\ \[ScriptS] + 1)\)\ \((360\ \[ScriptS] + 
                            1)\)\ \((1800\ \[ScriptS] + 1)\)\), "0", "1"},
                    {"0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", \(0.252`\ \((25.3`\ \[ScriptS] + 1)\)\^3\ \((360\ \
\[ScriptS] + 1)\)\), \(\(-154.8`\)\ \[ScriptS] - 0.43`\), "0", "0"},
                    {"0", "0", "0", "0", "0", "0", "0", "0", 
                      "0", \(0.0435`\ \((3.3`\ \[ScriptS] + 1.`)\)\^3\ \
\((1800.`\ \[ScriptS] + 1.`)\)\), \(\(-174.6`\)\ \[ScriptS] - 0.097`\), "0", 
                      "0"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  
                  RowLines->{
                    False, False, False, False, False, False, False, False, 
                      False, False, True, False},
                  
                  ColumnLines->{
                    False, False, False, False, False, False, False, False, 
                      False, False, True, False},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalM]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (SystemMatrix[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[9]=",
  CellLabelPositioning->Above,
  CellTags->"2.3"]
}, Open  ]],

Cell["\<\
For the application of modern synthesis techniques, such as pole \
assignment using state or output feedback, the designer usually needs a \
state-space form of the system model in which, for the use of state feedback, \
the system must be completely controllable and, for the use of output \
feedback, the system must be both completely observable and completely \
controllable.\
\>", "Text",
  CellTags->"2.3"],

Cell[TextData[{
  "Here is a previously developed state-space model of the distillation \
column, with 11 states. ",
  StyleBox["NumberForm", "MR"],
  " displays a smaller sized output."
}], "MathCaption",
  CellTags->"2.3"],

Cell[BoxData[
    \(\(ss = 
        StateSpace[{{\(-0.0005555555555555556\), \(-0.002799241440856779\), 
              0, 0, 0, 0, 0, 0, 0, 0, 0}, {0, \(-0.008918513630400741\), 
              0.0059439151861032935, 0, 0, 0, 0, 0, 0, 0, 0}, {0, 
              0.16773568793732085, \(-0.16513726151233085\), \
\(-0.0059778223713360945\), 0, 0, 0, 0, 0, 0, 0}, {0, \(-1. \), 
              0.9679483581050639, \(-0.17127799736495386\), \
\(-0.046289786795028265\), 0, 0, 0, 0, 0, 0}, {0, 0, 0, 
              1. , \(-0.5665349143610015\), \(-0.790513833992095\), 0, 0, 0, 
              0, 0}, {0, 0, 0, 0, 0, 0, 0, 1. , 0, 0, 0}, {0, 0, 0, 0, 0, 
              0, \(-0.0005555555555555556\), 0, \(-0.0022835249042145594\), 
              0, 0}, {0, 1. , 
              0.03205164189493615, \(-0.0007645316498551908\), 
              0.00006277527107565687, \(-0.0043651761982159525\), 
              0, \(-0.11579929732103646\), 0, 1. , 0}, {0, 0, 0, 0, 0, 0, 0, 
              0, \(-0.08333333333333333\), 0, \(-0.08055555555555555\)}, {0, 
              0, 0, 0, 0, 0, 0, 0, 0, \(-0.002777777777777778\), 0}, {0, 0, 
              0, 0, 0, 0, 0, 0, 0, 0, \(-0.002777777777777778\)}}, {{0, 
              0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 0}, {0, 
              0}, {1. , 0}, {0, 1. }}, {{\(-0.00014077283198397005\), 
              0.00003092943010954112, 0.00014170404385019825, 
              0.00002390422089646465, 4.928068564432184*^-6, 0, 
              0.00024049217002237137, 0, \(-0.0002471264367816092\), 0, 
              0}, {0, 0.0001503582011983364, 
              4.8192272207758386*^-6, \(-1.1495360363142286*^-7\), 
              9.438776838673724*^-9, 0, 0, 0, \(-0.0002787356321839081\), 0, 
              0}}];\)\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[ss, 1]\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          FormBox[
            SubsuperscriptBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"-0.0006\"\>", "\<\"-0.003\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-0.009\"\>", "\<\"0.006\"\>", "\<\"0\
\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0.2\"\>", "\<\"-0.2\"\>", \
"\<\"-0.006\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-1.\"\>", "\<\"1.\"\>", \
"\<\"-0.2\"\>", "\<\"-0.05\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\
\<\"-0.6\"\>", "\<\"-0.8\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"-0.0006\"\>", "\<\"0\"\>", "\<\"-0.002\"\>", "\
\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"1.\"\>", "\<\"0.03\"\>", \
"\<\"-0.0008\"\>", "\<\"0.00006\"\>", "\<\"-0.004\"\>", "\<\"0\"\>", \
"\<\"-0.1\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\
\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-0.08\"\>", "\<\"0\"\
\>", "\<\"-0.08\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"-0.003\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"-0.003\"\>", "\<\"0\"\>", "\<\"1.\"\>"},
                      {"\<\"-0.0001\"\>", "\<\"0.00003\"\>", \
"\<\"0.0001\"\>", "\<\"0.00002\"\>", \("5."\[Times]10\^"-6"\), "\<\"0\"\>", "\
\<\"0.0002\"\>", "\<\"0\"\>", "\<\"-0.0002\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0.0002\"\>", \
\("5."\[Times]10\^"-6"\), \("-1."\[Times]10\^"-7"\), \
\("9."\[Times]10\^"-9"\), "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-0.0003\
\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    
                    RowLines->{
                      False, False, False, False, False, False, False, False, 
                        False, False, True, False},
                    
                    ColumnLines->{
                      False, False, False, False, False, False, False, False, 
                        False, False, True, False},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
                "TraditionalForm"], 
              FormBox["\[Bullet]",
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[ScriptCapitalS]\"\>",
                  Editable->False,
                  ShowStringCharacters->False],
                "TraditionalForm"],
              MultilineFunction->None],
            "TraditionalForm"],
          (StateSpace[ 
            SlotSequence[ 1], ControlSystems`Common`Private`noD -> True]&)],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[11]//NumberForm=",
  CellLabelPositioning->Above,
  CellTags->"2.3"]
}, Open  ]],

Cell["The state-space model is controllable, but not observable.", \
"MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Controllable[ss]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Observable[ss]\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "There must be a total of two unobservable modes, because the McMillan \
degree, which is the total number of poles in the McMillan form of the \
transfer-function matrix model, indicates that a minimal state-space \
realization will only be of order 9 (see ",
  ButtonBox["Section\[NonBreakingSpace]4.1.3",
    ButtonData:>"PCS4.1.3",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(McMillanDegree[tf]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(9\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "Given a ",
  StyleBox["StateSpace", "MR"],
  " system as input, ",
  StyleBox["SystemMatrix", "MR"],
  " produces a system matrix model in the state-space form (see ",
  ButtonBox["Section\[NonBreakingSpace]3.3.2",
    ButtonData:>"PCS3.3.2",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "MathCaption",
  CellTags->"2.3"],

Cell[BoxData[
    \(\(pss\  = \ SystemMatrix[s, ss];\)\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[pss, 1]\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          FormBox[
            SubsuperscriptBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(\[ScriptS] + 
                          "0.0006"\), "\<\"0.003\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", \(\[ScriptS] + 
                          "0.009"\), "\<\"-0.006\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-0.2\"\>", \(\[ScriptS] + 
                          "0.2"\), "\<\"0.006\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"1.\"\>", "\<\"-1.\"\>", \(\[ScriptS] \
+ "0.2"\), "\<\"0.05\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-1.\"\>", \
\(\[ScriptS] + 
                          "0.6"\), "\<\"0.8\"\>", "\<\"0\"\>", "\<\"0\"\>", "\
\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", 
                        "\[ScriptS]", "\<\"0\"\>", "\<\"-1.\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.0006"\), "\<\"0\"\>", "\<\"0.002\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-1.\"\>", "\<\"-0.03\"\>", \
"\<\"0.0008\"\>", "\<\"-0.00006\"\>", "\<\"0.004\"\>", "\<\"0\"\>", \(\
\[ScriptS] + 
                          "0.1"\), "\<\"0\"\>", "\<\"-1.\"\>", "\<\"0\"\>", "\
\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.08"\), "\<\"0\"\>", "\<\"0.08\"\>", "\<\"0\"\>", \
"\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \(\[ScriptS] \
+ "0.003"\), "\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
\(\[ScriptS] + "0.003"\), "\<\"0\"\>", "\<\"1.\"\>"},
                      {"\<\"0.0001\"\>", "\<\"-0.00003\"\>", \
"\<\"-0.0001\"\>", "\<\"-0.00002\"\>", \("-5."\[Times]10\^"-6"\), \
"\<\"0\"\>", "\<\"-0.0002\"\>", "\<\"0\"\>", "\<\"0.0002\"\>", "\<\"0\"\>", "\
\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-0.0002\"\>", \
\("-5."\[Times]10\^"-6"\), \("1."\[Times]10\^"-7"\), \
\("-9."\[Times]10\^"-9"\), "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0.0003\
\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    
                    RowLines->{
                      False, False, False, False, False, False, False, False, 
                        False, False, True, False},
                    
                    ColumnLines->{
                      False, False, False, False, False, False, False, False, 
                        False, False, True, False},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[InvisibleSpace]\"\>",
                  ShowStringCharacters->False],
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[ScriptCapitalM]\"\>",
                  Editable->False,
                  ShowStringCharacters->False],
                "TraditionalForm"],
              MultilineFunction->None],
            "TraditionalForm"],
          (SystemMatrix[ s, 
            SlotSequence[ 1]]&)],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[16]//NumberForm=",
  CellLabelPositioning->Above,
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "In the same way that state-space models can have uncontrollable modes and \
unobservable modes, system matrix models may have input decoupling zeros and \
output decoupling zeros, respectively (see ",
  ButtonBox["Section\[NonBreakingSpace]4.4.1",
    ButtonData:>"PCS4.4.1",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "Text",
  CellTags->"2.3"],

Cell["\<\
This determines the output decoupling zeros, or unobservable modes, \
of the system.\
\>", "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(OutputDecouplingZeros[pss]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \({\(-0.002777777777777768`\), \(-0.0005555555555555556`\)}\)], "Output",
  CellLabel->"Out[17]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "This removes the decoupling zeros and produces a least-order, or minimal, \
system matrix model of the distillation column in state-space form, which is \
of order 9 as expected (see ",
  ButtonBox["Section\[NonBreakingSpace]4.4.3",
    ButtonData:>"PCS4.4.3",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "MathCaption",
  CellTags->"2.3"],

Cell[BoxData[
    \(\(lo\  = \ LeastOrderSystem[pss];\)\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[lo, 1]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->"2.3"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          FormBox[
            SubsuperscriptBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(\[ScriptS] + 
                          "0.08"\), "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"-1.\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"-0.0001\"\>", \(\[ScriptS] + 
                          "0.2"\), "\<\"0\"\>", "\<\"-0.006\"\>", "\<\"0.02\"\
\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>"},
                      {"\<\"-0.00008\"\>", "\<\"0.0008\"\>", \(\[ScriptS] + 
                          "0.003"\), "\<\"0.0002\"\>", "\<\"0.002\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", \
"\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.2"\), "\<\"0.3\"\>", "\<\"0.05\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"-1.\"\>", "\<\"0.0008\"\
\>", \(\[ScriptS] + 
                          "0.03"\), "\<\"-0.00006\"\>", "\<\"0\"\>", "\<\"0\"\
\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-1.\"\>", \
"\<\"-1.\"\>", \(\[ScriptS] + 
                          "0.6"\), "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\
\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0.0003\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.003"\), "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\
\<\"1.\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0.02\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.0006"\), "\<\"0.002\"\>", "\<\"0\"\>", \
"\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0.08\"\>", "\<\"0\"\>", \(\[ScriptS] + 
                          "0.08"\), "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-0.0002\"\>", "\<\"0.0002\"\>", "\
\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0.0003\"\>", \
"\<\"0\"\>", "\<\"0\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    
                    RowLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    
                    ColumnLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[InvisibleSpace]\"\>",
                  ShowStringCharacters->False],
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[ScriptCapitalM]\"\>",
                  Editable->False,
                  ShowStringCharacters->False],
                "TraditionalForm"],
              MultilineFunction->None],
            "TraditionalForm"],
          (SystemMatrix[ s, 
            SlotSequence[ 1]]&)],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[19]//NumberForm=",
  CellLabelPositioning->Above,
  CellTags->"2.3"]
}, Open  ]],

Cell[TextData[{
  "You can apply the tests for controllability and observability from ",
  StyleBox["Control System Professional",
    FontSlant->"Italic"],
  " directly to a system matrix model."
}], "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Controllable[lo]\)], "Input",
  CellLabel->"In[20]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[20]=",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Observable[lo]\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->"2.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->"2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4 Pole Assignment with State Feedback", "Subsection",
  CellTags->{"2.4", "c:5"}],

Cell[TextData[{
  "Since the least-order system matrix representation of the distillation \
column generated in ",
  ButtonBox["Section\[NonBreakingSpace]2.3",
    ButtonData:>"PCS2.3",
    ButtonStyle->"AddOnsLinkText"],
  " is in state-space form, the corresponding state-space model can be \
readily constructed."
}], "Text",
  CellTags->"2.4"],

Cell[TextData[{
  "Here is the resulting ",
  Cell[BoxData[
      \(TraditionalForm\`9\^th\)]],
  "-order state-space model."
}], "MathCaption",
  CellTags->"2.4"],

Cell[BoxData[
    \(\(sss\  = \ StateSpace[lo];\)\)], "Input",
  CellLabel->"In[22]:=",
  FormatType->TraditionalForm,
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[sss, 1]\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->"2.4"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          FormBox[
            SubsuperscriptBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"-0.08\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0.0001\"\>", "\<\"-0.2\"\>", "\<\"0\"\>", \
"\<\"0.006\"\>", "\<\"-0.02\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0.00008\"\>", "\<\"-0.0008\"\>", \
"\<\"-0.003\"\>", "\<\"-0.0002\"\>", "\<\"-0.002\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"-1.\"\>", "\<\"0\"\>", \
"\<\"-0.2\"\>", "\<\"-0.3\"\>", "\<\"-0.05\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\<\"-0.0008\"\
\>", "\<\"-0.03\"\>", "\<\"0.00006\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"1.\"\>", "\
\<\"1.\"\>", "\<\"-0.6\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"-0.0003\"\>", "\<\"0\"\>", "\<\"-0.003\"\>", "\<\"0\"\>", "\<\"0\"\>", "\
\<\"0\"\>", "\<\"1.\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"-0.02\"\>", "\<\"0\"\>", "\<\"-0.0006\"\>", \
"\<\"-0.002\"\>", "\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"-0.08\"\>", "\<\"0\"\>", "\<\"-0.08\"\>", \
"\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0.0002\"\>", "\<\"-0.0002\"\>", "\
\<\"0\"\>", "\<\"0\"\>"},
                      {"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", \
"\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"0\"\>", "\<\"-0.0003\"\>", "\<\"0\
\"\>", "\<\"0\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    
                    RowLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    
                    ColumnLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
                "TraditionalForm"], 
              FormBox["\[Bullet]",
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[ScriptCapitalS]\"\>",
                  Editable->False,
                  ShowStringCharacters->False],
                "TraditionalForm"],
              MultilineFunction->None],
            "TraditionalForm"],
          (StateSpace[ 
            SlotSequence[ 1]]&)],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[23]//NumberForm=",
  CellTags->"2.4"]
}, Open  ]],

Cell["These are the poles (eigenvalues) of this model.", "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(olp = Chop[Eigenvalues[sss[\([1]\)]], 10\^\(-5\)]\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->"2.4"],

Cell[BoxData[
    \({\(-0.30303235217544106`\), \(-0.3030292784577345`\), \
\(-0.3030292784577345`\), \(-0.08333333333333333`\), \
\(-0.03952600719118618`\), \(-0.03952600719118618`\), \(-0.03952506071644187`\
\), \(-0.002777777777777778`\), \(-0.0005555555555555556`\)}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->"2.4"]
}, Open  ]],

Cell[TextData[{
  "These are the desired closed-loop poles, produced by replacing the two \
slowest open-loop poles by poles at ",
  Cell[BoxData[
      \(TraditionalForm\`\(-0.01\)\)]],
  "."
}], "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(clp\  = \ Join[Drop[olp, \(-2\)], {\(-0.01\), \(-0.01\)}]\)], "Input",
  CellLabel->"In[25]:=",
  FormatType->TraditionalForm,
  CellTags->"2.4"],

Cell[BoxData[
    \({\(-0.30303235217544106`\), \(-0.3030292784577345`\), \
\(-0.3030292784577345`\), \(-0.08333333333333333`\), \
\(-0.03952600719118618`\), \(-0.03952600719118618`\), \(-0.03952506071644187`\
\), \(-0.01`\), \(-0.01`\)}\)], "Output",
  CellLabel->"Out[25]=",
  CellTags->"2.4"]
}, Open  ]],

Cell[TextData[{
  "This is a full-rank state-feedback compensator such that the resulting \
closed-loop system will have the desired poles (see ",
  ButtonBox["Section\[NonBreakingSpace]6.3",
    ButtonData:>"PCS6.3",
    ButtonStyle->"AddOnsLinkText"],
  ")."
}], "MathCaption",
  CellTags->"2.4"],

Cell[BoxData[
    \(\(km\  = \ 
        StateFeedbackGains[sss, clp, Method \[Rule] FullRank];\)\)], "Input",
  CellLabel->"In[26]:=",
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[km, 1]\)], "Input",
  CellLabel->"In[27]:=",
  CellTags->"2.4"],

Cell[BoxData[
    FormBox[
      TagBox[
        RowBox[{"(", "\[NoBreak]", GridBox[{
              {"\<\"0.00008\"\>", "\<\"0.\"\>", "\<\"0.04\"\>", "\<\"-0.00003\
\"\>", "\<\"-0.002\"\>", \("3."\[Times]10\^"-6"\), "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>"},
              {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"2.\"\>", \
"\<\"2.\"\>", "\<\"-1.\"\>", "\<\"-0.03\"\>", "\<\"0.02\"\>", \
"\<\"-0.04\"\>"}
              },
            RowSpacings->1,
            ColumnSpacings->1,
            ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[27]//NumberForm=",
  CellTags->"2.4"]
}, Open  ]],

Cell["This closes the feedback loop.", "MathCaption",
  CellTags->"2.4"],

Cell[BoxData[
    \(\(ssc\  = StateFeedbackConnect[sss, km];\)\)], "Input",
  CellLabel->"In[28]:=",
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberForm[ssc, 1]\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->"2.4"],

Cell[BoxData[
    FormBox[
      TagBox[
        TagBox[
          FormBox[
            SubsuperscriptBox[
              FormBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\<\"-0.08\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\
\>", "\<\"1.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.0001\"\>", "\<\"-0.2\"\>", "\<\"0.\"\>", \
"\<\"0.006\"\>", "\<\"-0.02\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\
\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {\("5."\[Times]10\^"-15"\), "\<\"-0.0008\"\>", \
"\<\"-0.05\"\>", "\<\"-0.0002\"\>", "\<\"-0.0003\"\>", \
\("-3."\[Times]10\^"-6"\), "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"1.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"-1.\"\>", "\<\"0.\"\>", "\<\"-0.2\"\
\>", "\<\"-0.3\"\>", "\<\"-0.05\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"1.\"\>", "\<\"-0.0008\
\"\>", "\<\"-0.03\"\>", "\<\"0.00006\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"1.\"\>", "\<\"1.\"\>", "\<\"-0.6\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"-2.\"\>", "\<\"-2.\"\>", "\<\"1.\"\>", "\<\"0.02\"\>", "\<\"-0.02\"\>", \
"\<\"0.04\"\>", "\<\"0.\"\>", "\<\"1.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"-0.02\"\>", "\<\"0.\"\>", "\<\"-0.0006\"\>", \
"\<\"-0.002\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"-0.08\"\>", "\<\"0.\"\>", \
"\<\"-0.08\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.0002\"\>", "\<\
\"-0.0002\"\>", "\<\"0.\"\>", "\<\"0.\"\>"},
                      {"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", "\<\"0.\"\>", \
"\<\"-0.0003\"\>", "\<\"0.\"\>", "\<\"0.\"\>"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left},
                    
                    RowLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    
                    ColumnLines->{
                      False, False, False, False, False, False, False, False, 
                        True, False},
                    AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
                "TraditionalForm"], 
              FormBox["\[Bullet]",
                "TraditionalForm"], 
              FormBox[
                StyleBox["\<\"\[ScriptCapitalS]\"\>",
                  Editable->False,
                  ShowStringCharacters->False],
                "TraditionalForm"],
              MultilineFunction->None],
            "TraditionalForm"],
          (StateSpace[ 
            SlotSequence[ 1]]&)],
        (NumberForm[ #, 1]&)], TraditionalForm]], "Output",
  CellLabel->"Out[29]//NumberForm=",
  CellTags->"2.4"]
}, Open  ]],

Cell["\<\
The constant state-feedback compensator has achieved the desired \
closed-loop system poles.\
\>", "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[Eigenvalues[ssc\[LeftDoubleBracket]1\[RightDoubleBracket]], 
      10\^\(-4\)]\)], "Input",
  CellLabel->"In[30]:=",
  CellTags->"2.4"],

Cell[BoxData[
    \({\(-0.3030454410714747`\), \(-0.3030454410714747`\), \
\(-0.3030000269452434`\), \(-0.08333333333421844`\), \
\(-0.03952659209979598`\), \(-0.03952542219363008`\), \(-0.03952506080721957`\
\), \(-0.010000000283062867`\), \(-0.009999999716937148`\)}\)], "Output",
  CellLabel->"Out[30]=",
  CellTags->"2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.5 Frequency-Domain Design", "Subsection",
  CellTags->{"2.5", "c:6"}],

Cell[TextData[{
  "Before applying any frequency-domain design technique to a multivariable \
system, you should attempt to find the best individual inputs for controlling \
the system outputs. Here, the relative gain array is used for that purpose \
(see ",
  ButtonBox["Section\[NonBreakingSpace]5.1",
    ButtonData:>"PCS5.1",
    ButtonStyle->"AddOnsLinkText"],
  "). Then one of the frequency-domain compensator design methods implemented \
in ",
  StyleBox["Polynomial Control Systems",
    FontSlant->"Italic"],
  " is applied to construct a simple controller that significantly reduces \
the interaction present in the system, as demonstrated using the Nyquist \
array technique (see ",
  ButtonBox["Section\[NonBreakingSpace]5.2",
    ButtonData:>"PCS5.2",
    ButtonStyle->"AddOnsLinkText"],
  "). "
}], "Text",
  CellTags->"2.5"],

Cell["\<\
At least at zero frequency, the current input-output pairing (the \
first input controls the first output and the second input controls the \
second output) appears to be appropriate for the subsequent design.\
\>", \
"MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RelativeGainArray[tf]\)], "Input",
  CellLabel->"In[31]:=",
  CellTags->"2.5"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4.259278619968635`", \(-3.2592786199686348`\)},
            {\(-3.2592786199686348`\), "4.259278619968635`"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
      TraditionalForm]], "Output",
  CellLabel->"Out[31]=",
  CellTags->"2.5"]
}, Open  ]],

Cell["Here is the Nyquist array for the system.", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[tf];\)\)], "Input",
  CellLabel->"In[32]:=",
  CellTags->"2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .51933 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0123649 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .51933 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .51933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .51933 L
s
0 .51933 m
1 .51933 L
s
1 0 m
1 .51933 L
s
0 0 m
1 0 L
1 .51933 L
0 .51933 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0123649 0.477324 0.247887 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.369507 1.47696 0.327569 1.47696 [
[.07411 .31507 -9.6 -7.2 ]
[.07411 .31507 9.6 0 ]
[.22181 .31507 -9.6 -7.2 ]
[.22181 .31507 9.6 0 ]
[.5172 .31507 -7.2 -7.2 ]
[.5172 .31507 7.2 0 ]
[.6649 .31507 -7.2 -7.2 ]
[.6649 .31507 7.2 0 ]
[.81259 .31507 -7.2 -7.2 ]
[.81259 .31507 7.2 0 ]
[.96029 .31507 -7.2 -7.2 ]
[.96029 .31507 7.2 0 ]
[.35701 .03218 -19.2 -3.6 ]
[.35701 .03218 0 3.6 ]
[.35701 .10602 -24 -3.6 ]
[.35701 .10602 0 3.6 ]
[.35701 .17987 -19.2 -3.6 ]
[.35701 .17987 0 3.6 ]
[.35701 .25372 -24 -3.6 ]
[.35701 .25372 0 3.6 ]
[.35701 .40142 -19.2 -3.6 ]
[.35701 .40142 0 3.6 ]
[.35701 .47526 -14.4 -3.6 ]
[.35701 .47526 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .51933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07411 .32757 m
.07411 .33382 L
s
[(-0.2)] .07411 .31507 0 1 Mshowa
.22181 .32757 m
.22181 .33382 L
s
[(-0.1)] .22181 .31507 0 1 Mshowa
.5172 .32757 m
.5172 .33382 L
s
[(0.1)] .5172 .31507 0 1 Mshowa
.6649 .32757 m
.6649 .33382 L
s
[(0.2)] .6649 .31507 0 1 Mshowa
.81259 .32757 m
.81259 .33382 L
s
[(0.3)] .81259 .31507 0 1 Mshowa
.96029 .32757 m
.96029 .33382 L
s
[(0.4)] .96029 .31507 0 1 Mshowa
.125 Mabswid
.10365 .32757 m
.10365 .33132 L
s
.13319 .32757 m
.13319 .33132 L
s
.16273 .32757 m
.16273 .33132 L
s
.19227 .32757 m
.19227 .33132 L
s
.25135 .32757 m
.25135 .33132 L
s
.28089 .32757 m
.28089 .33132 L
s
.31043 .32757 m
.31043 .33132 L
s
.33997 .32757 m
.33997 .33132 L
s
.39905 .32757 m
.39905 .33132 L
s
.42859 .32757 m
.42859 .33132 L
s
.45812 .32757 m
.45812 .33132 L
s
.48766 .32757 m
.48766 .33132 L
s
.54674 .32757 m
.54674 .33132 L
s
.57628 .32757 m
.57628 .33132 L
s
.60582 .32757 m
.60582 .33132 L
s
.63536 .32757 m
.63536 .33132 L
s
.69444 .32757 m
.69444 .33132 L
s
.72398 .32757 m
.72398 .33132 L
s
.75352 .32757 m
.75352 .33132 L
s
.78306 .32757 m
.78306 .33132 L
s
.84213 .32757 m
.84213 .33132 L
s
.87167 .32757 m
.87167 .33132 L
s
.90121 .32757 m
.90121 .33132 L
s
.93075 .32757 m
.93075 .33132 L
s
.04458 .32757 m
.04458 .33132 L
s
.01504 .32757 m
.01504 .33132 L
s
.98983 .32757 m
.98983 .33132 L
s
.25 Mabswid
0 .32757 m
1 .32757 L
s
.36951 .03218 m
.37576 .03218 L
s
[(-0.2)] .35701 .03218 1 0 Mshowa
.36951 .10602 m
.37576 .10602 L
s
[(-0.15)] .35701 .10602 1 0 Mshowa
.36951 .17987 m
.37576 .17987 L
s
[(-0.1)] .35701 .17987 1 0 Mshowa
.36951 .25372 m
.37576 .25372 L
s
[(-0.05)] .35701 .25372 1 0 Mshowa
.36951 .40142 m
.37576 .40142 L
s
[(0.05)] .35701 .40142 1 0 Mshowa
.36951 .47526 m
.37576 .47526 L
s
[(0.1)] .35701 .47526 1 0 Mshowa
.125 Mabswid
.36951 .04695 m
.37326 .04695 L
s
.36951 .06172 m
.37326 .06172 L
s
.36951 .07649 m
.37326 .07649 L
s
.36951 .09126 m
.37326 .09126 L
s
.36951 .12079 m
.37326 .12079 L
s
.36951 .13556 m
.37326 .13556 L
s
.36951 .15033 m
.37326 .15033 L
s
.36951 .1651 m
.37326 .1651 L
s
.36951 .19464 m
.37326 .19464 L
s
.36951 .20941 m
.37326 .20941 L
s
.36951 .22418 m
.37326 .22418 L
s
.36951 .23895 m
.37326 .23895 L
s
.36951 .26849 m
.37326 .26849 L
s
.36951 .28326 m
.37326 .28326 L
s
.36951 .29803 m
.37326 .29803 L
s
.36951 .3128 m
.37326 .3128 L
s
.36951 .34234 m
.37326 .34234 L
s
.36951 .35711 m
.37326 .35711 L
s
.36951 .37188 m
.37326 .37188 L
s
.36951 .38665 m
.37326 .38665 L
s
.36951 .41619 m
.37326 .41619 L
s
.36951 .43096 m
.37326 .43096 L
s
.36951 .44573 m
.37326 .44573 L
s
.36951 .4605 m
.37326 .4605 L
s
.36951 .01741 m
.37326 .01741 L
s
.36951 .00264 m
.37326 .00264 L
s
.36951 .49003 m
.37326 .49003 L
s
.36951 .5048 m
.37326 .5048 L
s
.25 Mabswid
.36951 0 m
.36951 .51933 L
s
0 0 m
1 0 L
1 .51933 L
0 .51933 L
closepath
clip
newpath
.5 Mabswid
.30536 .33037 m
.30537 .33053 L
.30539 .33071 L
.3054 .33089 L
.30542 .33109 L
.30544 .3313 L
.30547 .33152 L
.30549 .33175 L
.30552 .332 L
.30555 .33226 L
.30559 .33254 L
.30563 .33284 L
.30567 .33315 L
.30572 .33347 L
.30578 .33382 L
.30584 .33419 L
.30591 .33458 L
.30599 .33499 L
.30608 .33542 L
.30618 .33588 L
.30629 .33636 L
.30642 .33687 L
.30655 .3374 L
.30671 .33797 L
.30688 .33856 L
.30708 .33919 L
.3073 .33984 L
.30754 .34053 L
.30781 .34125 L
.30811 .34201 L
.30845 .3428 L
.30882 .34363 L
.30924 .34449 L
.3097 .34538 L
.31021 .34631 L
.31077 .34728 L
.3114 .34827 L
.31209 .34929 L
.31284 .35034 L
.31368 .35141 L
.31459 .35249 L
.31558 .35359 L
.31667 .3547 L
.31785 .3558 L
.31912 .35689 L
.32049 .35797 L
.32197 .35902 L
.32355 .36002 L
.32522 .36098 L
.327 .36188 L
Mistroke
.32887 .3627 L
.33084 .36343 L
.33288 .36407 L
.33499 .3646 L
.33717 .36501 L
.3394 .36529 L
.34166 .36544 L
.34394 .36546 L
.34622 .36533 L
.34849 .36506 L
.35074 .36466 L
.35294 .36412 L
.35508 .36346 L
.35716 .36267 L
.35916 .36178 L
.36106 .36078 L
.36287 .3597 L
.36457 .35853 L
.36616 .35731 L
.36764 .35602 L
.36901 .35469 L
.37026 .35333 L
.3714 .35195 L
.37243 .35056 L
.37335 .34915 L
.37416 .34775 L
.37487 .34636 L
.37549 .34499 L
.376 .34363 L
.37643 .3423 L
.37676 .341 L
.37701 .33974 L
.37718 .33851 L
.37727 .33733 L
.37729 .3362 L
.37724 .33511 L
.37713 .33408 L
.37695 .3331 L
.37672 .33218 L
.37643 .33133 L
.3761 .33054 L
.37573 .32983 L
.37533 .32918 L
.3749 .32861 L
.37445 .32811 L
.37399 .32769 L
.37353 .32733 L
.37308 .32705 L
.37263 .32683 L
.37221 .32667 L
Mistroke
.37181 .32657 L
.37144 .32651 L
.37111 .32649 L
.37081 .32651 L
.37054 .32656 L
.37032 .32662 L
.37012 .3267 L
.36997 .32678 L
.36984 .32687 L
.36973 .32696 L
.36965 .32704 L
.36959 .32712 L
.36955 .32719 L
.36952 .32725 L
.36949 .32731 L
.36948 .32735 L
.36947 .32739 L
.36947 .32743 L
.36947 .32746 L
.36947 .32748 L
.36947 .3275 L
.36948 .32751 L
.36948 .32753 L
.36948 .32754 L
.36949 .32754 L
.36949 .32755 L
.36949 .32755 L
.36949 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
Mistroke
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0123649 0.97619 0.247887 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.369507 1.47696 0.327569 1.47696 [
[.07411 .31507 -9.6 -7.2 ]
[.07411 .31507 9.6 0 ]
[.22181 .31507 -9.6 -7.2 ]
[.22181 .31507 9.6 0 ]
[.5172 .31507 -7.2 -7.2 ]
[.5172 .31507 7.2 0 ]
[.6649 .31507 -7.2 -7.2 ]
[.6649 .31507 7.2 0 ]
[.81259 .31507 -7.2 -7.2 ]
[.81259 .31507 7.2 0 ]
[.96029 .31507 -7.2 -7.2 ]
[.96029 .31507 7.2 0 ]
[.35701 .03218 -19.2 -3.6 ]
[.35701 .03218 0 3.6 ]
[.35701 .10602 -24 -3.6 ]
[.35701 .10602 0 3.6 ]
[.35701 .17987 -19.2 -3.6 ]
[.35701 .17987 0 3.6 ]
[.35701 .25372 -24 -3.6 ]
[.35701 .25372 0 3.6 ]
[.35701 .40142 -19.2 -3.6 ]
[.35701 .40142 0 3.6 ]
[.35701 .47526 -14.4 -3.6 ]
[.35701 .47526 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .51933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07411 .32757 m
.07411 .33382 L
s
[(-0.2)] .07411 .31507 0 1 Mshowa
.22181 .32757 m
.22181 .33382 L
s
[(-0.1)] .22181 .31507 0 1 Mshowa
.5172 .32757 m
.5172 .33382 L
s
[(0.1)] .5172 .31507 0 1 Mshowa
.6649 .32757 m
.6649 .33382 L
s
[(0.2)] .6649 .31507 0 1 Mshowa
.81259 .32757 m
.81259 .33382 L
s
[(0.3)] .81259 .31507 0 1 Mshowa
.96029 .32757 m
.96029 .33382 L
s
[(0.4)] .96029 .31507 0 1 Mshowa
.125 Mabswid
.10365 .32757 m
.10365 .33132 L
s
.13319 .32757 m
.13319 .33132 L
s
.16273 .32757 m
.16273 .33132 L
s
.19227 .32757 m
.19227 .33132 L
s
.25135 .32757 m
.25135 .33132 L
s
.28089 .32757 m
.28089 .33132 L
s
.31043 .32757 m
.31043 .33132 L
s
.33997 .32757 m
.33997 .33132 L
s
.39905 .32757 m
.39905 .33132 L
s
.42859 .32757 m
.42859 .33132 L
s
.45812 .32757 m
.45812 .33132 L
s
.48766 .32757 m
.48766 .33132 L
s
.54674 .32757 m
.54674 .33132 L
s
.57628 .32757 m
.57628 .33132 L
s
.60582 .32757 m
.60582 .33132 L
s
.63536 .32757 m
.63536 .33132 L
s
.69444 .32757 m
.69444 .33132 L
s
.72398 .32757 m
.72398 .33132 L
s
.75352 .32757 m
.75352 .33132 L
s
.78306 .32757 m
.78306 .33132 L
s
.84213 .32757 m
.84213 .33132 L
s
.87167 .32757 m
.87167 .33132 L
s
.90121 .32757 m
.90121 .33132 L
s
.93075 .32757 m
.93075 .33132 L
s
.04458 .32757 m
.04458 .33132 L
s
.01504 .32757 m
.01504 .33132 L
s
.98983 .32757 m
.98983 .33132 L
s
.25 Mabswid
0 .32757 m
1 .32757 L
s
.36951 .03218 m
.37576 .03218 L
s
[(-0.2)] .35701 .03218 1 0 Mshowa
.36951 .10602 m
.37576 .10602 L
s
[(-0.15)] .35701 .10602 1 0 Mshowa
.36951 .17987 m
.37576 .17987 L
s
[(-0.1)] .35701 .17987 1 0 Mshowa
.36951 .25372 m
.37576 .25372 L
s
[(-0.05)] .35701 .25372 1 0 Mshowa
.36951 .40142 m
.37576 .40142 L
s
[(0.05)] .35701 .40142 1 0 Mshowa
.36951 .47526 m
.37576 .47526 L
s
[(0.1)] .35701 .47526 1 0 Mshowa
.125 Mabswid
.36951 .04695 m
.37326 .04695 L
s
.36951 .06172 m
.37326 .06172 L
s
.36951 .07649 m
.37326 .07649 L
s
.36951 .09126 m
.37326 .09126 L
s
.36951 .12079 m
.37326 .12079 L
s
.36951 .13556 m
.37326 .13556 L
s
.36951 .15033 m
.37326 .15033 L
s
.36951 .1651 m
.37326 .1651 L
s
.36951 .19464 m
.37326 .19464 L
s
.36951 .20941 m
.37326 .20941 L
s
.36951 .22418 m
.37326 .22418 L
s
.36951 .23895 m
.37326 .23895 L
s
.36951 .26849 m
.37326 .26849 L
s
.36951 .28326 m
.37326 .28326 L
s
.36951 .29803 m
.37326 .29803 L
s
.36951 .3128 m
.37326 .3128 L
s
.36951 .34234 m
.37326 .34234 L
s
.36951 .35711 m
.37326 .35711 L
s
.36951 .37188 m
.37326 .37188 L
s
.36951 .38665 m
.37326 .38665 L
s
.36951 .41619 m
.37326 .41619 L
s
.36951 .43096 m
.37326 .43096 L
s
.36951 .44573 m
.37326 .44573 L
s
.36951 .4605 m
.37326 .4605 L
s
.36951 .01741 m
.37326 .01741 L
s
.36951 .00264 m
.37326 .00264 L
s
.36951 .49003 m
.37326 .49003 L
s
.36951 .5048 m
.37326 .5048 L
s
.25 Mabswid
.36951 0 m
.36951 .51933 L
s
0 0 m
1 0 L
1 .51933 L
0 .51933 L
closepath
clip
newpath
.5 Mabswid
.51258 .32225 m
.51256 .32193 L
.51253 .3216 L
.5125 .32124 L
.51247 .32087 L
.51243 .32047 L
.51239 .32005 L
.51234 .3196 L
.51229 .31913 L
.51223 .31863 L
.51216 .3181 L
.51209 .31754 L
.51201 .31695 L
.51191 .31633 L
.51181 .31567 L
.51169 .31497 L
.51156 .31423 L
.51141 .31345 L
.51125 .31263 L
.51106 .31176 L
.51085 .31084 L
.51062 .30987 L
.51036 .30885 L
.51007 .30777 L
.50975 .30664 L
.50939 .30545 L
.50898 .3042 L
.50853 .30288 L
.50803 .3015 L
.50746 .30006 L
.50684 .29855 L
.50614 .29697 L
.50537 .29533 L
.50451 .29361 L
.50356 .29184 L
.50251 .28999 L
.50135 .28809 L
.50007 .28613 L
.49866 .28412 L
.49711 .28207 L
.49542 .27997 L
.49356 .27785 L
.49155 .27572 L
.48935 .27358 L
.48698 .27145 L
.48442 .26936 L
.48167 .26731 L
.47874 .26532 L
.47561 .26342 L
.47229 .26163 L
Mistroke
.4688 .25998 L
.46514 .25847 L
.46133 .25713 L
.45738 .25599 L
.45331 .25506 L
.44915 .25435 L
.44491 .25388 L
.44064 .25365 L
.43636 .25367 L
.43209 .25394 L
.42786 .25445 L
.42371 .2552 L
.41965 .25617 L
.41571 .25734 L
.41191 .25871 L
.40826 .26025 L
.40478 .26194 L
.40149 .26376 L
.39838 .26569 L
.39545 .26771 L
.39272 .26979 L
.39018 .27191 L
.38783 .27406 L
.38566 .27623 L
.38365 .27839 L
.38182 .28054 L
.38014 .28266 L
.37861 .28474 L
.37722 .28678 L
.37595 .28877 L
.37481 .2907 L
.37378 .29257 L
.37284 .29438 L
.372 .29613 L
.37125 .29781 L
.37058 .29943 L
.36997 .30098 L
.36943 .30247 L
.36895 .30389 L
.36853 .30525 L
.36815 .30656 L
.36781 .3078 L
.36752 .30899 L
.36727 .31012 L
.36705 .3112 L
.36686 .31223 L
.36669 .31321 L
.36656 .31414 L
.36645 .31503 L
.36636 .31588 L
Mistroke
.36629 .31669 L
.36624 .31745 L
.36621 .31819 L
.3662 .31888 L
.36621 .31954 L
.36623 .32016 L
.36626 .32075 L
.36631 .32131 L
.36637 .32184 L
.36644 .32234 L
.36652 .32281 L
.36661 .32325 L
.36671 .32366 L
.36682 .32404 L
.36693 .3244 L
.36705 .32473 L
.36717 .32503 L
.36729 .32531 L
.36742 .32557 L
.36755 .3258 L
.36767 .32601 L
.36779 .3262 L
.36791 .32637 L
.36803 .32652 L
.36814 .32666 L
.36825 .32678 L
.36835 .32688 L
.36845 .32698 L
.36854 .32706 L
.36862 .32713 L
.3687 .32719 L
.36878 .32725 L
.36885 .32729 L
.36891 .32733 L
.36897 .32737 L
.36902 .3274 L
.36907 .32742 L
.36911 .32745 L
.36915 .32746 L
.36919 .32748 L
.36922 .32749 L
.36925 .32751 L
.36928 .32751 L
.3693 .32752 L
.36932 .32753 L
.36934 .32754 L
.36936 .32754 L
.36937 .32755 L
.36939 .32755 L
.3694 .32755 L
Mistroke
.36941 .32755 L
.36942 .32756 L
.36943 .32756 L
.36944 .32756 L
.36945 .32756 L
.36945 .32756 L
.36946 .32756 L
.36946 .32756 L
.36947 .32757 L
.36947 .32757 L
.36948 .32757 L
.36948 .32757 L
.36948 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.271439 0.477324 0.506961 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.369507 1.47696 0.327569 1.47696 [
[.07411 .31507 -9.6 -7.2 ]
[.07411 .31507 9.6 0 ]
[.22181 .31507 -9.6 -7.2 ]
[.22181 .31507 9.6 0 ]
[.5172 .31507 -7.2 -7.2 ]
[.5172 .31507 7.2 0 ]
[.6649 .31507 -7.2 -7.2 ]
[.6649 .31507 7.2 0 ]
[.81259 .31507 -7.2 -7.2 ]
[.81259 .31507 7.2 0 ]
[.96029 .31507 -7.2 -7.2 ]
[.96029 .31507 7.2 0 ]
[.35701 .03218 -19.2 -3.6 ]
[.35701 .03218 0 3.6 ]
[.35701 .10602 -24 -3.6 ]
[.35701 .10602 0 3.6 ]
[.35701 .17987 -19.2 -3.6 ]
[.35701 .17987 0 3.6 ]
[.35701 .25372 -24 -3.6 ]
[.35701 .25372 0 3.6 ]
[.35701 .40142 -19.2 -3.6 ]
[.35701 .40142 0 3.6 ]
[.35701 .47526 -14.4 -3.6 ]
[.35701 .47526 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .51933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07411 .32757 m
.07411 .33382 L
s
[(-0.2)] .07411 .31507 0 1 Mshowa
.22181 .32757 m
.22181 .33382 L
s
[(-0.1)] .22181 .31507 0 1 Mshowa
.5172 .32757 m
.5172 .33382 L
s
[(0.1)] .5172 .31507 0 1 Mshowa
.6649 .32757 m
.6649 .33382 L
s
[(0.2)] .6649 .31507 0 1 Mshowa
.81259 .32757 m
.81259 .33382 L
s
[(0.3)] .81259 .31507 0 1 Mshowa
.96029 .32757 m
.96029 .33382 L
s
[(0.4)] .96029 .31507 0 1 Mshowa
.125 Mabswid
.10365 .32757 m
.10365 .33132 L
s
.13319 .32757 m
.13319 .33132 L
s
.16273 .32757 m
.16273 .33132 L
s
.19227 .32757 m
.19227 .33132 L
s
.25135 .32757 m
.25135 .33132 L
s
.28089 .32757 m
.28089 .33132 L
s
.31043 .32757 m
.31043 .33132 L
s
.33997 .32757 m
.33997 .33132 L
s
.39905 .32757 m
.39905 .33132 L
s
.42859 .32757 m
.42859 .33132 L
s
.45812 .32757 m
.45812 .33132 L
s
.48766 .32757 m
.48766 .33132 L
s
.54674 .32757 m
.54674 .33132 L
s
.57628 .32757 m
.57628 .33132 L
s
.60582 .32757 m
.60582 .33132 L
s
.63536 .32757 m
.63536 .33132 L
s
.69444 .32757 m
.69444 .33132 L
s
.72398 .32757 m
.72398 .33132 L
s
.75352 .32757 m
.75352 .33132 L
s
.78306 .32757 m
.78306 .33132 L
s
.84213 .32757 m
.84213 .33132 L
s
.87167 .32757 m
.87167 .33132 L
s
.90121 .32757 m
.90121 .33132 L
s
.93075 .32757 m
.93075 .33132 L
s
.04458 .32757 m
.04458 .33132 L
s
.01504 .32757 m
.01504 .33132 L
s
.98983 .32757 m
.98983 .33132 L
s
.25 Mabswid
0 .32757 m
1 .32757 L
s
.36951 .03218 m
.37576 .03218 L
s
[(-0.2)] .35701 .03218 1 0 Mshowa
.36951 .10602 m
.37576 .10602 L
s
[(-0.15)] .35701 .10602 1 0 Mshowa
.36951 .17987 m
.37576 .17987 L
s
[(-0.1)] .35701 .17987 1 0 Mshowa
.36951 .25372 m
.37576 .25372 L
s
[(-0.05)] .35701 .25372 1 0 Mshowa
.36951 .40142 m
.37576 .40142 L
s
[(0.05)] .35701 .40142 1 0 Mshowa
.36951 .47526 m
.37576 .47526 L
s
[(0.1)] .35701 .47526 1 0 Mshowa
.125 Mabswid
.36951 .04695 m
.37326 .04695 L
s
.36951 .06172 m
.37326 .06172 L
s
.36951 .07649 m
.37326 .07649 L
s
.36951 .09126 m
.37326 .09126 L
s
.36951 .12079 m
.37326 .12079 L
s
.36951 .13556 m
.37326 .13556 L
s
.36951 .15033 m
.37326 .15033 L
s
.36951 .1651 m
.37326 .1651 L
s
.36951 .19464 m
.37326 .19464 L
s
.36951 .20941 m
.37326 .20941 L
s
.36951 .22418 m
.37326 .22418 L
s
.36951 .23895 m
.37326 .23895 L
s
.36951 .26849 m
.37326 .26849 L
s
.36951 .28326 m
.37326 .28326 L
s
.36951 .29803 m
.37326 .29803 L
s
.36951 .3128 m
.37326 .3128 L
s
.36951 .34234 m
.37326 .34234 L
s
.36951 .35711 m
.37326 .35711 L
s
.36951 .37188 m
.37326 .37188 L
s
.36951 .38665 m
.37326 .38665 L
s
.36951 .41619 m
.37326 .41619 L
s
.36951 .43096 m
.37326 .43096 L
s
.36951 .44573 m
.37326 .44573 L
s
.36951 .4605 m
.37326 .4605 L
s
.36951 .01741 m
.37326 .01741 L
s
.36951 .00264 m
.37326 .00264 L
s
.36951 .49003 m
.37326 .49003 L
s
.36951 .5048 m
.37326 .5048 L
s
.25 Mabswid
.36951 0 m
.36951 .51933 L
s
0 0 m
1 0 L
1 .51933 L
0 .51933 L
closepath
clip
newpath
.5 Mabswid
.00906 .39282 m
.01045 .39644 L
.012 .40023 L
.01372 .40419 L
.01563 .40832 L
.01776 .41261 L
.02011 .41708 L
.02272 .42171 L
.0256 .42649 L
.02878 .43142 L
.03228 .43648 L
.03612 .44166 L
.04033 .44694 L
.04494 .45229 L
.04996 .45769 L
.05542 .4631 L
.06132 .46849 L
.0677 .47381 L
.07455 .47903 L
.08189 .48409 L
.0897 .48893 L
.09798 .49352 L
.10672 .49779 L
.11589 .50168 L
.12546 .50515 L
.13538 .50814 L
.1456 .51061 L
.15608 .51252 L
.16673 .51385 L
.17751 .51456 L
.18833 .51464 L
.19913 .51411 L
.20983 .51295 L
.22036 .5112 L
.23066 .50888 L
.24067 .50603 L
.25034 .50269 L
.25962 .49891 L
.26849 .49474 L
.2769 .49024 L
.28485 .48546 L
.29232 .48045 L
.2993 .47527 L
.30581 .46997 L
.31185 .4646 L
.31743 .45919 L
.32257 .45378 L
.32729 .44841 L
.33161 .44311 L
.33556 .4379 L
Mistroke
.33915 .4328 L
.34241 .42784 L
.34538 .42301 L
.34806 .41833 L
.35048 .41382 L
.35267 .40947 L
.35464 .40529 L
.35641 .40129 L
.35801 .39745 L
.35944 .39378 L
.36073 .39027 L
.36188 .38693 L
.36291 .38375 L
.36384 .38072 L
.36467 .37784 L
.36541 .3751 L
.36607 .3725 L
.36666 .37004 L
.36719 .3677 L
.36766 .36549 L
.36808 .36339 L
.36846 .3614 L
.3688 .35952 L
.3691 .35773 L
.36936 .35605 L
.3696 .35445 L
.36981 .35295 L
.37 .35152 L
.37017 .35017 L
.37032 .34889 L
.37045 .34769 L
.37057 .34655 L
.37068 .34547 L
.37077 .34445 L
.37086 .34348 L
.37093 .34257 L
.371 .34171 L
.37105 .34089 L
.37111 .34012 L
.37115 .33939 L
.37119 .3387 L
.37123 .33805 L
.37126 .33743 L
.37128 .33685 L
.3713 .33629 L
.37132 .33577 L
.37134 .33527 L
.37135 .3348 L
.37136 .33435 L
.37137 .33393 L
Mistroke
.37138 .33353 L
.37138 .33314 L
.37138 .33278 L
.37138 .33243 L
.37137 .3321 L
.37137 .33179 L
.37136 .33149 L
.37134 .33121 L
.37133 .33094 L
.37131 .33068 L
.37129 .33043 L
.37127 .33019 L
.37125 .32997 L
.37122 .32975 L
.37119 .32955 L
.37115 .32935 L
.37111 .32917 L
.37107 .32899 L
.37102 .32882 L
.37097 .32866 L
.37091 .32851 L
.37086 .32837 L
.37079 .32823 L
.37073 .32811 L
.37066 .328 L
.37059 .32789 L
.37051 .3278 L
.37043 .32771 L
.37036 .32764 L
.37028 .32758 L
.3702 .32752 L
.37013 .32748 L
.37005 .32744 L
.36998 .32742 L
.36992 .3274 L
.36985 .32739 L
.3698 .32739 L
.36975 .32739 L
.3697 .32739 L
.36966 .3274 L
.36963 .32742 L
.3696 .32743 L
.36957 .32744 L
.36955 .32746 L
.36954 .32747 L
.36953 .32749 L
.36952 .3275 L
.36951 .32751 L
.36951 .32752 L
.3695 .32753 L
Mistroke
.3695 .32754 L
.3695 .32754 L
.3695 .32755 L
.3695 .32755 L
.3695 .32755 L
.3695 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32756 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.271439 0.97619 0.506961 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.369507 1.47696 0.327569 1.47696 [
[.07411 .31507 -9.6 -7.2 ]
[.07411 .31507 9.6 0 ]
[.22181 .31507 -9.6 -7.2 ]
[.22181 .31507 9.6 0 ]
[.5172 .31507 -7.2 -7.2 ]
[.5172 .31507 7.2 0 ]
[.6649 .31507 -7.2 -7.2 ]
[.6649 .31507 7.2 0 ]
[.81259 .31507 -7.2 -7.2 ]
[.81259 .31507 7.2 0 ]
[.96029 .31507 -7.2 -7.2 ]
[.96029 .31507 7.2 0 ]
[.35701 .03218 -19.2 -3.6 ]
[.35701 .03218 0 3.6 ]
[.35701 .10602 -24 -3.6 ]
[.35701 .10602 0 3.6 ]
[.35701 .17987 -19.2 -3.6 ]
[.35701 .17987 0 3.6 ]
[.35701 .25372 -24 -3.6 ]
[.35701 .25372 0 3.6 ]
[.35701 .40142 -19.2 -3.6 ]
[.35701 .40142 0 3.6 ]
[.35701 .47526 -14.4 -3.6 ]
[.35701 .47526 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .51933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07411 .32757 m
.07411 .33382 L
s
[(-0.2)] .07411 .31507 0 1 Mshowa
.22181 .32757 m
.22181 .33382 L
s
[(-0.1)] .22181 .31507 0 1 Mshowa
.5172 .32757 m
.5172 .33382 L
s
[(0.1)] .5172 .31507 0 1 Mshowa
.6649 .32757 m
.6649 .33382 L
s
[(0.2)] .6649 .31507 0 1 Mshowa
.81259 .32757 m
.81259 .33382 L
s
[(0.3)] .81259 .31507 0 1 Mshowa
.96029 .32757 m
.96029 .33382 L
s
[(0.4)] .96029 .31507 0 1 Mshowa
.125 Mabswid
.10365 .32757 m
.10365 .33132 L
s
.13319 .32757 m
.13319 .33132 L
s
.16273 .32757 m
.16273 .33132 L
s
.19227 .32757 m
.19227 .33132 L
s
.25135 .32757 m
.25135 .33132 L
s
.28089 .32757 m
.28089 .33132 L
s
.31043 .32757 m
.31043 .33132 L
s
.33997 .32757 m
.33997 .33132 L
s
.39905 .32757 m
.39905 .33132 L
s
.42859 .32757 m
.42859 .33132 L
s
.45812 .32757 m
.45812 .33132 L
s
.48766 .32757 m
.48766 .33132 L
s
.54674 .32757 m
.54674 .33132 L
s
.57628 .32757 m
.57628 .33132 L
s
.60582 .32757 m
.60582 .33132 L
s
.63536 .32757 m
.63536 .33132 L
s
.69444 .32757 m
.69444 .33132 L
s
.72398 .32757 m
.72398 .33132 L
s
.75352 .32757 m
.75352 .33132 L
s
.78306 .32757 m
.78306 .33132 L
s
.84213 .32757 m
.84213 .33132 L
s
.87167 .32757 m
.87167 .33132 L
s
.90121 .32757 m
.90121 .33132 L
s
.93075 .32757 m
.93075 .33132 L
s
.04458 .32757 m
.04458 .33132 L
s
.01504 .32757 m
.01504 .33132 L
s
.98983 .32757 m
.98983 .33132 L
s
.25 Mabswid
0 .32757 m
1 .32757 L
s
.36951 .03218 m
.37576 .03218 L
s
[(-0.2)] .35701 .03218 1 0 Mshowa
.36951 .10602 m
.37576 .10602 L
s
[(-0.15)] .35701 .10602 1 0 Mshowa
.36951 .17987 m
.37576 .17987 L
s
[(-0.1)] .35701 .17987 1 0 Mshowa
.36951 .25372 m
.37576 .25372 L
s
[(-0.05)] .35701 .25372 1 0 Mshowa
.36951 .40142 m
.37576 .40142 L
s
[(0.05)] .35701 .40142 1 0 Mshowa
.36951 .47526 m
.37576 .47526 L
s
[(0.1)] .35701 .47526 1 0 Mshowa
.125 Mabswid
.36951 .04695 m
.37326 .04695 L
s
.36951 .06172 m
.37326 .06172 L
s
.36951 .07649 m
.37326 .07649 L
s
.36951 .09126 m
.37326 .09126 L
s
.36951 .12079 m
.37326 .12079 L
s
.36951 .13556 m
.37326 .13556 L
s
.36951 .15033 m
.37326 .15033 L
s
.36951 .1651 m
.37326 .1651 L
s
.36951 .19464 m
.37326 .19464 L
s
.36951 .20941 m
.37326 .20941 L
s
.36951 .22418 m
.37326 .22418 L
s
.36951 .23895 m
.37326 .23895 L
s
.36951 .26849 m
.37326 .26849 L
s
.36951 .28326 m
.37326 .28326 L
s
.36951 .29803 m
.37326 .29803 L
s
.36951 .3128 m
.37326 .3128 L
s
.36951 .34234 m
.37326 .34234 L
s
.36951 .35711 m
.37326 .35711 L
s
.36951 .37188 m
.37326 .37188 L
s
.36951 .38665 m
.37326 .38665 L
s
.36951 .41619 m
.37326 .41619 L
s
.36951 .43096 m
.37326 .43096 L
s
.36951 .44573 m
.37326 .44573 L
s
.36951 .4605 m
.37326 .4605 L
s
.36951 .01741 m
.37326 .01741 L
s
.36951 .00264 m
.37326 .00264 L
s
.36951 .49003 m
.37326 .49003 L
s
.36951 .5048 m
.37326 .5048 L
s
.25 Mabswid
.36951 0 m
.36951 .51933 L
s
0 0 m
1 0 L
1 .51933 L
0 .51933 L
closepath
clip
newpath
.5 Mabswid
.98453 .2161 m
.98216 .20992 L
.97951 .20344 L
.97657 .19668 L
.9733 .18963 L
.96967 .18228 L
.96565 .17465 L
.9612 .16675 L
.95628 .15858 L
.95085 .15016 L
.94487 .14151 L
.9383 .13266 L
.9311 .12365 L
.92323 .1145 L
.91466 .10528 L
.90534 .09604 L
.89524 .08684 L
.88435 .07774 L
.87265 .06883 L
.86012 .06019 L
.84677 .05191 L
.83262 .04407 L
.81769 .03678 L
.80202 .03013 L
.78568 .02421 L
.76874 .0191 L
.75127 .01487 L
.73337 .01161 L
.71517 .00935 L
.69676 .00814 L
.67827 .00799 L
.65982 .00891 L
.64155 .01088 L
.62355 .01387 L
.60596 .01783 L
.58885 .02271 L
.57234 .02841 L
.55648 .03487 L
.54134 .042 L
.52696 .04969 L
.51339 .05786 L
.50063 .06642 L
.48869 .07526 L
.47757 .08432 L
.46726 .09351 L
.45772 .10275 L
.44894 .11199 L
.44088 .12116 L
.4335 .13022 L
.42676 .13913 L
Mistroke
.42062 .14784 L
.41504 .15633 L
.40998 .16458 L
.4054 .17257 L
.40126 .18028 L
.39752 .18771 L
.39416 .19486 L
.39113 .20171 L
.3884 .20827 L
.38596 .21455 L
.38376 .22054 L
.38179 .22625 L
.38003 .2317 L
.37845 .23688 L
.37703 .2418 L
.37577 .24649 L
.37464 .25093 L
.37363 .25515 L
.37273 .25915 L
.37192 .26294 L
.3712 .26654 L
.37056 .26994 L
.36999 .27317 L
.36948 .27622 L
.36903 .27911 L
.36862 .28185 L
.36826 .28444 L
.36794 .28689 L
.36766 .28921 L
.36741 .2914 L
.36719 .29348 L
.36699 .29544 L
.36682 .2973 L
.36666 .29906 L
.36653 .30073 L
.36641 .3023 L
.36631 .3038 L
.36622 .30521 L
.36615 .30655 L
.36608 .30782 L
.36603 .30902 L
.36599 .31016 L
.36596 .31124 L
.36593 .31226 L
.36592 .31323 L
.36591 .31415 L
.36591 .31503 L
.36592 .31586 L
.36594 .31665 L
.36596 .31739 L
Mistroke
.36599 .3181 L
.36603 .31878 L
.36608 .31942 L
.36613 .32003 L
.36619 .3206 L
.36626 .32115 L
.36633 .32166 L
.36642 .32215 L
.3665 .32261 L
.3666 .32304 L
.3667 .32345 L
.3668 .32383 L
.36691 .32419 L
.36702 .32452 L
.36714 .32483 L
.36725 .32511 L
.36737 .32538 L
.36749 .32562 L
.36761 .32584 L
.36773 .32604 L
.36785 .32622 L
.36796 .32638 L
.36807 .32653 L
.36818 .32666 L
.36828 .32678 L
.36838 .32688 L
.36847 .32698 L
.36856 .32706 L
.36864 .32713 L
.36872 .32719 L
.36879 .32724 L
.36886 .32729 L
.36892 .32733 L
.36897 .32737 L
.36903 .3274 L
.36907 .32742 L
.36912 .32744 L
.36916 .32746 L
.36919 .32748 L
.36922 .32749 L
.36925 .3275 L
.36928 .32751 L
.3693 .32752 L
.36932 .32753 L
.36934 .32754 L
.36936 .32754 L
.36938 .32755 L
.36939 .32755 L
.3694 .32755 L
.36941 .32755 L
Mistroke
.36942 .32756 L
.36943 .32756 L
.36944 .32756 L
.36945 .32756 L
.36945 .32756 L
.36946 .32756 L
.36946 .32756 L
.36947 .32757 L
.36947 .32757 L
.36948 .32757 L
.36948 .32757 L
.36948 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.36949 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.3695 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
.36951 .32757 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{367, 190.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005_0000_R000`400?l00000o`00003oool0001_
o`00007ooooo00000ol0003oooooooooo`3oooooof_ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooom[ooooo`7o00000Oooool00003o`000?oooooooooo0?ooooooJoooool1o`00007ooooo
00000ol0003oooooooooo`3oooooof_ooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001oooo
o`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`00
0?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`2Tooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool4o`000004ooooool0003oooooo`0000So
oooo00?o0000ooooooooool00_ooool2o`0009oooooo1?l000001?oooooo0000ooooool00008oooo
o`03o`000?oooooooooo00;ooooo0_l0001_ooooo`7o00000Oooool00003o`000?oooooooooo03?o
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo00000:Gooooo00?o0000oooo
ool000002Oooool01Ol0003ooooooooooooooooo0000073ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0<oooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool00000YOooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool00000L?ooool1o`00007ooooo0000
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`03o`000?oooooo
oooo0:Cooooo00?o0000ooooooooool01_ooool3o`0000?ooooo00?o0000ooooooooool0K_ooool1
o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000oooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?o
oooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo0000
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1
o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000oooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?o
oooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`?o00000oooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002oooo
o`?o00000oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo02Wo
oooo1?l000001?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooooooo0_l0002Jooooo`Co000000Coooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o0000Koooool1o`00007ooooo00000ol0003ooooooooo
o`0^ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`00
0?oooooooooo09kooooo00?o0000ooooool000002?ooool01?l0003oooooooooooooool3o`0000?o
oooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo09ko
oooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Ko
oooo0_l00003ooooo`?o00000oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Ko
oooo0_l00003ooooo`?o00000oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003ooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0/oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo04?o
oooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`00
0?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003ooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool0Y?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo02kooooo1?l000001?oooooo0000ooooool00008ooooo`03o`00
0?oooooooooo00;ooooo0_l0002Oooooo`Co000000Coooooo`000?oooooo00002?ooool00ol0003o
ooooooooo`02ooooo`;o0000Koooool1o`00007ooooo00000ol0003oooooooooo`0cooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Sooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1^ooooo`7o0000
0Oooool00003o`000?oooooooooo03?ooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo00Kooooo0_l00004ooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001oooo
o`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`00
0?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003ooooooooo
o`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001oooo
o`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`?o00000oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo02Wo
oooo1?l000001?oooooo0000ooooool00007ooooo`03o`000?oooooo000000Cooooo00Co0000oooo
oooooooooooo0_l0002Jooooo`Co000000Coooooo`000?oooooo00001oooool00ol0003oooooo`00
0004ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`1Sooooo`7o0000
0Oooool00003o`000?oooooooooo02kooooo00?o0000ooooool000001oooool00ol0003oooooo`00
0002ooooo`?o00000oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooooooool01?ooool4o`000003ooooool0
003o000000;o0000HOooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo09kooooo00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooooooo0ol00009ooooo`?o0000G_ooool1o`00007ooooo0000
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol0
0003ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ooooool3o`0000?ooooo00?o0000ooooooooool00_l0000=ooooo`;o0000GOooool1o`00007ooooo
00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00Co0000ooooool0003o0000
3oooool2o`0005cooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003ooooooooo
o`2cooooo`?o00004Oooool2o`0005_ooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00004?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0
000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000@ooooo`;o0000
4Oooool01_l0003oooooo`000?l0003oooooo`0000?ooooo0ol0000<ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooooooo0ol0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo1?l00000
1?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00Gooooo1?l000001?oooooo0000oooo
ool00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
o`000007ooooo`?o00005Oooool4o`000004ooooool0003oooooo`0000Sooooo00?o0000oooooooo
ool01Oooool4o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooooooool03oooool2o`00
013ooooo00Go0000ooooool0003oooooo`000006ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`000007ooooo`?o00002Oooool1o`00007ooooo00000ol0
003oooooooooo`0>ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000001[ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooo0000ooooo`;o00001Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool00ol0003oooooo`000009
ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo0_l0000Jooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo
00kooooo0_l0000Aooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000002?ooool2o`00
00Wooooo0Ol00001ooooo`0000?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`?o
00003?ooool00ol0003oooooooooo`06ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo0ol0000<ooooo`03
o`000?oooooooooo00Kooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`06ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`;o
00004?ooool2o`0001;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00003Oooool00ol0
003oooooooooo`06ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`?o00003Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0@oooool00ol0003oooooooooo`2booooo`;o00005_ooool00ol0003oooooooooo`1Gooooo`7o
00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/_ooool2o`0001Kooooo
00?o0000ooooooooool0Eoooool1o`00007ooooo00000ol0003oooooooooo`06ooooojKo00004?oo
oonVo`0000Sooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool2o`0001Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool00003o`000?oooooooooo
03Sooooo0_l00009ooooo`;o0000]?ooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003
o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool2o`000;Cooooo00?o0000oooooooo
ool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0iooooo`;o00001oooool2o`000;Gooooo
00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0kooooo`;o00001?oo
ool3o`000;Gooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0l
ooooo`Go00000_ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000
ooooooooool0;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003ooooo
ooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo02kooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`000004ooooo`04o`000?ooooooooooooooo`;o0000Woooool00ol0003ooooo
o`000007ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooooooo0_l0001_ooooo`7o
00000Oooool00003o`000?oooooooooo02kooooo00?o0000ooooool000001oooool00ol0003ooooo
o`000002ooooo`?o00000oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo000000Oooooo
00?o0000ooooool000000_ooool3o`0000?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`0^ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09kooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000
ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03
o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo
00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000
ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool0K_oo
ool1o`00007ooooo00000ol0003oooooooooo`0cooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool00_ooool2o`000:Cooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02
ooooo`;o0000Koooool1o`00007ooooo00000ol0003oooooooooo`0cooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003
o`000?oooooooooo03?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0:?ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`06ooooo`;o00001?ooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Kooooo
0_l00004ooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000
ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001
ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo
06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooom[ooooo`7o0000
0Oooool00003o`000?oooooooooo0?ooooooJoooool1o`00007ooooo00000ol0003oooooooooo`3o
ooooof_ooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooom[ooooo`7o00000Oooool00003
o`000?oooooooooo0?ooooooJoooool1o`00007ooooo00000ol0003oooooooooo`3oooooof_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooom[ooooo`7o00000Oooool00003o`000?oooooo
oooo0?ooooooJoooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03
o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool09_oooolFo`0003;ooooo
0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oo
oooooooo02?ooooo0ol0000Fooooo`Go0000;Oooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool08?ooool3o`0001kooooo0ol0000Z
ooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`0Mooooo`?o00009?oo
ool3o`0002Oooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool4o`000004ooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool00_ooool2o`0009oooooo1?l000001?oooooo0000oooo
ool00008ooooo`03o`000?oooooooooo00;ooooo0_l0000Looooo`;o0000:_ooool2o`0002Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0<oooool00ol0003oooooo`000009ooooo`05o`000?oo
ooooooooooooool00000YOooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool0
00006_ooool3o`0002kooooo00?o0000ooooooooool08_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0cooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00002Uooooo`03
o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000<_ooool00ol0
003oooooooooo`0Qooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo00?o0000oooooooo
ool01_ooool3o`0000?ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`06ooooo`?o
00000oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo0ol0000Pooooo`7o
00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003ooooo
ooooo`0Cooooo`;o0000>Oooool00ol0003oooooooooo`0Mooooo`7o00000Oooool00003o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool07?ooool1o`00007ooooo00000ol0003oooooooooo`13
ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0l
ooooo`;o00007?ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01Wooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Iooooo`7o
00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04;ooooo0_l0000Iooooo`7o00000Oooool00003o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0<ooooo`;o0000Aooo
ool00ol0003oooooooooo`0Fooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooooooool3o`0000;ooooo0ol00003ooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000;ooooo
0ol00003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0Eooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1?l000001?oooooo0000oooo
ool00008ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0002Jooooo`Co
000000Coooooo`000?oooooo00002?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00003?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo0Ol00001
ooooo`0000?o0000ooooooooool0;_ooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
ooooo`?o00000oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0_l0001=ooooo`03o`000?oo
oooooooo01?ooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool00ol0003oooooo`000008
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Cooooo`7o00000Oooool00003o`000?oo
oooooooo02oooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0ol00003ooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool01_ooool2o`0000?ooooo0ol00003ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Booooo`7o00000Ooo
ool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool04Oooool1o`00007ooooo00000ol0
003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo013ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0?ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo
00?o0000ooooooooool0/oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool03_ooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2c
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0>
ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool03Oooool1o`00
007ooooo00000ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0ol00003ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool4o`00
0004ooooool0003oooooo`0000Sooooo00?o0000ooooooooool00_ooool2o`0009oooooo1?l00000
1?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool02oooool1o`00007ooooo00000ol0003oooooooooo`0c
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2S
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000005kooooo00?o0000ooooooooool02oooool1o`00007ooooo00000ol0003oooooooooo`0c
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2S
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000005kooooo00?o0000ooooooooool02oooool1o`00007ooooo00000ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooooooool01_ooool2o`0000Cooooo00Co0000oooooooooooo0000H?ooool00ol0003ooooooooo
o`0:ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool0
1?l0003oooooooooool0001Pooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0@oooool00ol0003oooooooooo`2cooooo`04o`000?ooooooooooo`00067ooooo00?o
0000ooooooooool02Oooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo0;?ooooo00?o0000ooooool00000H_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool0
0003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool00ol0003oooooo`00001^oooo
o`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool3o`0006ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`;o0000
Koooool1o`00007ooooo00000ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;?ooooo0_l0
001_ooooo`7o00000Oooool00003o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ooooool3o`0000?ooooo0_l0001_ooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1?l0
00001?oooooo0000ooooool00007ooooo`03o`000?oooooo000000Cooooo00Co0000oooooooooooo
oooo0_l0002Jooooo`Co000000Coooooo`000?oooooo00001oooool00ol0003oooooo`000004oooo
o`04o`000?ooooooooooooooo`;o0000Koooool1o`00007ooooo00000ol0003oooooooooo`0^oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool3o`0000?ooooo00?o0000oooo
ooooool0W_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo0ol00003oooo
o`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0;_ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0
;oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00003oooo
o`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool00ol0003o
ooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00004?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000=ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooooooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0ol0000<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000?oooo
o`;o00004_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00003?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooooooo`?o00003Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool1o`00007ooooo00000ol0003ooooooooo
o`09ooooo`Co000000Coooooo`000?oooooo00002?ooool00ol0003oooooooooo`05ooooo`Co0000
00Coooooo`000?oooooo00002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool02_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000001oooool3o`0001Gooooo1?l000001?oooooo0000ooooool00008oooo
o`03o`000?oooooooooo00Gooooo1?l000001?oooooo0000ooooool00008ooooo`03o`000?oooooo
oooo00kooooo0_l0000Aooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000002Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Oooooo0ol00009ooooo`7o00000Oooool0
0003o`000?oooooooooo00kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool02oooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooool000006_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0>oooo
o`;o00004Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Wooooo0Ol00001oooo
o`0000?o0000ooooooooool03_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002?ooool2o`0001[ooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03_ooool2o`00017o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000002?ooool2o`0000Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
3oooool00ol0003oooooooooo`06ooooo`?o00003?ooool00ol0003oooooooooo`06ooooo`;o0000
4Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo0_l0000>ooooo`03o`00
0?oooooooooo00Kooooo0ol0000<ooooo`03o`000?oooooooooo00Kooooo0ol0000<ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`?o0000
3?ooool00ol0003oooooooooo`06ooooo`;o00004?ooool2o`0001;ooooo00?o0000ooooooooool0
1_ooool2o`0000gooooo00?o0000ooooooooool01_ooool3o`0000cooooo00?o0000ooooooooool0
1_ooool3o`0000gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`7o0000
0Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/_ooool2o`00073ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2booooo`;o0000L?ooool1
o`00007ooooo00000ol0003oooooooooo`06ooooojKo00004?oooonVo`0000Sooooo0Ol00001oooo
o`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`0000?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001oooo
o`0000?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06ko
oooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool2o`000;Gooooo00?o0000ooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`;o0000]Oooool00ol0003ooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo0_l0002eooooo`03o`000?oooooo
oooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool2o`000;Gooooo00?o0000oooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`12ooooo`;o0000]Oooool00ol0003o
ooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo047ooooo00?o0000ooooool00000
]Oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol000001?oooooo0000ooooool0002Qooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000oooo
ooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`;o00009Oooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000000Cooooo0ol000000ooooooo0000o`00002Oooooo`03
o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool01?l0003oooooooooooooool2o`00
06oooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool4o`0000;ooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo0ol00003ooooo`03
o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool2o`0002Cooooo
00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000o`0000;o
oooo00?o0000ooooooooool0W_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Oo
oooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo06kooooo0Ol00001oooo
o`0000?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`05o`000?oooooooooooooo
ool00000]Oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo00[o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;?o
oooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02oooooo0_l00004ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0
K_ooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol0
0001ooooo`0000?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`1^ooooo`7o00000Oooool0
0003o`000?oooooooooo00gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool0
3oooool2o`0002Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2cooooo`03o`00
0?oooooooooo06kooooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Pooooo`04o`000?ooooooooooooooo`;o00000oooool3o`0000?ooooo00?o0000ooooooooool0
Y?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003o
ooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooo`000002o`0000Kooooo00?o0000ooooooooool00_ooool2o`000:Cooooo
00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`;o0000Koooool1o`00007ooooo
00000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo0ol00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Xoooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0D
ooooo`;o00007Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Xoooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0K_ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`?o00005oooool3o`00
0003ooooool0003ooooo00Oooooo0_l00004ooooo`03o`000?oooooooooo0:Cooooo00?o0000oooo
ooooool01_ooool2o`0000Cooooo00?o0000ooooooooool0K_ooool1o`00007ooooo00000ol0003o
ooooooooo`0Iooooo`?o00004_ooool2o`0001?ooooo00?o0000ooooooooool0/oooool00ol0003o
ooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo01cooooo0ol0000:ooooo`Go0000
5Oooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo06kooooo0Ol00001ooooo`0000?o
0000ooooooooool07oooool:o`0001[ooooo00?o0000ooooooooool0/oooool00ol0003ooooooooo
o`1^ooooo`7o00000Oooool00003o`000?oooooooooo04?ooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`1^ooooo`7o00000Oooool00003o`000?oooooooooo0?ooooooJoooool1o`00
007ooooo00000ol0003oooooooooo`3oooooof_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooom[ooooo`7o00000Oooool00?oo0000Kol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 366}, {189.562, 0}} -> {-0.0528481, -0.0259718, \
0.00575327, 0.00575327}, {{9.1875, 174.688}, {185, 99.0625}} -> {-0.28792, \
-0.241201, 0.00410731, 0.00410731}, {{191.25, 356.812}, {185, 99.0625}} -> \
{-1.0354, -0.241124, 0.00410569, 0.00410569}, {{9.1875, 174.688}, {90.4375, \
4.5}} -> {-0.28792, -0.629598, 0.00410731, 0.00410731}, {{191.25, 356.812}, \
{90.4375, 4.5}} -> {-1.0354, -0.629368, 0.00410569, 0.00410569}},
  CellTags->"2.5"]
}, Open  ]],

Cell[TextData[{
  "The Nyquist array suggests that the four element Nyquist plots would \
correspond to stable closed-loop subsystems, if a gain of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " is applied to element (1, 1) and element (2, 1) before closing the \
feedback loops with unity negative feedback."
}], "Text",
  CellTags->"2.5"],

Cell[TextData[{
  "This compensator applies a gain of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " to element (1, 1)."
}], "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(comp\  = \ TransferFunction[s, {{\(-1\), 0}, {0, 1}}]\)], "Input",
  CellLabel->"In[33]:=",
  CellTags->"2.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(-1\), "0"},
                    {"0", "1"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[33]=",
  CellTags->"2.5"]
}, Open  ]],

Cell["This is the resulting forward-path transfer-function matrix.", \
"MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fp\  = \ SeriesConnect[comp, tf]\)], "Input",
  CellLabel->"In[34]:=",
  CellTags->"2.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(0.252`\/\(\((3.3`\ \[ScriptS] + 1)\)\^3\ \((1800\ \
\[ScriptS] + 1)\)\)\), \(0.43`\/\(\((12\ \[ScriptS] + 
                                1)\)\ \((1800\ \[ScriptS] + 1)\)\)\)},
                    {\(0.0435`\/\(\((25.3`\ \[ScriptS] + 1)\)\^3\ \((360\ \
\[ScriptS] + 1)\)\)\), \(0.097`\/\(\((12\ \[ScriptS] + 
                                1)\)\ \((360\ \[ScriptS] + 1)\)\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[34]=",
  CellTags->"2.5"]
}, Open  ]],

Cell["\<\
The Gershgorin circles superimposed on the diagonal elements of the \
Nyquist array show the interaction present in the system over the bandwidth \
of interest.\
\>", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[fp, 
        GershgorinCircles \[Rule] ColumnDominance];\)\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->"2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.391 1.12522 0.504055 1.12522 [
[.16596 .49155 -9.6 -7.2 ]
[.16596 .49155 9.6 0 ]
[.61604 .49155 -7.2 -7.2 ]
[.61604 .49155 7.2 0 ]
[.84109 .49155 -7.2 -7.2 ]
[.84109 .49155 7.2 0 ]
[.3785 .05397 -19.2 -3.6 ]
[.3785 .05397 0 3.6 ]
[.3785 .27901 -19.2 -3.6 ]
[.3785 .27901 0 3.6 ]
[.3785 .7291 -14.4 -3.6 ]
[.3785 .7291 0 3.6 ]
[.3785 .95414 -14.4 -3.6 ]
[.3785 .95414 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16596 .50405 m
.16596 .5103 L
s
[(-0.2)] .16596 .49155 0 1 Mshowa
.61604 .50405 m
.61604 .5103 L
s
[(0.2)] .61604 .49155 0 1 Mshowa
.84109 .50405 m
.84109 .5103 L
s
[(0.4)] .84109 .49155 0 1 Mshowa
.125 Mabswid
.22222 .50405 m
.22222 .5078 L
s
.27848 .50405 m
.27848 .5078 L
s
.33474 .50405 m
.33474 .5078 L
s
.44726 .50405 m
.44726 .5078 L
s
.50352 .50405 m
.50352 .5078 L
s
.55978 .50405 m
.55978 .5078 L
s
.6723 .50405 m
.6723 .5078 L
s
.72857 .50405 m
.72857 .5078 L
s
.78483 .50405 m
.78483 .5078 L
s
.1097 .50405 m
.1097 .5078 L
s
.05343 .50405 m
.05343 .5078 L
s
.89735 .50405 m
.89735 .5078 L
s
.95361 .50405 m
.95361 .5078 L
s
.25 Mabswid
0 .50405 m
1 .50405 L
s
.391 .05397 m
.39725 .05397 L
s
[(-0.4)] .3785 .05397 1 0 Mshowa
.391 .27901 m
.39725 .27901 L
s
[(-0.2)] .3785 .27901 1 0 Mshowa
.391 .7291 m
.39725 .7291 L
s
[(0.2)] .3785 .7291 1 0 Mshowa
.391 .95414 m
.39725 .95414 L
s
[(0.4)] .3785 .95414 1 0 Mshowa
.125 Mabswid
.391 .11023 m
.39475 .11023 L
s
.391 .16649 m
.39475 .16649 L
s
.391 .22275 m
.39475 .22275 L
s
.391 .33527 m
.39475 .33527 L
s
.391 .39153 m
.39475 .39153 L
s
.391 .44779 m
.39475 .44779 L
s
.391 .56032 m
.39475 .56032 L
s
.391 .61658 m
.39475 .61658 L
s
.391 .67284 m
.39475 .67284 L
s
.391 .78536 m
.39475 .78536 L
s
.391 .84162 m
.39475 .84162 L
s
.391 .89788 m
.39475 .89788 L
s
.25 Mabswid
.391 0 m
.391 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.43987 .50192 m
.43986 .5018 L
.43985 .50166 L
.43984 .50152 L
.43982 .50137 L
.43981 .50121 L
.43979 .50104 L
.43977 .50087 L
.43975 .50068 L
.43972 .50048 L
.4397 .50027 L
.43967 .50004 L
.43963 .49981 L
.43959 .49956 L
.43955 .49929 L
.4395 .49901 L
.43945 .49872 L
.43939 .4984 L
.43932 .49807 L
.43925 .49773 L
.43916 .49736 L
.43907 .49697 L
.43896 .49656 L
.43884 .49613 L
.43871 .49568 L
.43856 .49521 L
.43839 .4947 L
.43821 .49418 L
.438 .49363 L
.43777 .49305 L
.43752 .49245 L
.43723 .49182 L
.43692 .49116 L
.43656 .49048 L
.43618 .48977 L
.43574 .48904 L
.43527 .48829 L
.43474 .48751 L
.43417 .48671 L
.43353 .4859 L
.43284 .48507 L
.43208 .48423 L
.43126 .48339 L
.43036 .48255 L
.42939 .48171 L
.42834 .48089 L
.42722 .4801 L
.42602 .47933 L
.42474 .4786 L
.42338 .47792 L
Mistroke
.42196 .47729 L
.42046 .47673 L
.4189 .47625 L
.41729 .47585 L
.41563 .47553 L
.41394 .47532 L
.41222 .4752 L
.41048 .47519 L
.40874 .47529 L
.40701 .47549 L
.4053 .4758 L
.40362 .47621 L
.40199 .47671 L
.40041 .47731 L
.39889 .47799 L
.39743 .47875 L
.39606 .47958 L
.39476 .48046 L
.39355 .4814 L
.39242 .48238 L
.39138 .48339 L
.39042 .48443 L
.38956 .48548 L
.38877 .48654 L
.38807 .48761 L
.38745 .48868 L
.38691 .48974 L
.38644 .49078 L
.38605 .49182 L
.38573 .49283 L
.38547 .49382 L
.38528 .49478 L
.38515 .49572 L
.38508 .49662 L
.38507 .49748 L
.38511 .49831 L
.38519 .4991 L
.38533 .49984 L
.38551 .50054 L
.38573 .50119 L
.38598 .50179 L
.38626 .50233 L
.38657 .50282 L
.38689 .50326 L
.38723 .50364 L
.38758 .50396 L
.38793 .50423 L
.38828 .50445 L
.38862 .50462 L
.38894 .50474 L
Mistroke
.38925 .50482 L
.38953 .50486 L
.38978 .50487 L
.39001 .50486 L
.39021 .50483 L
.39038 .50478 L
.39053 .50472 L
.39065 .50465 L
.39075 .50459 L
.39083 .50452 L
.39089 .50446 L
.39093 .5044 L
.39097 .50434 L
.39099 .5043 L
.39101 .50425 L
.39102 .50422 L
.39103 .50419 L
.39103 .50416 L
.39103 .50414 L
.39103 .50412 L
.39103 .50411 L
.39102 .5041 L
.39102 .50409 L
.39102 .50408 L
.39102 .50407 L
.39101 .50407 L
.39101 .50407 L
.39101 .50406 L
.39101 .50406 L
.39101 .50406 L
.39101 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50405 L
Mistroke
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.391 1.12522 0.504055 1.12522 [
[.16596 .49155 -9.6 -7.2 ]
[.16596 .49155 9.6 0 ]
[.61604 .49155 -7.2 -7.2 ]
[.61604 .49155 7.2 0 ]
[.84109 .49155 -7.2 -7.2 ]
[.84109 .49155 7.2 0 ]
[.3785 .05397 -19.2 -3.6 ]
[.3785 .05397 0 3.6 ]
[.3785 .27901 -19.2 -3.6 ]
[.3785 .27901 0 3.6 ]
[.3785 .7291 -14.4 -3.6 ]
[.3785 .7291 0 3.6 ]
[.3785 .95414 -14.4 -3.6 ]
[.3785 .95414 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16596 .50405 m
.16596 .5103 L
s
[(-0.2)] .16596 .49155 0 1 Mshowa
.61604 .50405 m
.61604 .5103 L
s
[(0.2)] .61604 .49155 0 1 Mshowa
.84109 .50405 m
.84109 .5103 L
s
[(0.4)] .84109 .49155 0 1 Mshowa
.125 Mabswid
.22222 .50405 m
.22222 .5078 L
s
.27848 .50405 m
.27848 .5078 L
s
.33474 .50405 m
.33474 .5078 L
s
.44726 .50405 m
.44726 .5078 L
s
.50352 .50405 m
.50352 .5078 L
s
.55978 .50405 m
.55978 .5078 L
s
.6723 .50405 m
.6723 .5078 L
s
.72857 .50405 m
.72857 .5078 L
s
.78483 .50405 m
.78483 .5078 L
s
.1097 .50405 m
.1097 .5078 L
s
.05343 .50405 m
.05343 .5078 L
s
.89735 .50405 m
.89735 .5078 L
s
.95361 .50405 m
.95361 .5078 L
s
.25 Mabswid
0 .50405 m
1 .50405 L
s
.391 .05397 m
.39725 .05397 L
s
[(-0.4)] .3785 .05397 1 0 Mshowa
.391 .27901 m
.39725 .27901 L
s
[(-0.2)] .3785 .27901 1 0 Mshowa
.391 .7291 m
.39725 .7291 L
s
[(0.2)] .3785 .7291 1 0 Mshowa
.391 .95414 m
.39725 .95414 L
s
[(0.4)] .3785 .95414 1 0 Mshowa
.125 Mabswid
.391 .11023 m
.39475 .11023 L
s
.391 .16649 m
.39475 .16649 L
s
.391 .22275 m
.39475 .22275 L
s
.391 .33527 m
.39475 .33527 L
s
.391 .39153 m
.39475 .39153 L
s
.391 .44779 m
.39475 .44779 L
s
.391 .56032 m
.39475 .56032 L
s
.391 .61658 m
.39475 .61658 L
s
.391 .67284 m
.39475 .67284 L
s
.391 .78536 m
.39475 .78536 L
s
.391 .84162 m
.39475 .84162 L
s
.391 .89788 m
.39475 .89788 L
s
.25 Mabswid
.391 0 m
.391 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.5 .5 m
.49998 .49976 L
.49996 .4995 L
.49994 .49923 L
.49991 .49895 L
.49989 .49865 L
.49985 .49832 L
.49982 .49799 L
.49978 .49763 L
.49973 .49725 L
.49968 .49684 L
.49963 .49642 L
.49956 .49597 L
.49949 .49549 L
.49941 .49499 L
.49932 .49446 L
.49922 .49389 L
.49911 .4933 L
.49898 .49267 L
.49884 .49201 L
.49869 .49131 L
.49851 .49057 L
.49831 .48979 L
.49809 .48897 L
.49784 .48811 L
.49757 .4872 L
.49726 .48625 L
.49691 .48525 L
.49653 .4842 L
.4961 .4831 L
.49563 .48195 L
.4951 .48074 L
.49451 .47949 L
.49386 .47819 L
.49313 .47683 L
.49233 .47543 L
.49145 .47398 L
.49047 .47249 L
.4894 .47096 L
.48822 .46939 L
.48692 .4678 L
.48551 .46618 L
.48398 .46455 L
.4823 .46292 L
.4805 .4613 L
.47855 .45971 L
.47645 .45814 L
.47422 .45663 L
.47183 .45519 L
.46931 .45382 L
Mistroke
.46665 .45256 L
.46386 .45141 L
.46095 .45039 L
.45794 .44952 L
.45484 .44881 L
.45167 .44828 L
.44845 .44792 L
.44519 .44774 L
.44193 .44776 L
.43868 .44796 L
.43546 .44835 L
.43229 .44892 L
.4292 .44966 L
.4262 .45055 L
.4233 .4516 L
.42052 .45277 L
.41788 .45406 L
.41536 .45545 L
.41299 .45691 L
.41077 .45845 L
.40869 .46003 L
.40675 .46165 L
.40496 .46329 L
.4033 .46494 L
.40178 .46659 L
.40038 .46822 L
.3991 .46984 L
.39794 .47143 L
.39687 .47298 L
.39591 .47449 L
.39504 .47597 L
.39425 .47739 L
.39354 .47877 L
.3929 .4801 L
.39233 .48139 L
.39181 .48262 L
.39135 .4838 L
.39094 .48493 L
.39058 .48602 L
.39025 .48706 L
.38996 .48805 L
.38971 .48899 L
.38949 .4899 L
.38929 .49076 L
.38913 .49158 L
.38898 .49237 L
.38886 .49311 L
.38875 .49383 L
.38867 .4945 L
.3886 .49515 L
Mistroke
.38855 .49576 L
.38851 .49635 L
.38849 .49691 L
.38848 .49743 L
.38849 .49794 L
.3885 .49841 L
.38853 .49886 L
.38856 .49929 L
.38861 .49969 L
.38866 .50007 L
.38872 .50043 L
.38879 .50076 L
.38887 .50108 L
.38895 .50137 L
.38904 .50164 L
.38913 .50189 L
.38922 .50212 L
.38931 .50234 L
.38941 .50253 L
.38951 .50271 L
.3896 .50287 L
.3897 .50301 L
.38979 .50314 L
.38988 .50326 L
.38996 .50336 L
.39004 .50345 L
.39012 .50353 L
.39019 .5036 L
.39026 .50367 L
.39033 .50372 L
.39039 .50377 L
.39044 .50381 L
.3905 .50384 L
.39054 .50388 L
.39059 .5039 L
.39063 .50392 L
.39067 .50394 L
.3907 .50396 L
.39073 .50398 L
.39076 .50399 L
.39078 .504 L
.3908 .50401 L
.39082 .50401 L
.39084 .50402 L
.39086 .50403 L
.39087 .50403 L
.39089 .50403 L
.3909 .50404 L
.39091 .50404 L
.39092 .50404 L
Mistroke
.39093 .50404 L
.39094 .50405 L
.39094 .50405 L
.39095 .50405 L
.39095 .50405 L
.39096 .50405 L
.39096 .50405 L
.39097 .50405 L
.39097 .50405 L
.39097 .50405 L
.39098 .50405 L
.39098 .50405 L
.39098 .50405 L
.39098 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
Mistroke
Mfstroke
newpath
.5 .5 .47619 0 365.73 arc
s
newpath
.49989 .49865 .47044 0 365.73 arc
s
newpath
.49968 .49684 .46069 0 365.73 arc
s
newpath
.49932 .49446 .4447 0 365.73 arc
s
newpath
.49869 .49131 .41989 0 365.73 arc
s
newpath
.49757 .4872 .38437 0 365.73 arc
s
newpath
.49563 .48195 .33854 0 365.73 arc
s
newpath
.49233 .47543 .28613 0 365.73 arc
s
newpath
.48692 .4678 .23288 0 365.73 arc
s
newpath
.47855 .45971 .18399 0 365.73 arc
s
newpath
.46665 .45256 .14236 0 365.73 arc
s
newpath
.45167 .44828 .10867 0 365.73 arc
s
newpath
.43546 .44835 .08226 0 365.73 arc
s
newpath
.42052 .45277 .06196 0 365.73 arc
s
newpath
.40869 .46003 .04651 0 365.73 arc
s
newpath
.40038 .46822 .03484 0 365.73 arc
s
newpath
.39504 .47597 .02603 0 365.73 arc
s
newpath
.39181 .48262 .01939 0 365.73 arc
s
newpath
.38996 .48805 .01438 0 365.73 arc
s
newpath
.38898 .49237 .01058 0 365.73 arc
s
newpath
.38855 .49576 .00769 0 365.73 arc
s
newpath
.3885 .49841 .00548 0 365.73 arc
s
newpath
.38872 .50043 .0038 0 365.73 arc
s
newpath
.38913 .50189 .00254 0 365.73 arc
s
newpath
.3896 .50287 .00163 0 365.73 arc
s
newpath
.39004 .50345 .001 0 365.73 arc
s
newpath
.39039 .50377 .0006 0 365.73 arc
s
newpath
.39063 .50392 .00035 0 365.73 arc
s
newpath
.39078 .504 .0002 0 365.73 arc
s
newpath
.39087 .50403 .00011 0 365.73 arc
s
newpath
.39093 .50404 6e-05 0 365.73 arc
s
newpath
.39096 .50405 4e-05 0 365.73 arc
s
newpath
.39098 .50405 2e-05 0 365.73 arc
s
newpath
.39099 .50405 1e-05 0 365.73 arc
s
newpath
.39099 .50405 1e-05 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.391 1.12522 0.504055 1.12522 [
[.16596 .49155 -9.6 -7.2 ]
[.16596 .49155 9.6 0 ]
[.61604 .49155 -7.2 -7.2 ]
[.61604 .49155 7.2 0 ]
[.84109 .49155 -7.2 -7.2 ]
[.84109 .49155 7.2 0 ]
[.3785 .05397 -19.2 -3.6 ]
[.3785 .05397 0 3.6 ]
[.3785 .27901 -19.2 -3.6 ]
[.3785 .27901 0 3.6 ]
[.3785 .7291 -14.4 -3.6 ]
[.3785 .7291 0 3.6 ]
[.3785 .95414 -14.4 -3.6 ]
[.3785 .95414 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16596 .50405 m
.16596 .5103 L
s
[(-0.2)] .16596 .49155 0 1 Mshowa
.61604 .50405 m
.61604 .5103 L
s
[(0.2)] .61604 .49155 0 1 Mshowa
.84109 .50405 m
.84109 .5103 L
s
[(0.4)] .84109 .49155 0 1 Mshowa
.125 Mabswid
.22222 .50405 m
.22222 .5078 L
s
.27848 .50405 m
.27848 .5078 L
s
.33474 .50405 m
.33474 .5078 L
s
.44726 .50405 m
.44726 .5078 L
s
.50352 .50405 m
.50352 .5078 L
s
.55978 .50405 m
.55978 .5078 L
s
.6723 .50405 m
.6723 .5078 L
s
.72857 .50405 m
.72857 .5078 L
s
.78483 .50405 m
.78483 .5078 L
s
.1097 .50405 m
.1097 .5078 L
s
.05343 .50405 m
.05343 .5078 L
s
.89735 .50405 m
.89735 .5078 L
s
.95361 .50405 m
.95361 .5078 L
s
.25 Mabswid
0 .50405 m
1 .50405 L
s
.391 .05397 m
.39725 .05397 L
s
[(-0.4)] .3785 .05397 1 0 Mshowa
.391 .27901 m
.39725 .27901 L
s
[(-0.2)] .3785 .27901 1 0 Mshowa
.391 .7291 m
.39725 .7291 L
s
[(0.2)] .3785 .7291 1 0 Mshowa
.391 .95414 m
.39725 .95414 L
s
[(0.4)] .3785 .95414 1 0 Mshowa
.125 Mabswid
.391 .11023 m
.39475 .11023 L
s
.391 .16649 m
.39475 .16649 L
s
.391 .22275 m
.39475 .22275 L
s
.391 .33527 m
.39475 .33527 L
s
.391 .39153 m
.39475 .39153 L
s
.391 .44779 m
.39475 .44779 L
s
.391 .56032 m
.39475 .56032 L
s
.391 .61658 m
.39475 .61658 L
s
.391 .67284 m
.39475 .67284 L
s
.391 .78536 m
.39475 .78536 L
s
.391 .84162 m
.39475 .84162 L
s
.391 .89788 m
.39475 .89788 L
s
.25 Mabswid
.391 0 m
.391 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.66561 .45435 m
.66455 .45159 L
.66337 .4487 L
.66206 .44568 L
.6606 .44254 L
.65898 .43926 L
.65719 .43586 L
.6552 .43234 L
.653 .42869 L
.65058 .42494 L
.64792 .42108 L
.64499 .41713 L
.64178 .41311 L
.63827 .40904 L
.63445 .40492 L
.63029 .4008 L
.62579 .3967 L
.62093 .39264 L
.61571 .38867 L
.61012 .38481 L
.60417 .38112 L
.59786 .37763 L
.5912 .37437 L
.58422 .37141 L
.57693 .36877 L
.56937 .36649 L
.56158 .3646 L
.5536 .36315 L
.54548 .36214 L
.53727 .3616 L
.52903 .36153 L
.5208 .36194 L
.51265 .36282 L
.50463 .36415 L
.49678 .36592 L
.48915 .36809 L
.48179 .37064 L
.47471 .37352 L
.46796 .37669 L
.46155 .38012 L
.4555 .38377 L
.44981 .38758 L
.44449 .39153 L
.43953 .39556 L
.43493 .39966 L
.43068 .40378 L
.42676 .4079 L
.42316 .41199 L
.41987 .41603 L
.41687 .42 L
Mistroke
.41413 .42388 L
.41164 .42767 L
.40938 .43134 L
.40734 .43491 L
.40549 .43834 L
.40383 .44166 L
.40233 .44484 L
.40098 .44789 L
.39976 .45082 L
.39867 .45361 L
.39769 .45628 L
.39681 .45883 L
.39602 .46126 L
.39532 .46356 L
.39469 .46576 L
.39412 .46784 L
.39362 .46982 L
.39317 .4717 L
.39277 .47348 L
.39241 .47517 L
.39208 .47677 L
.3918 .47828 L
.39154 .47972 L
.39131 .48107 L
.39111 .48236 L
.39093 .48357 L
.39077 .48472 L
.39062 .48581 L
.39049 .48684 L
.39038 .48781 L
.39028 .48873 L
.39019 .4896 L
.39011 .49042 L
.39004 .4912 L
.38997 .49193 L
.38992 .49262 L
.38987 .49328 L
.38982 .4939 L
.38978 .49449 L
.38975 .49505 L
.38972 .49557 L
.38969 .49607 L
.38967 .49654 L
.38965 .49699 L
.38963 .49741 L
.38962 .49781 L
.3896 .49819 L
.38959 .49855 L
.38959 .49889 L
.38958 .49921 L
Mistroke
.38958 .49952 L
.38957 .49981 L
.38957 .50009 L
.38958 .50035 L
.38958 .5006 L
.38958 .50084 L
.38959 .50107 L
.3896 .50128 L
.38961 .50149 L
.38962 .50169 L
.38964 .50187 L
.38966 .50205 L
.38967 .50223 L
.3897 .50239 L
.38972 .50255 L
.38975 .5027 L
.38978 .50284 L
.38981 .50297 L
.38985 .5031 L
.38989 .50322 L
.38993 .50334 L
.38997 .50345 L
.39002 .50355 L
.39007 .50364 L
.39012 .50373 L
.39018 .50381 L
.39023 .50388 L
.39029 .50395 L
.39035 .504 L
.39041 .50405 L
.39047 .50409 L
.39053 .50412 L
.39058 .50415 L
.39064 .50417 L
.39069 .50418 L
.39074 .50419 L
.39078 .50419 L
.39082 .50419 L
.39085 .50419 L
.39088 .50418 L
.39091 .50417 L
.39093 .50416 L
.39095 .50415 L
.39096 .50414 L
.39098 .50413 L
.39098 .50412 L
.39099 .50411 L
.391 .5041 L
.391 .50409 L
.391 .50409 L
Mistroke
.391 .50408 L
.391 .50408 L
.391 .50407 L
.391 .50407 L
.391 .50407 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50406 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
Mistroke
Mfstroke
newpath
.66561 .45435 .04891 0 365.73 arc
s
newpath
.65898 .43926 .04889 0 365.73 arc
s
newpath
.64792 .42108 .04884 0 365.73 arc
s
newpath
.63029 .4008 .04877 0 365.73 arc
s
newpath
.60417 .38112 .04862 0 365.73 arc
s
newpath
.56937 .36649 .04838 0 365.73 arc
s
newpath
.52903 .36153 .04794 0 365.73 arc
s
newpath
.48915 .36809 .0472 0 365.73 arc
s
newpath
.4555 .38377 .04595 0 365.73 arc
s
newpath
.43068 .40378 .04394 0 365.73 arc
s
newpath
.41413 .42388 .04092 0 365.73 arc
s
newpath
.40383 .44166 .03677 0 365.73 arc
s
newpath
.39769 .45628 .03167 0 365.73 arc
s
newpath
.39412 .46784 .02611 0 365.73 arc
s
newpath
.39208 .47677 .02067 0 365.73 arc
s
newpath
.39093 .48357 .01578 0 365.73 arc
s
newpath
.39028 .48873 .01163 0 365.73 arc
s
newpath
.38992 .49262 .00823 0 365.73 arc
s
newpath
.38972 .49557 .00551 0 365.73 arc
s
newpath
.38962 .49781 .00342 0 365.73 arc
s
newpath
.38958 .49952 .00191 0 365.73 arc
s
newpath
.38958 .50084 .00095 0 365.73 arc
s
newpath
.38964 .50187 .00042 0 365.73 arc
s
newpath
.38975 .5027 .00016 0 365.73 arc
s
newpath
.38993 .50334 6e-05 0 365.73 arc
s
newpath
.39018 .50381 2e-05 0 365.73 arc
s
newpath
.39047 .50409 1e-05 0 365.73 arc
s
newpath
.39074 .50419 0 0 365.73 arc
s
newpath
.39091 .50417 0 0 365.73 arc
s
newpath
.39098 .50412 0 0 365.73 arc
s
newpath
.391 .50408 0 0 365.73 arc
s
newpath
.391 .50406 0 0 365.73 arc
s
newpath
.391 .50406 0 0 365.73 arc
s
newpath
.391 .50406 0 0 365.73 arc
s
newpath
.391 .50406 0 0 365.73 arc
s
newpath
.391 .50406 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
newpath
.391 .50405 0 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.391 1.12522 0.504055 1.12522 [
[.16596 .49155 -9.6 -7.2 ]
[.16596 .49155 9.6 0 ]
[.61604 .49155 -7.2 -7.2 ]
[.61604 .49155 7.2 0 ]
[.84109 .49155 -7.2 -7.2 ]
[.84109 .49155 7.2 0 ]
[.3785 .05397 -19.2 -3.6 ]
[.3785 .05397 0 3.6 ]
[.3785 .27901 -19.2 -3.6 ]
[.3785 .27901 0 3.6 ]
[.3785 .7291 -14.4 -3.6 ]
[.3785 .7291 0 3.6 ]
[.3785 .95414 -14.4 -3.6 ]
[.3785 .95414 0 3.6 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16596 .50405 m
.16596 .5103 L
s
[(-0.2)] .16596 .49155 0 1 Mshowa
.61604 .50405 m
.61604 .5103 L
s
[(0.2)] .61604 .49155 0 1 Mshowa
.84109 .50405 m
.84109 .5103 L
s
[(0.4)] .84109 .49155 0 1 Mshowa
.125 Mabswid
.22222 .50405 m
.22222 .5078 L
s
.27848 .50405 m
.27848 .5078 L
s
.33474 .50405 m
.33474 .5078 L
s
.44726 .50405 m
.44726 .5078 L
s
.50352 .50405 m
.50352 .5078 L
s
.55978 .50405 m
.55978 .5078 L
s
.6723 .50405 m
.6723 .5078 L
s
.72857 .50405 m
.72857 .5078 L
s
.78483 .50405 m
.78483 .5078 L
s
.1097 .50405 m
.1097 .5078 L
s
.05343 .50405 m
.05343 .5078 L
s
.89735 .50405 m
.89735 .5078 L
s
.95361 .50405 m
.95361 .5078 L
s
.25 Mabswid
0 .50405 m
1 .50405 L
s
.391 .05397 m
.39725 .05397 L
s
[(-0.4)] .3785 .05397 1 0 Mshowa
.391 .27901 m
.39725 .27901 L
s
[(-0.2)] .3785 .27901 1 0 Mshowa
.391 .7291 m
.39725 .7291 L
s
[(0.2)] .3785 .7291 1 0 Mshowa
.391 .95414 m
.39725 .95414 L
s
[(0.4)] .3785 .95414 1 0 Mshowa
.125 Mabswid
.391 .11023 m
.39475 .11023 L
s
.391 .16649 m
.39475 .16649 L
s
.391 .22275 m
.39475 .22275 L
s
.391 .33527 m
.39475 .33527 L
s
.391 .39153 m
.39475 .39153 L
s
.391 .44779 m
.39475 .44779 L
s
.391 .56032 m
.39475 .56032 L
s
.391 .61658 m
.39475 .61658 L
s
.391 .67284 m
.39475 .67284 L
s
.391 .78536 m
.39475 .78536 L
s
.391 .84162 m
.39475 .84162 L
s
.391 .89788 m
.39475 .89788 L
s
.25 Mabswid
.391 0 m
.391 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.85956 .41913 m
.85775 .41442 L
.85573 .40949 L
.85349 .40434 L
.851 .39896 L
.84824 .39337 L
.84517 .38756 L
.84178 .38153 L
.83803 .37531 L
.83389 .36889 L
.82934 .36231 L
.82433 .35556 L
.81885 .3487 L
.81286 .34173 L
.80632 .33471 L
.79922 .32767 L
.79153 .32065 L
.78323 .31372 L
.77432 .30694 L
.76477 .30035 L
.7546 .29404 L
.74382 .28807 L
.73245 .28252 L
.72051 .27745 L
.70806 .27294 L
.69515 .26905 L
.68184 .26583 L
.66821 .26334 L
.65434 .26162 L
.64031 .2607 L
.62623 .26058 L
.61218 .26128 L
.59825 .26279 L
.58455 .26507 L
.57114 .26808 L
.55811 .2718 L
.54552 .27615 L
.53344 .28107 L
.52191 .28649 L
.51096 .29236 L
.50061 .29858 L
.49089 .3051 L
.4818 .31184 L
.47333 .31874 L
.46547 .32574 L
.45821 .33278 L
.45152 .33982 L
.44537 .3468 L
.43975 .35371 L
.43462 .36049 L
Mistroke
.42994 .36713 L
.42569 .3736 L
.42183 .37988 L
.41834 .38597 L
.41519 .39184 L
.41234 .39751 L
.40978 .40295 L
.40747 .40817 L
.4054 .41317 L
.40353 .41795 L
.40186 .42251 L
.40036 .42687 L
.39901 .43101 L
.39781 .43496 L
.39673 .43872 L
.39577 .44228 L
.39491 .44567 L
.39414 .44888 L
.39345 .45193 L
.39284 .45482 L
.39229 .45756 L
.3918 .46015 L
.39137 .46261 L
.39098 .46494 L
.39063 .46714 L
.39033 .46922 L
.39005 .4712 L
.38981 .47306 L
.38959 .47483 L
.3894 .4765 L
.38923 .47808 L
.38908 .47958 L
.38895 .481 L
.38883 .48234 L
.38873 .48361 L
.38864 .48481 L
.38856 .48594 L
.3885 .48702 L
.38844 .48804 L
.38839 .48901 L
.38835 .48992 L
.38832 .49079 L
.3883 .49161 L
.38828 .49239 L
.38827 .49313 L
.38826 .49383 L
.38826 .4945 L
.38827 .49513 L
.38828 .49573 L
.3883 .4963 L
Mistroke
.38832 .49684 L
.38835 .49736 L
.38839 .49785 L
.38843 .49831 L
.38848 .49875 L
.38853 .49916 L
.38858 .49956 L
.38865 .49993 L
.38871 .50028 L
.38878 .50061 L
.38886 .50092 L
.38894 .50121 L
.38902 .50148 L
.38911 .50173 L
.38919 .50197 L
.38928 .50218 L
.38938 .50238 L
.38947 .50257 L
.38956 .50274 L
.38965 .50289 L
.38974 .50303 L
.38982 .50315 L
.38991 .50326 L
.38999 .50336 L
.39007 .50345 L
.39014 .50353 L
.39021 .5036 L
.39028 .50366 L
.39034 .50372 L
.3904 .50377 L
.39045 .50381 L
.39051 .50384 L
.39055 .50387 L
.39059 .5039 L
.39063 .50392 L
.39067 .50394 L
.3907 .50396 L
.39073 .50397 L
.39076 .50399 L
.39078 .504 L
.39081 .50401 L
.39083 .50401 L
.39084 .50402 L
.39086 .50403 L
.39088 .50403 L
.39089 .50403 L
.3909 .50404 L
.39091 .50404 L
.39092 .50404 L
.39093 .50404 L
Mistroke
.39094 .50405 L
.39094 .50405 L
.39095 .50405 L
.39095 .50405 L
.39096 .50405 L
.39096 .50405 L
.39097 .50405 L
.39097 .50405 L
.39097 .50405 L
.39098 .50405 L
.39098 .50405 L
.39098 .50405 L
.39098 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.39099 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
.391 .50405 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[35]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`02oooooaCo0000?Oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03
o`000?oooooooooo08cooooo2?l000000ooooooo0000o`00000Do`0003Oooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`29ooooo`co00003Oooool<o`0003Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000P?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wo00000ooooolBo`0000Cooooo2Ol0000aooooo`7o00000Oooool00003o`000?oo
oooooooo02;ooooo1?l000001?oooooo0000ooooool00007ooooo`?o00000_ooool2o`0007Wooooo
1?l000001?oooooo0000ooooool00003ooooo`Oo00000_ooool6o`0001;ooooo1_l00004ooooo`;o
000000Coooooo`000?l0003o0000;_ooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03
o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`1mooooo`03
o`000?oooooo000000?o000000Koooooo`000?l0003oooooo`000?ooool4o`0001gooooo0ol00003
ooooo`;o000000?oooooo`000?l000000_l0000[ooooo`7o00000Oooool00003o`000?oooooooooo
02Oooooo00?o0000ooooool000002?ooool2o`0000;ooooo00?o0000ooooooooool0OOooool7o`00
00?ooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo4Ol00009ooooo`?o00000_ooool01_l0
003oooooo`000?l0003oooooo`0002[ooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0007oooooo1?l00003ooooo`?o00000_oo
ool00ol0003oooooooooo`07o`00017ooooo1Ol00007ooooo`;o000000?oooooo`000?l000001?l0
000Yooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0Noooool5
o`0000;ooooo0_l00007ooooo`;o00007?ooool3o`0000Kooooo0ol000001?oooooo0000o`000?oo
ool2o`0002Oooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1h
ooooo`?o000000?oooooo`000?l000000_ooool2o`0000Kooooo0ol000000ooooooo0000ooooo`0N
ooooo`;o00001oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo02Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1gooooo`05o`000?oooooo0000
ooooool000000oooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`04
oooooa3o00002oooool3o`0000Gooooo00Ko0000ooooooooooooooooo`000?ooool3o`0002?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2o`0007Oooooo00?o0000ooooool000000_l0
0002ooooo`;o00001?ooool2o`0000Oooooo1ol0000@ooooo`Go00002Oooool2o`0000Cooooo0ol0
00001_oooooo0000o`000?l0003oooooo`0002;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
=_ooool00ol0003oooooooooo`1eooooo`Co00000_ooool2o`0000?ooooo0ol00006ooooo`Go0000
6_ooool4o`0000Oooooo0ol00004ooooo`03o`000?oooooooooo00Co00008Oooool1o`00007ooooo
00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Cooooo0ol00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00?o0000ooooooooool07Ooo
ool3o`0000Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00023ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1cooooo`?o00000_oo
ool2o`0000Cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool08?oo
ool2o`0000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0001oooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1aooooo`;o000000Go
ooooo`000?ooooooooooo`000004ooooo`;o00001Oooool2o`0000Oooooo00?o0000ooooooooool0
1?ooool?o`0000oooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00Ko0000oooooooooooo
ooooo`000?ooool2o`0001gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`1`ooooo`05o`000?oooooo0000o`000?ooool00_l00003ooooo`;o00001_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Co00003oooool4o`0000cooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooooooool3o`000005ooooool0003o0000ooooool000007?oo
ool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo06oooooo00Ko0000
ooooool0003o0000ooooool00004ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`Co0000
5oooool4o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooool0003o
0000ooooool0000Kooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_l0001_ooooo`06
o`000?oooooo0000o`000?oooooo00000oooool2o`0000Gooooo0_l00009ooooo`;o000000?ooooo
o`000?l000007?ooool2o`0000Wooooo0_l00005ooooo`;o00001?ooool01_l0003oooooo`000?l0
003oooooo`0001[ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`1]ooooo`06o`000?oooooo0000o`000?oooooo00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo0_l00003ooooo`03o`000?oooooooooo01gooooo0_l00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0003oooooo`000?l0003ooooo
o`0001Wooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1]oooo
o`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo0_l00005ooooo`03o`000?oooooooooo01oooooo0_l00008ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`0001Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1/ooooo`;o000000?oooooo`000?l0
00000oooool00ol0003oooooooooo`03ooooo`;o00001oooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool<o`00013ooooo0_l00007ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?l000006?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo06_ooooo0_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01Ol0000<ooooo`Go
00003Oooool2o`0000Oooooo00?o0000ooooooooool00oooool02?l0003ooooooooooooooooo0000
ooooool0003ooooo0_l0000Gooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000
ooooooooool0J_ooool2o`000004ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0ol0000Fooooo`;o00003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00So0000oooooooooooooooo
o`000?oooooo0000ooooo`;o00005_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03
o`000?oooooooooo06Wooooo0_l000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`?o00006_ooool3o`00
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`08o`000?oooooooooo
ooooool0003oooooo`000?ooool2o`0001Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool2o`0006[ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool2o`0000Sooooo0_l00002ooooo`;o00007?ooool2o`0000Wooooo0_l0
0007ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001Go
oooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Xooooo`?o0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool2o`0000Cooooo00?o0000ooooooooool07Oooool2o`0000Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0
003ooooo0ol0000Dooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0Ioooool3o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`go00003Oooool2o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000;ooooo0ol0000Cooooo`7o00000Oooool00003o`000?oooooooooo
03Kooooo00?o0000ooooooooool0Ioooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo0_l00007
ooooo`03o`000?oooooooooo00;ooooo0ol0000=ooooo`?o00003?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool02Ol0003ooooooooooooo
oooo0000ooooool0003oooooo`00000Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0I_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooool000000_l0000Cooooo`?o00002_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000001;ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`1Vooooo`;o00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`?o00006Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2o`0001;ooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Uooooo`05o`000?oooooo0000
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool06_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo0000017o
oooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`1Tooooo`?o00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`00
00?ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00Oooooo1_l0000=
ooooo`;o00002?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000;ooooo0ol0000@ooooo`7o00000Oooool00003o`000?oooooo
oooo02;ooooo1?l000001?oooooo0000ooooool00008ooooo`04o`000?ooooooooooooooo`;o0000
IOooool3o`000005ooooool0003oooooooooool000001Oooool00ol0003oooooooooo`03ooooo`Go
000000Coooooo`000?l0003o00001oooool2o`0000?ooooo0_l00003ooooo`Go00001_ooool4o`00
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`?o00004?oo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo0000IOooool3o`0000;ooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo0ol00006ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000000_l0000?ooooo`?o00002Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol0000?ooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool0001Uooooo`05o`000?oooooo0000oooo
ool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0001Gooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Wo0000ooooooooooooooooo`00
0?oooooo0000ooooool000003oooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Kooooo0ol00002ooooo`03o`000?oooooooooo06;ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00ol000000ooooooo0000
o`00000Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`000003ooooool0003o000000kooooo0Ol00001ooooo`0000?o0000ooooooooool0
=_ooool00ol0003oooooooooo`1Qooooo`;o000000Coooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`03ooooo`[o
00002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Oo0000oooooooo
oooo0000ooooool0003ooooo00;o00003Oooool1o`00007ooooo00000ol0003oooooooooo`0foooo
o`03o`000?oooooooooo067ooooo0ol000000ooooooo0000ooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool01_l0003ooooooooooooooooo0000ooooo`?o00002_ooool4o`0000Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooooooool0
003ooooo0ol0000=ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0H?ooool01_l0003oooooo`000?l0003oooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooo`000?ooool00_l000000ooooooo0000ooooo`0;ooooo`7o00000Oooool00003o`000?oooooo
oooo03Kooooo0_l0001Qooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool3o`0001;ooooo0_l00007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`?o
00003?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo063ooooo
0ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool01ol0003o
oooooooooooooooo0000ooooool000000_ooool<o`0000Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo0000oooo
o`03o`0000cooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1O
ooooo`;o000000Coooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01ol0003oooooooooool0003oooooo`000?ooool00_l0000;ooooo`7o00000Oooool0
0003o`000?oooooooooo03Kooooo00?o0000ooooooooool0Goooool3o`000003ooooool0003ooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool2o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`?o
00002oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo05oooooo
0ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo0_l00003ooooo`Oo00001_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooooooool0003ooooo0ol0000;ooooo`7o00000Oooool00003o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0Goooool2o`0000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
o`000?ooool2o`0000Oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02o`0000_ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`1Oooooo`;o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o00002oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool2o`0000_ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2o`00063ooooo0_l00000
1Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo000000;o000000Coooooo`000?l0003o00001oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02o`00
00_ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Nooooo`?o
000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?oooooo0000ooooo`?o00000oooool3o`0000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0ol0000:ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0G_oo
ool3o`000005ooooool0003oooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`0:o`00
0?ooooooooooooooool0003oooooo`000?oooooo0000ooooo`;o00002?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
ool0003ooooo00?o00002_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo05kooooo0ol000001Ooooooo0000oooooooooooo000000?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool2o`000004ooooool0003o0000
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000oooooooooooo0000ooooo`03o`0000[ooooo0Ol00001ooooo`0000?o0000
ooooooooool0=_ooool00ol0003oooooooooo`1Nooooo`;o000000?oooooo`000?ooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool2o`000003oooo
ool0003ooooo00;o00000oooool2o`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`00
00[ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Mooooo`?o
000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`?o000000?oooooo`000?l000001_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000000_l00009ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o
0000ooooooooool0GOooool3o`000005ooooool0003oooooooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`0<o`000?ooooooooooooooool0003oooooo`000?oooooo0000ooooool0003ooooo
1Ol00002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0000Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Mooooo`?o000000Goooooo`000?oo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000ooooooooooooooooo`000?oo
ool7o`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00?o
00002Oooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooooooo0ol0000Dooooo`;o00005_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooooooo`?o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07Oooool3o`000005ooooool0003oooooooooool000000oooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooooooo`04o`0000?ooooo
00?o0000ooooooooool00_ooool01_l0003ooooooooooooooooo0000ooooo`Co00000_ooool3o`00
0003ooooool0003o000000Oo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Cooooo00Co0000oooooooooooooooo1?l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000
oooooooooooo0000ooooo`03o`0000Wooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool4
o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool03oooool00ol0003oooooo`00
0007ooooo`?o00007oooool3o`000006ooooool0003oooooooooool0003ooooo1?l000000ooooooo
0000ooooo`02o`0000Gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`08
o`000?ooooooooooooooool0003oooooo`000?ooool2o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000ooooo`02o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00_oo
ool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000ooooo`02ooooo`04o`000?oo
ooooooooooooo`?o00001?ooool01Ol0003oooooooooool0003ooooo00?o00002Oooool1o`00007o
oooo00000ol0003oooooooooo`0Eooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000001oooooo0ol000001Ooooooo0000
oooooooooooo000000?ooooo00Go0000oooooooooooo0000ooooo`02o`0000Gooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`02ooooo`08o`000?ooooooooooooooool0003ooooo
o`000?ooool8o`0000;ooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00oooool2o`00
00Kooooo00?o0000ooooooooool01Oooool2o`000003ooooool0003ooooo00;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Cooooo00Go0000oooooooooooo0000ooooo`03o`0000Wooooo
0Ol00001ooooo`0000?o0000ooooooooool05Oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooool000000_l0000Booooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooo`000008ooooo`;o00007oooool01Ol0003oooooo`00
0?oooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`00
00Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`08o`000?oooooo
ooooooooool0003oooooo`000?ooool2o`000003ooooool0003o000000;o000000Koooooo`000?oo
oooo0000ooooool00003ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
o`000?ooool00_ooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00002Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Kooooo0ol0000Dooooo`;o00000_ooool3o`00017ooooo
00?o0000ooooooooool01_ooool3o`00017ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`05o`000?oooooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000001Oooool4o`0000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000;ooooo2_l000001?oooooo0000ooooool00003ooooo`05o`000?oo
oooo0000ooooool000001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo
1?l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000ooooool0003ooooo
o`0000Wooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05Oooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000
1_l00002ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00004oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Wooooo
0Ol00001ooooo`0000?o0000ooooooooool0=Oooool2o`0000Gooooo0_l0001Hooooo`05o`000?oo
oooo0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooo000000[o000000?oooooo`000?l000000oooool2o`00
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool02?l0003oooooooooool0003oooooo`000?oooooo0000
2Oooool1o`00007ooooo00000ol0003oooooooooo`03oooooh?o00003Ooooon3o`0000Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooool000000_l00002ooooo`05o`000?ooooooooooooooool000001Ooo
ool2o`0000Cooooo00?o0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`09o`0000Cooooo00?o0000ooooool0
00001?ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ool000001?ooool00ol0003oooooo`000006ooooo`;o00001Oooool2o`0000Cooooo00?o0000oooo
ool000000_ooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00Sooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Mooooo`05o`000?oooooo0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?oooooo0000o`0000Wooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00So0000oooooooooooo0000ooooool0003oooooo`0000Wooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1Mooooo`05o`000?oooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`;o000000?oooooo`000?l000001ol00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00So
0000oooooooooooo0000ooooool0003oooooo`0000Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1Mooooo`?o000000Goooooo`000?ooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003o
oooo00?o00002Oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo
05gooooo0ol000001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00003Oooool2o`0000Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go
0000oooooooooooo0000ooooo`03o`0000Wooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`1Mooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003oooooooooool0003ooooo00?o
00001oooool3o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0000Wooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool2o`0005kooooo0ol000001Ooooooo0000oooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo0000
o`0000?ooooo1ol0000:ooooo`;o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1Mooooo`?o000000?oooooo`000?ooool00_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0001Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ooooooooooooooooo`000?ooool3o`0000Wooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1Mooooo`?o00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool3o`00017ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool3o`0000Wooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Nooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000>ooooo`;o00002Ooo
ool2o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooooooool0003ooooo00?o0000
2_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo05kooooo0ol0
00001Ooooooo0000oooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo
00Co0000oooooooooooooooo1?l00006ooooo`Co00002_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000002o`0000[ooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Nooooo`?o000000Goooooo`000?oo
ooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007
ooooo`Ko00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool3o`0000[ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`1Nooooo`?o000000Goooooo`000?ooooooooooo`000004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo00006Oooool2o`0000[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool01ol0003oooooooooool0003oooooo`000?ooool00_l0000:ooooo`7o00000Oooool00003
o`000?oooooooooo03Kooooo00?o0000ooooooooool0Goooool2o`000003ooooool0003ooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`?o00006?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000_ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=_ooool2o`00063ooooo0_l00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool2o`0001Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo0000
00_ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Oooooo`?o
000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
ool0003o00004_ooool2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooo
oooo0000ooooo`?o00002oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo05oooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooooooool2o`0000_ooooo1Ol0000<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000_ooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Oooooo`?o00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool;o`00
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`?o00002oooool1
o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo05oooooo00Ko0000oooo
ool0003o0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Looooo`;o00002_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool01_l0003ooooooooooooooooo0000ooooo`;o
000000?oooooo`000?ooool02_ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo063ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
0_l00003ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01_l0003ooooo
oooooooooooo0000ooooo`?o00003?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03
o`000?oooooooooo063ooooo0ol00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00Co0000oooo
oooooooo00006oooool2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool3o`0000cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=_ooool2o`00067ooooo00Ko0000ooooool0003o0000oooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00002_ooool4o`0001Sooooo0_l0000<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0
003ooooo0_l000000ooooooo0000ooooo`0;ooooo`7o00000Oooool00003o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0HOooool3o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool3o`00
01Cooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool3o`0000gooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Qooooo`;o000000Coooooo`00
0?oooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o00003_ooool3
o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000o`0000gooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Rooooo`?o00000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`?o0000
4Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool02?l0003ooooooooooooooooo0000ooooool0003ooooo0_l0000>ooooo`7o00000Oooool0
0003o`000?oooooooooo03Kooooo00?o0000ooooooooool0Hoooool2o`0000?ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`Go00004oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooool000003oooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool0
00000_ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000001?l00002
ooooo`03o`000?oooooooooo01kooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000004?oo
ool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooooooo0_l0001Uooooo`?o00000_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool3o`000003ooooool0003ooooo00Kooooo0ol00002ooooo`;o0000
7?ooool3o`0000_ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03o`00013ooooo0Ol00001ooooo`0000?o0000ooooooooool09ooo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0006Kooooo0_l000001Ooooooo0000
oooooooooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooo000000Wooooo1?l0000Kooooo`;o00003Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo0000
o`00013ooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0006Oooooo0ol00003ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_l0
000Hooooo`;o00003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000003ooooo`?o00004Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo0ol00002ooooo`03o`000?oooooo000000;o00004_oo
ool3o`0000oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0000Booooo`7o00000Oooool00003o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0I_ooool2o`000005ooooool0003oooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l0000:ooooo`03
o`000?oooooooooo00;ooooo4_l0000@ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`02o`0001;ooooo0Ol00001oooo
o`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Wooooo`;o000000Coooooo`000?oo
oooo00001?ooool00ol0003oooooooooo`03ooooo`;o00002Oooool2o`0000Sooooo00?o0000oooo
ooooool08_ooool2o`0000Wooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
oooooooo0000ooooo`02o`0001?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Wooooo`07o`000?oooooo0000ooooool0003oooooo`000004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02?ooool2o`0000Kooooo00?o0000ooooooooool08?oo
ool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`07o`000?oo
oooo0000ooooool0003oooooo`00000Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0J?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`;o00001?ooool00ol0003o
ooooooooo`0Nooooo`;o00002oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0Cooooo`7o00000Oooool00003o`00
0?oooooooooo03Kooooo0_l0001Zooooo`;o000000Goooooo`000?ooooooooooo`000004ooooo`03
o`000?oooooooooo00Cooooo0_l0000;ooooo`;o00000_ooool2o`0001gooooo0_l0000;ooooo`;o
00001_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooo`000?ooool00_l0000Eoooo
o`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0J_ooool2o`000005
ooooool0003oooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00[ooooo0ol0000Looooo`;o00003?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000oooooooooooo0000ooooo`02o`0001Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`1[ooooo`;o000000Goooooo`000?ooooooooooo`000004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool2o`0001Wooooo0_l0000=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01Ol0003oooooooooool0
003ooooo00;o00005oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo06_ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool2o`0000_ooooo00?o0000ooooool000001Ol0000=ooooo`Ko00003Ooo
ool2o`0000Oooooo00?o0000ooooooooool00oooool02?l0003oooooooooool0003oooooo`000?oo
oooo00005oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo06co
oooo00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool2o`0000Wooooo00?o0000ooooooooool01Oooool=o`00017ooooo0_l00008oooo
o`03o`000?oooooooooo00?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0001Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1]ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
0ol00006ooooo`03o`000?oooooooooo027ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`05o`000?oooooo0000ooooool000006Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo06kooooo00Go0000ooooool0003oooooo`000002ooooo`03
o`000?oooooooooo00;ooooo0ol00009ooooo`;o00001?ooool00ol0003oooooooooo`0Oooooo`;o
00002Oooool2o`0000Cooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000006_oo
ool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;o0000L?ooool3o`000004ooooool0003o
ooooooooo`;o00001Oooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0001gooooo0ol0
000:ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0001_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`1aooooo`;o0000
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
0ol0000Looooo`;o00003?ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooooooool0
003ooooo0_l0000Mooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0L_ooool2o`000003ooooool0003ooooo00;ooooo0_l00004ooooo`;o00002oooool3o`0001So
oooo0_l0000<ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`00000Nooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0Loooool4o`0000Cooooo
0_l00004ooooo`?o00002?ooool00ol0003oooooooooo`07o`0000Wooooo2?l0000;ooooo`?o0000
1?ooool2o`0000?ooooo00?o0000ooooool000000_l0000Oooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0M?ooool00ol0003oooooo`000003o`0000?ooooo00?o
0000ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01oooool9o`00017ooooo0_l0
0006ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?oooooo00008?ooool1o`00007o
oooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo07Gooooo00?o0000ooooool00000
0_ooool2o`0000;ooooo0_l00006ooooo`?o00000oooool00ol0003oooooooooo`0Nooooo`?o0000
1_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooo0000027ooooo0Ol00001ooooo`0000?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1fooooo`?o00000oooool01?l0003ooooooooo
ooooool3o`0000Kooooo1?l0000Nooooo`;o00001oooool2o`0000?ooooo00Co0000oooooooooooo
oooo0ol0000Rooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_l0001jooooo`?o0000
00?oooooo`000?l000001?ooool00ol0003oooooooooo`06ooooo`;o00006_ooool3o`0000Oooooo
0_l00003ooooo`;o00000_ooool3o`0002Cooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`1kooooo`?o000000?oooooo`000?l000000oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Go00003oooool5o`0000Wooooo00Co0000oooooooooooooooo
0_l000000ooooooo0000o`000003o`0002Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`1looooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooooooo
0ol00004ooooo`03o`000?oooooooooo00Gooooo3ol0000<ooooo`;o00000oooool01Ol0003ooooo
ooooool0003ooooo00;o00009oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo07gooooo00Go0000ooooool0003o0000ooooo`03o`0000?ooooo1_l0000Kooooo`Ko
00000oooool2o`000005ooooool0003o0000ooooool00000:Oooool1o`00007ooooo00000ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo07kooooo1_l000000ooooooo0000o`000005ooooo`04
o`000?oooooo0000o`0001Kooooo0ol00006ooooo`?o000000Coooooo`000?l0003ooooo0_l0000Z
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0POooool9o`00
00;ooooo00Co0000oooooooooooooooo2Ol00005ooooo`So00001oooool2o`000003ooooool0003o
000000Co0000;?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo
08Cooooo3?l00009ooooo`Go00002Oooool<o`0002oooooo0Ol00001ooooo`0000?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo0000P?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Ko00000oooool3
o`00017ooooo0ol00003ooooo`Ko0000<_ooool1o`00007ooooo00000ol0003oooooooooo`0Woooo
o`03o`000?oooooo000000Oooooo0ol00002ooooo`;o0000O_ooool00ol0003oooooo`000007oooo
o`Wo00000ooooolAo`0000?ooooo1_l0000eooooo`7o00000Oooool00003o`000?oooooooooo02Oo
oooo00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo07go
oooo00?o0000ooooool000001oooool00ol0003oooooo`000002oooooako0000>?ooool1o`00007o
oooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Sooooo0_l00002ooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooool000002?ooool2o`0000;ooooo00?o0000ooooooooool0
0_oooolCo`0003kooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`00083ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool0001Eooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o
0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo
00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Dooo
ool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo
00000ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00020ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool0001Eooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo
1?l000001?oooooo0000ooooool00007ooooo`?o00000_ooool2o`0007Wooooo1?l000001?oooooo
0000ooooool00007ooooo`?o00000_ooool2o`0005Cooooo0Ol00001ooooo`0000?o0000oooooooo
ool09oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool0OOooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool0Doooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Sooooo
0_l00002ooooo`03o`000?oooooooooo07gooooo00?o0000ooooool000002?ooool2o`0000;ooooo
00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo0000P?ooool00ol0003oooooooooo`08ooooo`04o`00
0?ooooooooooo`0005Gooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool2o`0008gooooo0_l0001Dooooo`7o00000Oooool00003
o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo
03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003
o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o
00000Oooool00003o`000?oooooooooo03Kooooo0_l0002=ooooo`;o0000E?ooool1o`00007ooooo
00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Dooo
ool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo
08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo
00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Dooo
ool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;o0000SOooool2o`00
05Cooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03
o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000
ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo01_ooooo1Ol0000c
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`0Dooooo`Oo00001Oooool5o`0002kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002
ooooo`03o`000?oooooooooo017ooooo0ol0000Aooooo`?o0000:oooool1o`00007ooooo00000ol0
003oooooooooo`0Rooooo`Co000000Coooooo`000?oooooo00002?ooool01?l0003ooooooooooooo
ool2o`0007Wooooo1?l000001?oooooo0000ooooool00008ooooo`04o`000?ooooooooooooooo`;o
00004?ooool2o`0001Oooooo0ol0000Xooooo`7o00000Oooool00003o`000?oooooooooo02Oooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool0001oooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Jooooo`;o00009_ooool1o`00
007ooooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo0000Ooooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000gooooo0ol0000O
ooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ol0
003oooooooooo`06ooooo`?o00000_ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Kooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool2o`00
02?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`?o
0000N_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool08?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo
1_l00002ooooo`Ko0000MOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool07oooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Oooooo0_l00002ooooo`06o`000?oooooo0000o`000?oooooo00000_ooool01?l0003o
ooooooooooooool2o`0007?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01kooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2o`0000Ko
oooo0ol00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooo`000006o`00
06oooooo0_l00007ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07Oooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo0_l000001_oooooo
0000ooooool0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Go0000
ooooooooooooooooo`00001^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Looooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`;o00001?ooool2o`0000?ooooo0_l0
0004ooooo`03o`000?oooooo000000;o0000KOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool06oooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000?ooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000003ooooo`?o00000_ooool2o`0006cooooo00?o0000ooooooooool00ooo
ool2o`00037ooooo00?o0000ooooooooool06_ooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00;o00000_ooool3o`0000;ooooo3Ol00002ooooo`04o`000?oooooo
ooooo`0000?ooooo0_l0001[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Jooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00Co0000
ooooool0003o00000oooool00ol0003oooooooooo`03o`000007ooooool0003oooooooooool0003o
ooooo`000002ooooo`03o`000?oooooo000000?o00000_ooool7o`0006[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool2o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`00
0003ooooool0003ooooo00;o00000_ooool2o`0000;ooooo00Co0000ooooool0003ooooo1Ol00003
ooooo`03o`000?oooooo000000;o0000J?ooool01Ol0003ooooooooooooooooo000003Kooooo00?o
0000ooooooooool06?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`Co00000_ooool3
o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`;o00000_ooool01Ol0003oooooo`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo06Kooooo
0_l000000ooooooo0000o`00000fooooo`03o`000?oooooooooo01Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0=Oooool2o`0000;ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooooooo00;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`Ko0000
0_ooool3o`0006Oooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`0Gooooo`7o
00000Oooool00003o`000?oooooooooo03Cooooo00?o0000ooooool000000ol000001Ooooooo0000
o`000?l0003ooooo00?o00000_ooool01Ol0003oooooo`000?l0003ooooo00Co00000_ooool01?l0
003oooooo`000?l00002ooooo`;o000000?oooooo`000?l000001Ol0001Vooooo`04o`000?oooooo
ooooo`0003Sooooo00?o0000ooooooooool05oooool1o`00007ooooo00000ol0003oooooooooo`0d
ooooo`?o00000oooool2o`0000;ooooo00?o0000ooooooooool00_l000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo00Ko000000Goooooo`000?oooooo0000ooooo`03o`0000?ooooo0ol0
001Vooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool05_ooool1o`00007ooooo0000
0ol0003oooooooooo`0dooooo`?o00000oooool3o`000004ooooool0003oooooooooo`?o00002_oo
ool2o`000005ooooool0003oooooo`000?ooool01?l00002ooooo`04o`000?ooooooooooo`0006Ko
oooo00?o0000ooooool00000>_ooool00ol0003oooooooooo`0Fooooo`7o00000Oooool00003o`00
0?oooooooooo03Cooooo00?o0000ooooool000000ol00002ooooo`Ko00003Oooool7o`0000;ooooo
00Co0000oooooooooooo00000_ooool2o`0006Gooooo00?o0000ooooool00000Doooool1o`00007o
oooo00000ol0003oooooooooo`0dooooo`Oo00000_ooool00ol0003oooooo`00000Aooooo`Co0000
1?ooool2o`0000?ooooo0_l0001Uooooo`;o0000E?ooool1o`00007ooooo00000ol0003ooooooooo
o`0cooooo`;o000000?oooooo`000?l000000ol00002ooooo`;o00004oooool3o`0000Cooooo0_l0
0003ooooo`?o0000I?ooool2o`0005Cooooo0Ol00001ooooo`0000?o0000ooooooooool05_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00004Oooool7o`000004ooooool0
003o0000o`00013ooooo00?o0000ooooooooool00_ooool8o`0000;ooooo00Co0000ooooool0003o
00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00005?ooool2o`00
01Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`00017ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo0Ol00001
ooooo`0000?o0000ooooooooool04?ooool4o`000004ooooool0003oooooo`0000Sooooo00?o0000
ooooooooool04?ooool2o`000006ooooool0003o0000ooooool0003ooooo0_l0000@ooooo`03o`00
0?oooooo000000?ooooo0_l00003ooooo`03o`000?oooooo000000;o00000_ooool2o`0000Wooooo
00?o0000ooooool000001oooool3o`0002Sooooo1?l000001?oooooo0000ooooool00008ooooo`03
o`000?oooooooooo01?ooooo0_l0000Eooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooo`000007ooooo`?o00005Oooool1o`00007ooooo00000ol0003ooooo
ooooo`0Eooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool03oooool9o`00017ooooo
00?o0000ooooool000000oooool5o`000003ooooool0003o000000Cooooo0_l00009ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool00000;Oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooool000001oooool00ol0003oooooo`00000Eooooo`7o0000
0Oooool00003o`000?oooooooooo01Gooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`0?ooooo`So00004_ooool00ol0003oooooo`000004ooooo`;o00000_ooool2o`0000?ooooo0_l0
00000ooooooo0000ooooo`08ooooo`03o`000?oooooo000000Sooooo0_l0000]ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000008ooooo`;o00005Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo0ol0000B
ooooo`Oo00004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?o00000_ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`06ooooo`?o00005?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Kooooo0ol0000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool1o`00007ooooo00000ol0003oooooooooo`0dooooo`Ko00006oooool2o`0000;ooooo0ol00002
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0
003oooooooooo`0eooooo`Co00007_ooool3o`0000?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo00?oooooPol0000=oooooh?o
00001Oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2o`0008gooooo0_l0001Dooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_l0002=ooooo`;o
0000E?ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo
00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo
00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;o0000SOoo
ool2o`0005Cooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00000_ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo05?ooooo
0Ol00001ooooo`0000?o0000ooooooooool09oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooooooo`;o0000O_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooooooo`;o
0000E?ooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo0000Ooooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
05Gooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0007oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0001E
ooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo0_l0002=ooooo`;o0000E?ooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo
00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00007ooooo00000ol0
003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0Doooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`03o`000?oooooooooo08cooooo00?o0000oooooooo
ool0Doooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`;o0000SOooool2o`0005Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`00
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo05?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool2o`0008gooooo0_l0001D
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0
003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00083ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0005Gooooo0Ol00001
ooooo`0000?o0000ooooooooool09oooool00ol0003oooooo`000007ooooo`?o00000_ooool2o`00
07kooooo00?o0000ooooool000001oooool3o`0000;ooooo0_l0001Dooooo`7o00000Oooool00003
o`000?oooooooooo02Oooooo00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo07gooooo00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool09oooool00ol0003ooooo
o`000008ooooo`;o00000_ooool00ol0003oooooooooo`1mooooo`03o`000?oooooo000000Sooooo
0_l00002ooooo`03o`000?oooooooooo05?ooooo0Ol00001ooooo`0000?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00083ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool0001Eooooo`7o00000Oooool00003o`000?oooooooooo03Kooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1Cooooo`7o00000Ooo
ool00003o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`1C
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0509259, -0.0509259, \
0.00732353, 0.00732353}, {{6.9375, 136.938}, {280, 150}} -> {-0.394919, \
-0.49582, 0.00683634, 0.00683634}, {{150, 280}, {280, 150}} -> {-1.37294, \
-0.49582, 0.00683634, 0.00683634}, {{6.9375, 136.938}, {136.938, 6.9375}} -> \
{-0.394919, -1.47384, 0.00683634, 0.00683634}, {{150, 280}, {136.938, \
6.9375}} -> {-1.37294, -1.47384, 0.00683634, 0.00683634}},
  CellTags->"2.5"]
}, Open  ]],

Cell["\<\
The level of interaction shown by the Gershgorin circles \
superimposed on element (1, 1) indicates that there will only be a small \
response from output 2 when a unit-step function is applied to input 1. \
However, the level of interaction shown for element (2, 2) is not acceptable, \
and implies that there would be a significant response from output 1 when a \
unit-step function is applied to input 2. The time responses of this system \
confirm the interaction predicted by the Nyquist array.\
\>", "Text",
  CellTags->"2.5"],

Cell["\<\
These are the resulting variations in the top temperature (solid \
line) and the bottom temperature (dashed line) for separate unit-step changes \
in each input.\
\>", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[fp, 
        UnitStep[1], {t, 
          10000}, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[ .001], 
            Dashing[{0.015}]}];\)\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-05 0.0147151 2.34484 [
[.21429 .00222 -9.6 -7.2 ]
[.21429 .00222 9.6 0 ]
[.40476 .00222 -9.6 -7.2 ]
[.40476 .00222 9.6 0 ]
[.59524 .00222 -9.6 -7.2 ]
[.59524 .00222 9.6 0 ]
[.78571 .00222 -9.6 -7.2 ]
[.78571 .00222 9.6 0 ]
[.97619 .00222 -12 -7.2 ]
[.97619 .00222 12 0 ]
[.01131 .13196 -19.2 -3.6 ]
[.01131 .13196 0 3.6 ]
[.01131 .2492 -14.4 -3.6 ]
[.01131 .2492 0 3.6 ]
[.01131 .36644 -19.2 -3.6 ]
[.01131 .36644 0 3.6 ]
[.01131 .48368 -14.4 -3.6 ]
[.01131 .48368 0 3.6 ]
[.01131 .60093 -19.2 -3.6 ]
[.01131 .60093 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2000)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4000)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6000)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8000)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13196 m
.03006 .13196 L
s
[(0.05)] .01131 .13196 1 0 Mshowa
.02381 .2492 m
.03006 .2492 L
s
[(0.1)] .01131 .2492 1 0 Mshowa
.02381 .36644 m
.03006 .36644 L
s
[(0.15)] .01131 .36644 1 0 Mshowa
.02381 .48368 m
.03006 .48368 L
s
[(0.2)] .01131 .48368 1 0 Mshowa
.02381 .60093 m
.03006 .60093 L
s
[(0.25)] .01131 .60093 1 0 Mshowa
.125 Mabswid
.02381 .03816 m
.02756 .03816 L
s
.02381 .06161 m
.02756 .06161 L
s
.02381 .08506 m
.02756 .08506 L
s
.02381 .10851 m
.02756 .10851 L
s
.02381 .15541 m
.02756 .15541 L
s
.02381 .17885 m
.02756 .17885 L
s
.02381 .2023 m
.02756 .2023 L
s
.02381 .22575 m
.02756 .22575 L
s
.02381 .27265 m
.02756 .27265 L
s
.02381 .2961 m
.02756 .2961 L
s
.02381 .31954 m
.02756 .31954 L
s
.02381 .34299 m
.02756 .34299 L
s
.02381 .38989 m
.02756 .38989 L
s
.02381 .41334 m
.02756 .41334 L
s
.02381 .43679 m
.02756 .43679 L
s
.02381 .46024 m
.02756 .46024 L
s
.02381 .50713 m
.02756 .50713 L
s
.02381 .53058 m
.02756 .53058 L
s
.02381 .55403 m
.02756 .55403 L
s
.02381 .57748 m
.02756 .57748 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01472 m
.06244 .13134 L
.10458 .23469 L
.14415 .31115 L
.18221 .36977 L
.22272 .41941 L
.26171 .45729 L
.30316 .48915 L
.34309 .51335 L
.3815 .53187 L
.42237 .54751 L
.46172 .55943 L
.49955 .56858 L
.53984 .57633 L
.57861 .58226 L
.61984 .58725 L
.65954 .59105 L
.69774 .59396 L
.73838 .59642 L
.77751 .5983 L
.81909 .59987 L
.85916 .60107 L
.89771 .60199 L
.93871 .60276 L
.97619 .60332 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .01472 m
.04262 .04354 L
.0522 .06126 L
.06244 .07559 L
.07286 .08636 L
.08255 .09384 L
.09409 .10037 L
.10458 .10468 L
.11454 .10771 L
.12373 .10983 L
.13381 .11159 L
.14451 .11296 L
.15392 .11386 L
.16404 .11459 L
.1736 .11511 L
.18234 .11547 L
.19219 .11578 L
.20133 .116 L
.21136 .11618 L
.22205 .11632 L
.23234 .11643 L
.24346 .11651 L
.25397 .11656 L
.26364 .1166 L
.27337 .11663 L
.28246 .11665 L
.29243 .11667 L
.30312 .11668 L
.3133 .11669 L
.32436 .1167 L
.33481 .1167 L
.34448 .1167 L
.35411 .11671 L
.36315 .11671 L
.37306 .11671 L
.38375 .11671 L
.39332 .11671 L
.40379 .11671 L
.41472 .11671 L
.42489 .11671 L
.43541 .11672 L
.44535 .11672 L
.45427 .11672 L
.46394 .11672 L
.4734 .11672 L
.48381 .11672 L
.49468 .11672 L
.50485 .11672 L
.51526 .11672 L
.52514 .11672 L
Mistroke
.53401 .11672 L
.54368 .11672 L
.55402 .11672 L
.56339 .11672 L
.5742 .11672 L
.58438 .11672 L
.59417 .11672 L
.60449 .11672 L
.61331 .11672 L
.62298 .11672 L
.63321 .11672 L
.64253 .11672 L
.65328 .11672 L
.66346 .11672 L
.67313 .11672 L
.6834 .11672 L
.69217 .11672 L
.70184 .11672 L
.71196 .11672 L
.72122 .11672 L
.7314 .11672 L
.74209 .11672 L
.75166 .11672 L
.76187 .11672 L
.77151 .11672 L
.78025 .11672 L
.79026 .11672 L
.79948 .11672 L
.80959 .11672 L
.82029 .11672 L
.82975 .11672 L
.8399 .11672 L
.84948 .11672 L
.85823 .11672 L
.86812 .11672 L
.87729 .11672 L
.88735 .11672 L
.89804 .11672 L
.90739 .11672 L
.91749 .11672 L
.92701 .11672 L
.93576 .11672 L
.94555 .11672 L
.95466 .11672 L
.96466 .11672 L
.97535 .11672 L
.97619 .11672 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@oooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`00A?ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001kooooo0ol00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000N
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001oooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000007Oooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooool000001oooool004Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000007_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Nooooo`?o
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00008?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001gooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000Oooooo
0015ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000001oooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001oooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00007Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000001oooool001_ooooo00?o0000oooo
ooooool09Oooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo0ol00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo000Kooooo`03
o`000?oooooooooo0?oooooo0oooool001_ooooo00?o0000ooooooooool0ooooool3ooooo`005Ooo
ooooo`0000cooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0@ooooo`006oooool2o`0002oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0@ooooo`006oooool2o`000?oooooo1?ooool001_ooooo0_l0003oooooo`Cooooo
000Kooooo`05o`000?oooooo0000ooooool00000ooooool1ooooo`006oooool3o`000003ooooool0
003ooooo0?oooooo000Kooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0oOooool0
01_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3looooo`006oooool01?l0
003oooooooooool0003oooooo`;ooooo000Kooooo`04o`000?ooooooooooo`000?oooooo0_ooool0
01_ooooo00Go0000ooooooooooooooooo`00003oooooo`7ooooo000Kooooo`;o00000_ooool01?l0
003oooooooooool0003mooooo`006oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0n_ooool001_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
00000?_ooooo000Kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3hooooo`006oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?go
oooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0o?ooool001_ooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo0_l0003gooooo`006oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0m?ooool001_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0??ooooo000Kooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0noooool001_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`?o0000l?ooool001_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`;o0000k_ooool001_ooooo0_l00006ooooo`03o`000?oooooo
oooo00oooooo0_l0003Yooooo`006oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo0_l00003ooooo`Go0000goooool001_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Mooooo`Go00000oooool4o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?o
oooo1Ol00003ooooo`Co00000oooool5o`0000?ooooo1Ol00003ooooo`Co00000oooool5o`0000?o
oooo1_l00003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Co00000oooool5o`0000?o
oooo1Ol00003ooooo`Co00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5o`0000?o
oooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo0_l0000Booooo`006oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?Wooooo000Kooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0nOooool000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?Sooooo0005ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`3hooooo`001Oooool00ol0
003oooooo`000007ooooo`03o`000?oooooo000000;ooooo0ol00004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0n?ooool000Gooooo00?o0000ooooool000001oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3gooooo`001_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooooooo`?o
00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?Oooooo000Kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0moooool001_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`3fooooo`006oooool2o`0000[ooooo00?o0000ooooooooool0m_ooool0
01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3eooooo`006oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?Gooooo000Kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0m?ooool001_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`3dooooo`006oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?Cooooo000Koooo
o`;o00003Oooool00ol0003oooooooooo`3cooooo`006oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0??ooooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
l_ooool001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3booooo`006oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?7ooooo000Kooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0lOooool001_ooooo0_l0000?ooooo`03o`000?oooooooooo0?7o
oooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0l?ooool001_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3`ooooo`006oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0>oooooo000Kooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0koooool001_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3^ooooo`00
6oooool2o`0001;ooooo00?o0000ooooooooool0k_ooool001_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`3^ooooo`006oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo0>gooooo000Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0kOooool001_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3/ooooo`002oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0>cooooo000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
0oooool3o`0001Cooooo00?o0000ooooooooool0joooool000[ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0jooo
ool000[ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0j_ooool000_ooooo00?o0000ooooooooool01_ooool2o`00
00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3Zooooo`006oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo0>Wooooo000Kooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0jOooool001_ooooo0_l0000Hooooo`03o`000?oooooooooo0>Sooooo000K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0ioooool001_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`3Wooooo`006oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0>Kooooo000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
i_ooool001_ooooo0_l0000Kooooo`03o`000?oooooooooo0>Gooooo000Kooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0iOooool001_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`3Tooooo`006oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>Co
oooo000Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0hoooool001_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`3Sooooo`006oooool2o`0001kooooo00?o0000
ooooooooool0h_ooool001_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3Qoooo
o`006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>7ooooo000Kooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0h?ooool001_ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`3Pooooo`006oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0=oooooo000Kooooo`;o00008_ooool00ol0003oooooooooo`3Nooooo`006oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo0=kooooo000Kooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0gOooool001_ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`3Mooooo`006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0=cooooo0006oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00002ooooo`?o00001?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0=_ooooo0005ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o00009?ooool00ol0
003oooooooooo`3Kooooo`001Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooooooo
o`?o00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0=[ooooo0005ooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0f_ooool000Kooooo00?o0000ooooooooool01_ooool2o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0fOooool001_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`3Hooooo`006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo0=Oooooo000Kooooo`;o0000:_ooool00ol0003oooooooooo`3F
ooooo`006oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0=Gooooo000Kooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0e?ooool001_ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`3Dooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0=?ooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0d_ooool0
01_ooooo0_l0000_ooooo`03o`000?oooooooooo0=7ooooo000Kooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0d?ooool001_ooooo00?o0000ooooooooool0<?ooool2o`000=3ooooo
000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0cOooool001_ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`3<ooooo`006oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo0<_ooooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`3:ooooo`00
6oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0<Wooooo000Kooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0b?ooool001_ooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`37ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
0<Kooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l00036ooooo`006oooool2o`0003gooooo
00?o0000ooooooooool0`oooool001_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`32ooooo`006oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0<7ooooo000Koooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0`?ooool001_ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`2oooooo`002oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;ko
oooo000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool3o`0004;ooooo
00?o0000ooooooooool0_Oooool000[ooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0_?ooool000[ooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Cooooo0_l0002l
ooooo`002oooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`16oooo
o`;o0000^_ooool001_ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2gooooo`00
6oooool00ol0003oooooooooo`19ooooo`;o0000]oooool001_ooooo0_l0001<ooooo`;o0000]Ooo
ool001_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2booooo`006oooool00ol0
003oooooooooo`1>ooooo`;o0000/_ooool001_ooooo00?o0000ooooooooool0D?ooool3o`000:oo
oooo000Kooooo`03o`000?oooooooooo05?ooooo0_l0002]ooooo`006oooool00ol0003ooooooooo
o`1Eooooo`?o0000Z_ooool001_ooooo0_l0001Iooooo`;o0000Z?ooool001_ooooo00?o0000oooo
ooooool0F_ooool3o`000:Gooooo000Kooooo`03o`000?oooooooooo05gooooo0_l0002Sooooo`00
6oooool00ol0003oooooooooo`1Oooooo`?o0000X?ooool001_ooooo00?o0000ooooooooool0H_oo
ool3o`0009gooooo000Kooooo`03o`000?oooooooooo06Gooooo0ol0002Jooooo`006oooool2o`00
06Wooooo0ol0002Gooooo`006oooool00ol0003oooooooooo`1[ooooo`Co0000Toooool001_ooooo
00?o0000ooooooooool0Koooool3o`00093ooooo000Kooooo`03o`000?oooooooooo07;ooooo0ol0
002=ooooo`006oooool00ol0003oooooooooo`1eooooo`Go0000R?ooool001_ooooo00?o0000oooo
ooooool0N_ooool5o`0008?ooooo000Kooooo`;o0000P?ooool7o`0007cooooo000Kooooo`03o`00
0?oooooooooo08Kooooo2ol0001aooooo`006oooool00ol0003oooooooooo`2Aooooo`[o0000Iooo
ool001_ooooo00?o0000ooooooooool0Voooool:o`0005gooooo000Kooooo`03o`000?oooooooooo
0:Gooooo2_l0001Cooooo`001_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`?o00000_ooool3o`0000Cooooo00?o0000ooooooooool0[ooooolDo`0003oooooo0005ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`?o
0000`ooooolYo`0001Kooooo0005ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
0ol00004ooooo`03o`000?oooooooooo0>cooooo1?l0000Booooo`001Oooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0ooooool3ooooo`001_oo
ool00ol0003oooooooooo`06ooooo`?o00000_ooool3o`0000Cooooo00?o0000ooooooooool0oooo
ool3ooooo`006oooool00ol0003oooooooooo`3oooooo`?ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002>ooooo`?o0000Soooool008oooooo00?o0000oooo
ooooool0S_ooool008Gooooo0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`?o
00000_ooool3o`0000Gooooo0ol0001looooo`00Q_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo07_ooooo0026ooooo`07o`000?ooooooooooooooool0003o
ooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Noooool008Kooooo00?o0000ooooooooool01?l00000
0ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l00006ooooo`03o`00
0?oooooooooo07_ooooo0025ooooo`?o00004Oooool00ol0003oooooooooo`05ooooo`;o0000OOoo
ool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1141, -0.017408, 41.301, \
0.00167748}},
  CellTags->"2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 9.52381e-05 0.0147151 1.37419 [
[.21429 .00222 -9.6 -7.2 ]
[.21429 .00222 9.6 0 ]
[.40476 .00222 -9.6 -7.2 ]
[.40476 .00222 9.6 0 ]
[.59524 .00222 -9.6 -7.2 ]
[.59524 .00222 9.6 0 ]
[.78571 .00222 -9.6 -7.2 ]
[.78571 .00222 9.6 0 ]
[.97619 .00222 -12 -7.2 ]
[.97619 .00222 12 0 ]
[.01131 .15213 -14.4 -3.6 ]
[.01131 .15213 0 3.6 ]
[.01131 .28955 -14.4 -3.6 ]
[.01131 .28955 0 3.6 ]
[.01131 .42697 -14.4 -3.6 ]
[.01131 .42697 0 3.6 ]
[.01131 .56439 -14.4 -3.6 ]
[.01131 .56439 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2000)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4000)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6000)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8000)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10000)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15213 m
.03006 .15213 L
s
[(0.1)] .01131 .15213 1 0 Mshowa
.02381 .28955 m
.03006 .28955 L
s
[(0.2)] .01131 .28955 1 0 Mshowa
.02381 .42697 m
.03006 .42697 L
s
[(0.3)] .01131 .42697 1 0 Mshowa
.02381 .56439 m
.03006 .56439 L
s
[(0.4)] .01131 .56439 1 0 Mshowa
.125 Mabswid
.02381 .0422 m
.02756 .0422 L
s
.02381 .06968 m
.02756 .06968 L
s
.02381 .09717 m
.02756 .09717 L
s
.02381 .12465 m
.02756 .12465 L
s
.02381 .17962 m
.02756 .17962 L
s
.02381 .2071 m
.02756 .2071 L
s
.02381 .23459 m
.02756 .23459 L
s
.02381 .26207 m
.02756 .26207 L
s
.02381 .31704 m
.02756 .31704 L
s
.02381 .34452 m
.02756 .34452 L
s
.02381 .37201 m
.02756 .37201 L
s
.02381 .39949 m
.02756 .39949 L
s
.02381 .45446 m
.02756 .45446 L
s
.02381 .48194 m
.02756 .48194 L
s
.02381 .50943 m
.02756 .50943 L
s
.02381 .53691 m
.02756 .53691 L
s
.02381 .59188 m
.02756 .59188 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .01472 m
.06244 .13078 L
.10458 .23425 L
.14415 .3108 L
.18221 .3695 L
.22272 .41919 L
.26171 .45712 L
.30316 .48901 L
.34309 .51324 L
.3815 .53178 L
.42237 .54745 L
.46172 .55938 L
.49955 .56853 L
.53984 .5763 L
.57861 .58224 L
.61984 .58723 L
.65954 .59104 L
.69774 .59395 L
.73838 .59641 L
.77751 .59829 L
.81909 .59987 L
.85916 .60107 L
.89771 .60198 L
.93871 .60276 L
.97619 .60332 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .01472 m
.03279 .04188 L
.04262 .06834 L
.05288 .08895 L
.06244 .10333 L
.0731 .11527 L
.0828 .12334 L
.094 .13021 L
.10458 .13494 L
.11428 .13816 L
.12455 .14071 L
.13333 .14236 L
.14299 .14375 L
.15313 .14484 L
.1624 .14559 L
.17311 .14624 L
.18328 .1467 L
.19287 .14702 L
.20309 .14727 L
.21273 .14745 L
.22147 .14758 L
.2315 .14769 L
.24072 .14777 L
.25085 .14783 L
.26154 .14788 L
.27102 .14791 L
.28118 .14794 L
.29077 .14795 L
.29951 .14797 L
.30943 .14798 L
.3186 .14799 L
.32866 .14799 L
.33936 .148 L
.34873 .148 L
.35883 .148 L
.36837 .14801 L
.37711 .14801 L
.38691 .14801 L
.39603 .14801 L
.40604 .14801 L
.41673 .14801 L
.42698 .14801 L
.43808 .14801 L
.44856 .14801 L
.45823 .14801 L
.46792 .14801 L
.47699 .14801 L
.48694 .14801 L
.49763 .14801 L
.50776 .14801 L
Mistroke
.51881 .14801 L
.52924 .14801 L
.53891 .14801 L
.5495 .14801 L
.55947 .14801 L
.56842 .14801 L
.57809 .14801 L
.58762 .14801 L
.59807 .14801 L
.60898 .14801 L
.61915 .14801 L
.62963 .14801 L
.63954 .14801 L
.64844 .14801 L
.65811 .14801 L
.66753 .14801 L
.67792 .14801 L
.68877 .14801 L
.69894 .14801 L
.7088 .14801 L
.71916 .14801 L
.72801 .14801 L
.73768 .14801 L
.74798 .14801 L
.75733 .14801 L
.76812 .14801 L
.7783 .14801 L
.78804 .14801 L
.79835 .14801 L
.80715 .14801 L
.81681 .14801 L
.827 .14801 L
.8363 .14801 L
.84703 .14801 L
.85721 .14801 L
.86684 .14801 L
.87709 .14801 L
.88584 .14801 L
.8955 .14801 L
.90558 .14801 L
.91483 .14801 L
.92498 .14801 L
.93567 .14801 L
.9452 .14801 L
.95539 .14801 L
.96501 .14801 L
.97375 .14801 L
.97619 .14801 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[36]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00@?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Koooo
o`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`00@Oooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001oooooo0ol00002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000N
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001kooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000007Oooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooool000002_ooool004;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000007oooool00ol0003oooooo`000002ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000Nooooo`?o
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00007oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000001gooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000[ooooo
0012ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooo0000023ooooo0_l00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`00000Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000001kooooo00?o0000ooooool0
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00007Oooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000002_ooool001Wooooo00?o0000oooo
ooooool09?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0ol00003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo000Iooooo`03
o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000ooooooooool0ooooool5ooooo`004ooo
ooooo`0000kooooo000Iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Booooo`006Oooool2o`0002kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0Booooo`006Oooool2o`000?oooooo1_ooool001Wooooo0_l0003oooooo`Kooooo
000Iooooo`?o0000ooooool5ooooo`006Oooool00ol0003oooooo`00003oooooo`Gooooo000Ioooo
o`?o0000ooooool5ooooo`006Oooool01?l0003oooooooooool0003oooooo`Cooooo000Iooooo`04
o`000?ooooooooooo`000?oooooo1?ooool001Wooooo00Co0000oooooooooooo0000ooooool4oooo
o`006Oooool00ol0003oooooooooo`02o`000?oooooo0oooool001Wooooo00?o0000ooooooooool0
0_l0003oooooo`?ooooo000Iooooo`05o`000?ooooooooooooooool00000ooooool3ooooo`006Ooo
ool2o`0000?ooooo00?o0000ooooooooool0ooooool001Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0o_ooool001Wooooo
00?o0000ooooooooool00oooool2o`000?oooooo000Iooooo`03o`000?oooooooooo00?ooooo0_l0
003oooooo`006Oooool00ol0003oooooooooo`04ooooo`;o0000o_ooool001Wooooo0_l00005oooo
o`03o`000?oooooo00000?gooooo000Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oOooool001Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3looooo`006Ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?_ooooo000Iooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo0000noooool001Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`000?Wooooo000Iooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3fooooo`006Oooool2o`0000Oooooo00?o0000oooo
ooooool0noooool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`;o
0000m?ooool001Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?7ooooo000Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3`ooooo`006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo1Ol0003Zooooo`006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo1Ol00003ooooo`Go0000foooool000Wooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool3o`0000Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Loooo
o`04o`000?ooooooooooooooo`Co00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool5
o`0000?ooooo1?l00003ooooo`Go00000oooool5o`0000?ooooo1?l00003ooooo`Go00000oooool0
1?l0003oooooooooooooool4o`0000?ooooo1Ol00003ooooo`Go00000_ooool5o`0000?ooooo1Ol0
0003ooooo`Go00000_ooool5o`0000?ooooo1Ol00003ooooo`Co00000oooool5o`0000?ooooo1Ol0
0002ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go00000oooool2o`0001Cooooo0008
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo00?o0000
ooooooooool0n?ooool000Sooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0n?ooool000Sooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0moooool000Wooooo00?o0000ooooooooool01_ooool2o`0000Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3gooooo`006Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0?Kooooo000Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0m_ooool0
01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3fooooo`006Oooool2o`0000go
oooo00?o0000ooooooooool0mOooool001Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`3eooooo`006Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?Gooooo000I
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0m?ooool001Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3dooooo`006Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0?Cooooo000Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
loooool001Wooooo0_l0000?ooooo`03o`000?oooooooooo0??ooooo000Iooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0l_ooool001Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`3booooo`006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?;o
oooo000Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0lOooool001Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`3aooooo`006Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0?7ooooo000Iooooo`;o00004_ooool00ol0003oooooooooo`3`oooo
o`006Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0?3ooooo000Iooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0koooool001Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`3_ooooo`006Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0>kooooo000Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0k_ooool001Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3]ooooo`006Oooool2o`0001Gooooo
00?o0000ooooooooool0kOooool001Wooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3/ooooo`006Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>cooooo000Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0joooool001Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`3Zooooo`006Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo0>[ooooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo
0ol00004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0jOooool000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`;o00006Oooool00ol0003ooooooooo
o`3Yooooo`002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`3Xooooo`002?ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3Xoooo
o`002Oooool00ol0003oooooooooo`06ooooo`?o00001?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo0>Oooooo000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
ioooool001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3Vooooo`006Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>Kooooo000Iooooo`;o00007Oooool00ol0
003oooooooooo`3Uooooo`006Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0>Co
oooo000Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0i?ooool001Wooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`3Sooooo`006Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo0>;ooooo000Iooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0h_ooool001Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3Qooooo`00
6Oooool2o`0002;ooooo00?o0000ooooooooool0h?ooool001Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`3Pooooo`006Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo0=oooooo000Iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0g_ooool001Wo
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3Nooooo`006Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo0=gooooo000Iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0g?ooool001Wooooo0_l0000Vooooo`03o`000?oooooooooo0=cooooo000Ioooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0foooool001Wooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`3Jooooo`006Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo0=Wooooo000Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0fOoo
ool001Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3Hooooo`006Oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo0=Oooooo000Iooooo`;o0000;?ooool00ol0003o
ooooooooo`3Fooooo`006Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0=Gooooo
000Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0eOooool001Wooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`3Dooooo`006Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo0=?ooooo000Iooooo`03o`000?oooooooooo02oooooo0_l0003Cooooo`00
2Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0=3ooooo0008ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool00_ooool2o`0003?ooooo00?o0000ooooooooool0coooool000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0c_ooool000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0cOooool000Wooooo00?o0000oooo
ooooool01_ooool3o`0000Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3<oooo
o`006Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0<_ooooo000Iooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0b_ooool001Wooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`39ooooo`006Oooool2o`0003[ooooo0_l00039ooooo`006Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0<Kooooo000Iooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool0aOooool001Wooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`34ooooo`006Oooool00ol0003oooooooooo`0nooooo`;o0000a?ooool001Wooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`31ooooo`006Oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo0<3ooooo000Iooooo`;o0000@oooool00ol0003oooooooooo`2oooooo`00
6Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0;kooooo000Iooooo`03o`000?oo
oooooooo04Cooooo0_l0002nooooo`006Oooool00ol0003oooooooooo`16ooooo`;o0000_?ooool0
01Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2iooooo`006Oooool00ol0003o
ooooooooo`19ooooo`;o0000^Oooool001Wooooo00?o0000ooooooooool0Boooool2o`000;Oooooo
000Iooooo`;o0000C_ooool00ol0003oooooooooo`2dooooo`006Oooool00ol0003oooooooooo`1>
ooooo`;o0000]?ooool001Wooooo00?o0000ooooooooool0D?ooool3o`000;7ooooo000Iooooo`03
o`000?oooooooooo05?ooooo0_l0002_ooooo`006Oooool00ol0003oooooooooo`1Eooooo`?o0000
[?ooool001Wooooo00?o0000ooooooooool0F?ooool2o`000:[ooooo000Iooooo`03o`000?oooooo
oooo05[ooooo0ol0002Wooooo`006Oooool2o`0005kooooo0_l0002Uooooo`006Oooool00ol0003o
ooooooooo`1Oooooo`?o0000X_ooool001Wooooo00?o0000ooooooooool0H_ooool3o`0009oooooo
000Iooooo`03o`000?oooooooooo06Gooooo0ol0002Looooo`006Oooool00ol0003oooooooooo`1X
ooooo`?o0000VOooool001Wooooo00?o0000ooooooooool0Joooool4o`0009Gooooo0009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06oooooo0ol0002Booooo`002?ooool00ol0003oooooo`000007ooooo`?o0000
1?ooool2o`0007?ooooo0ol0002?ooooo`002?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool0MOooool5o`0008[ooooo0008ooooo`03o`000?oooooo
000000Sooooo0_l00004ooooo`03o`000?oooooooooo07[ooooo1Ol00025ooooo`002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ooooool7o`00
07kooooo000Iooooo`03o`000?oooooooooo08Kooooo2_l0001dooooo`006Oooool00ol0003ooooo
ooooo`2@ooooo`[o0000J_ooool001Wooooo00?o0000ooooooooool0V_ooool:o`00063ooooo000I
ooooo`;o0000YOooool:o`0005Kooooo000Iooooo`03o`000?oooooooooo0:kooooo5Ol00011oooo
o`006Oooool00ol0003oooooooooo`33ooooobSo00006Oooool001Wooooo00?o0000ooooooooool0
joooool5o`0001Cooooo000Iooooo`03o`000?oooooooooo0?oooooo1Oooool001Wooooo00?o0000
ooooooooool0ooooool5ooooo`006Oooool00ol0003oooooooooo`3oooooo`Gooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo002;ooooo`?o0000T_ooool008co
oooo00?o0000ooooooooool0TOooool008;ooooo0ol00002ooooo`03o`000?oooooo000000;ooooo
0ol00002ooooo`?o00000_ooool3o`0000Kooooo0ol0001nooooo`00Poooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07gooooo0023ooooo`07o`000?oooooo
ooooooooool0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O?ooool008?ooooo00?o0000oooo
ooooool01?l000000ooooooo0000o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l0
0008ooooo`03o`000?oooooooooo07cooooo0022ooooo`?o00004Oooool00ol0003oooooooooo`06
ooooo`?o0000O_ooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1041.88, -0.029704, 41.301, \
0.00286236}},
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Clearly, a forward-path compensator that would reduce the interaction in \
loop 2 is needed, and a pseudo-diagonalizing compensator algorithm has been \
implemented that allows a different frequency value to be applied to each \
individual column in the resulting system, if desired (see ",
  ButtonBox["Section\[NonBreakingSpace]5.2",
    ButtonData:>"PCS5.2",
    ButtonStyle->"AddOnsLinkText"],
  "). The compensators determined using this algorithm are always real."
}], "Text",
  CellTags->"2.5"],

Cell["\<\
This determines a series forward-path constant compensator that \
will reduce the interaction in loop 2, by applying the pseudo-diagonalizing \
algorithm to both column 1 and column 2 at zero frequency.\
\>", "MathCaption",\

  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(comp1\  = \ 
      PseudodiagonalizingCompensator[fp, 0, Method \[Rule] QNorm]\)], "Input",\

  CellLabel->"In[37]:=",
  CellTags->"2.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"16.901899285589824`", \(-74.92594528663528`\)},
                    {\(-7.579717720857292`\), "43.91008886565602`"}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox["\[Bullet]",
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[37]=",
  CellTags->"2.5"]
}, Open  ]],

Cell["\<\
This connects the compensator in series with the existing \
forward-path system model.\
\>", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(q\  = \ Together /@ SeriesConnect[comp1, fp] // Chop\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->"2.5"],

Cell[BoxData[
    FormBox[
      TagBox[
        FormBox[
          SubsuperscriptBox[
            FormBox[
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(\(\(-117.12869576581284`\)\ \[ScriptS]\^3 - 
                            106.4806325143753`\ \[ScriptS]\^2 + 
                            18.84448510193414`\ \[ScriptS] + 
                            1.0000000000000004`\)\/\(\((3.3`\ \[ScriptS] + \
1.`)\)\^3\ \((12.`\ \[ScriptS] + 1.`)\)\ \((1800.`\ \[ScriptS] + 
                                1.`)\)\)\), \(\(678.5386513329845`\ \
\[ScriptS]\^3 + 616.8533193936222`\ \[ScriptS]\^2 - 
                            39.65081024568744`\ \[ScriptS]\)\/\(\((3.3`\ \
\[ScriptS] + 1.`)\)\^3\ \((12.`\ \[ScriptS] + 1.`)\)\ \((1800.`\ \[ScriptS] + 
                                1.`)\)\)\)},
                    {\(\(\(-11906.560690277052`\)\ \[ScriptS]\^3 - 
                            1411.8451411395713`\ \[ScriptS]\^2 - 
                            46.981364349189754`\ \[ScriptS]\)\/\(\((12.`\ \
\[ScriptS] + 1.`)\)\ \((25.3`\ \[ScriptS] + 1.`)\)\^3\ \((360.`\ \[ScriptS] + 
                                1.`)\)\)\), \(\(68975.9377919498`\ \[ScriptS]\
\^3 + 8178.9649555671685`\ \[ScriptS]\^2 + 284.1679038159957`\ \[ScriptS] + 
                            0.9999999999999991`\)\/\(\((12.`\ \[ScriptS] + 
                                1.`)\)\ \((25.3`\ \[ScriptS] + 1.`)\)\^3\ \
\((360.`\ \[ScriptS] + 1.`)\)\)\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left},
                  AllowScriptLevelChange->False], "\[NoBreak]", ")"}],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[InvisibleSpace]\"\>",
                ShowStringCharacters->False],
              "TraditionalForm"], 
            FormBox[
              StyleBox["\<\"\[ScriptCapitalT]\"\>",
                Editable->False,
                ShowStringCharacters->False],
              "TraditionalForm"],
            MultilineFunction->None],
          "TraditionalForm"],
        (TransferFunction[ s, 
          SlotSequence[ 1]]&)], TraditionalForm]], "Output",
  CellLabel->"Out[38]=",
  CellTags->"2.5"]
}, Open  ]],

Cell["\<\
This is the resulting Nyquist array plot for the system, using the \
Gershgorin circles for column dominance.\
\>", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(NyquistArrayPlot[q, 
        GershgorinCircles \[Rule] ColumnDominance];\)\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->"2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5316 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0126572 0.47619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .5316 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .5316 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .5316 L
s
0 .5316 m
1 .5316 L
s
1 0 m
1 .5316 L
s
0 0 m
1 0 L
1 .5316 L
0 .5316 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0126572 0.477324 0.253746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.120679 0.85038 0.460702 0.85038 [
[.29076 .4482 -7.2 -7.2 ]
[.29076 .4482 7.2 0 ]
[.46083 .4482 -7.2 -7.2 ]
[.46083 .4482 7.2 0 ]
[.63091 .4482 -7.2 -7.2 ]
[.63091 .4482 7.2 0 ]
[.80098 .4482 -7.2 -7.2 ]
[.80098 .4482 7.2 0 ]
[.97106 .4482 -2.4 -7.2 ]
[.97106 .4482 2.4 0 ]
[.10818 .03551 -19.2 -3.6 ]
[.10818 .03551 0 3.6 ]
[.10818 .12055 -19.2 -3.6 ]
[.10818 .12055 0 3.6 ]
[.10818 .20559 -19.2 -3.6 ]
[.10818 .20559 0 3.6 ]
[.10818 .29063 -19.2 -3.6 ]
[.10818 .29063 0 3.6 ]
[.10818 .37566 -19.2 -3.6 ]
[.10818 .37566 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .5316 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29076 .4607 m
.29076 .46695 L
s
[(0.2)] .29076 .4482 0 1 Mshowa
.46083 .4607 m
.46083 .46695 L
s
[(0.4)] .46083 .4482 0 1 Mshowa
.63091 .4607 m
.63091 .46695 L
s
[(0.6)] .63091 .4482 0 1 Mshowa
.80098 .4607 m
.80098 .46695 L
s
[(0.8)] .80098 .4482 0 1 Mshowa
.97106 .4607 m
.97106 .46695 L
s
[(1)] .97106 .4482 0 1 Mshowa
.125 Mabswid
.1632 .4607 m
.1632 .46445 L
s
.20572 .4607 m
.20572 .46445 L
s
.24824 .4607 m
.24824 .46445 L
s
.33327 .4607 m
.33327 .46445 L
s
.37579 .4607 m
.37579 .46445 L
s
.41831 .4607 m
.41831 .46445 L
s
.50335 .4607 m
.50335 .46445 L
s
.54587 .4607 m
.54587 .46445 L
s
.58839 .4607 m
.58839 .46445 L
s
.67343 .4607 m
.67343 .46445 L
s
.71595 .4607 m
.71595 .46445 L
s
.75846 .4607 m
.75846 .46445 L
s
.8435 .4607 m
.8435 .46445 L
s
.88602 .4607 m
.88602 .46445 L
s
.92854 .4607 m
.92854 .46445 L
s
.07816 .4607 m
.07816 .46445 L
s
.03564 .4607 m
.03564 .46445 L
s
.25 Mabswid
0 .4607 m
1 .4607 L
s
.12068 .03551 m
.12693 .03551 L
s
[(-0.5)] .10818 .03551 1 0 Mshowa
.12068 .12055 m
.12693 .12055 L
s
[(-0.4)] .10818 .12055 1 0 Mshowa
.12068 .20559 m
.12693 .20559 L
s
[(-0.3)] .10818 .20559 1 0 Mshowa
.12068 .29063 m
.12693 .29063 L
s
[(-0.2)] .10818 .29063 1 0 Mshowa
.12068 .37566 m
.12693 .37566 L
s
[(-0.1)] .10818 .37566 1 0 Mshowa
.125 Mabswid
.12068 .05252 m
.12443 .05252 L
s
.12068 .06953 m
.12443 .06953 L
s
.12068 .08653 m
.12443 .08653 L
s
.12068 .10354 m
.12443 .10354 L
s
.12068 .13756 m
.12443 .13756 L
s
.12068 .15456 m
.12443 .15456 L
s
.12068 .17157 m
.12443 .17157 L
s
.12068 .18858 m
.12443 .18858 L
s
.12068 .2226 m
.12443 .2226 L
s
.12068 .2396 m
.12443 .2396 L
s
.12068 .25661 m
.12443 .25661 L
s
.12068 .27362 m
.12443 .27362 L
s
.12068 .30763 m
.12443 .30763 L
s
.12068 .32464 m
.12443 .32464 L
s
.12068 .34165 m
.12443 .34165 L
s
.12068 .35866 m
.12443 .35866 L
s
.12068 .39267 m
.12443 .39267 L
s
.12068 .40968 m
.12443 .40968 L
s
.12068 .42669 m
.12443 .42669 L
s
.12068 .44369 m
.12443 .44369 L
s
.12068 .0185 m
.12443 .0185 L
s
.12068 .0015 m
.12443 .0015 L
s
.12068 .47771 m
.12443 .47771 L
s
.12068 .49472 m
.12443 .49472 L
s
.12068 .51172 m
.12443 .51172 L
s
.12068 .52873 m
.12443 .52873 L
s
.25 Mabswid
.12068 0 m
.12068 .5316 L
s
0 0 m
1 0 L
1 .5316 L
0 .5316 L
closepath
clip
newpath
.5 Mabswid
.12051 .45671 m
.12049 .45648 L
.12047 .45622 L
.12044 .45596 L
.12041 .45568 L
.12038 .45538 L
.12035 .45507 L
.12031 .45473 L
.12026 .45438 L
.12021 .45401 L
.12015 .45361 L
.12009 .45319 L
.12001 .45275 L
.11993 .45228 L
.11984 .45179 L
.11974 .45127 L
.11963 .45072 L
.1195 .45013 L
.11935 .44952 L
.11919 .44887 L
.11901 .44819 L
.11881 .44747 L
.11859 .44671 L
.11833 .44591 L
.11805 .44507 L
.11774 .44419 L
.11739 .44326 L
.11699 .44229 L
.11656 .44128 L
.11607 .44022 L
.11553 .43911 L
.11492 .43796 L
.11425 .43676 L
.11351 .43552 L
.11269 .43423 L
.11177 .43291 L
.11077 .43155 L
.10966 .43016 L
.10844 .42874 L
.1071 .42731 L
.10563 .42587 L
.10403 .42443 L
.10229 .42299 L
.10039 .42159 L
.09835 .42022 L
.09615 .41891 L
.09378 .41767 L
.09126 .41652 L
.08858 .41548 L
.08574 .41458 L
Mistroke
.08276 .41384 L
.07964 .41327 L
.0764 .41289 L
.07306 .41274 L
.06963 .41281 L
.06614 .41314 L
.06261 .41373 L
.05907 .41459 L
.05555 .41573 L
.05207 .41715 L
.04867 .41885 L
.04538 .42082 L
.04221 .42306 L
.0392 .42556 L
.03637 .4283 L
.03374 .43126 L
.03133 .43444 L
.02916 .43781 L
.02723 .44136 L
.02557 .44506 L
.02418 .4489 L
.02308 .45286 L
.02226 .45692 L
.02174 .46106 L
.02153 .46527 L
.02162 .46952 L
.02203 .47381 L
.02277 .47811 L
.02383 .48239 L
.02522 .48665 L
.02695 .49085 L
.02902 .49498 L
.03144 .499 L
.0342 .50288 L
.0373 .5066 L
.04074 .51013 L
.0445 .51341 L
.04858 .51642 L
.05295 .51912 L
.05758 .52147 L
.06245 .52344 L
.06751 .52499 L
.07271 .52608 L
.078 .52671 L
.08332 .52685 L
.08861 .5265 L
.09379 .52566 L
.09882 .52436 L
.10361 .52261 L
.10812 .52046 L
Mistroke
.11229 .51796 L
.11609 .51516 L
.11948 .51212 L
.12245 .50892 L
.12499 .50561 L
.12711 .50225 L
.12883 .49892 L
.13018 .49565 L
.13118 .49248 L
.13187 .48946 L
.13229 .4866 L
.13249 .48393 L
.13249 .48145 L
.13233 .47916 L
.13204 .47708 L
.13166 .47518 L
.1312 .47346 L
.1307 .47192 L
.13015 .47053 L
.12959 .4693 L
.12902 .4682 L
.12845 .46722 L
.1279 .46636 L
.12735 .4656 L
.12683 .46494 L
.12633 .46436 L
.12586 .46385 L
.12542 .4634 L
.125 .46302 L
.12461 .46269 L
.12425 .4624 L
.12392 .46215 L
.12361 .46194 L
.12333 .46175 L
.12307 .4616 L
.12283 .46146 L
.12262 .46135 L
.12242 .46125 L
.12224 .46116 L
.12208 .46109 L
.12194 .46103 L
.12181 .46098 L
.12169 .46094 L
.12158 .4609 L
.12149 .46087 L
.1214 .46084 L
.12133 .46082 L
.12126 .4608 L
.1212 .46079 L
.12114 .46077 L
Mistroke
.12109 .46076 L
.12105 .46075 L
.12101 .46074 L
.12097 .46074 L
.12094 .46073 L
.12091 .46073 L
.12089 .46072 L
.12086 .46072 L
.12084 .46072 L
.12083 .46071 L
.12081 .46071 L
.1208 .46071 L
.12078 .46071 L
.12077 .46071 L
.12076 .46071 L
.12075 .46071 L
.12075 .46071 L
.12074 .4607 L
.12073 .4607 L
.12073 .4607 L
.12072 .4607 L
.12072 .4607 L
.12071 .4607 L
.12071 .4607 L
.12071 .4607 L
.1207 .4607 L
.1207 .4607 L
.1207 .4607 L
.1207 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0126572 0.97619 0.253746 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.120679 0.85038 0.460702 0.85038 [
[.29076 .4482 -7.2 -7.2 ]
[.29076 .4482 7.2 0 ]
[.46083 .4482 -7.2 -7.2 ]
[.46083 .4482 7.2 0 ]
[.63091 .4482 -7.2 -7.2 ]
[.63091 .4482 7.2 0 ]
[.80098 .4482 -7.2 -7.2 ]
[.80098 .4482 7.2 0 ]
[.97106 .4482 -2.4 -7.2 ]
[.97106 .4482 2.4 0 ]
[.10818 .03551 -19.2 -3.6 ]
[.10818 .03551 0 3.6 ]
[.10818 .12055 -19.2 -3.6 ]
[.10818 .12055 0 3.6 ]
[.10818 .20559 -19.2 -3.6 ]
[.10818 .20559 0 3.6 ]
[.10818 .29063 -19.2 -3.6 ]
[.10818 .29063 0 3.6 ]
[.10818 .37566 -19.2 -3.6 ]
[.10818 .37566 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .5316 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29076 .4607 m
.29076 .46695 L
s
[(0.2)] .29076 .4482 0 1 Mshowa
.46083 .4607 m
.46083 .46695 L
s
[(0.4)] .46083 .4482 0 1 Mshowa
.63091 .4607 m
.63091 .46695 L
s
[(0.6)] .63091 .4482 0 1 Mshowa
.80098 .4607 m
.80098 .46695 L
s
[(0.8)] .80098 .4482 0 1 Mshowa
.97106 .4607 m
.97106 .46695 L
s
[(1)] .97106 .4482 0 1 Mshowa
.125 Mabswid
.1632 .4607 m
.1632 .46445 L
s
.20572 .4607 m
.20572 .46445 L
s
.24824 .4607 m
.24824 .46445 L
s
.33327 .4607 m
.33327 .46445 L
s
.37579 .4607 m
.37579 .46445 L
s
.41831 .4607 m
.41831 .46445 L
s
.50335 .4607 m
.50335 .46445 L
s
.54587 .4607 m
.54587 .46445 L
s
.58839 .4607 m
.58839 .46445 L
s
.67343 .4607 m
.67343 .46445 L
s
.71595 .4607 m
.71595 .46445 L
s
.75846 .4607 m
.75846 .46445 L
s
.8435 .4607 m
.8435 .46445 L
s
.88602 .4607 m
.88602 .46445 L
s
.92854 .4607 m
.92854 .46445 L
s
.07816 .4607 m
.07816 .46445 L
s
.03564 .4607 m
.03564 .46445 L
s
.25 Mabswid
0 .4607 m
1 .4607 L
s
.12068 .03551 m
.12693 .03551 L
s
[(-0.5)] .10818 .03551 1 0 Mshowa
.12068 .12055 m
.12693 .12055 L
s
[(-0.4)] .10818 .12055 1 0 Mshowa
.12068 .20559 m
.12693 .20559 L
s
[(-0.3)] .10818 .20559 1 0 Mshowa
.12068 .29063 m
.12693 .29063 L
s
[(-0.2)] .10818 .29063 1 0 Mshowa
.12068 .37566 m
.12693 .37566 L
s
[(-0.1)] .10818 .37566 1 0 Mshowa
.125 Mabswid
.12068 .05252 m
.12443 .05252 L
s
.12068 .06953 m
.12443 .06953 L
s
.12068 .08653 m
.12443 .08653 L
s
.12068 .10354 m
.12443 .10354 L
s
.12068 .13756 m
.12443 .13756 L
s
.12068 .15456 m
.12443 .15456 L
s
.12068 .17157 m
.12443 .17157 L
s
.12068 .18858 m
.12443 .18858 L
s
.12068 .2226 m
.12443 .2226 L
s
.12068 .2396 m
.12443 .2396 L
s
.12068 .25661 m
.12443 .25661 L
s
.12068 .27362 m
.12443 .27362 L
s
.12068 .30763 m
.12443 .30763 L
s
.12068 .32464 m
.12443 .32464 L
s
.12068 .34165 m
.12443 .34165 L
s
.12068 .35866 m
.12443 .35866 L
s
.12068 .39267 m
.12443 .39267 L
s
.12068 .40968 m
.12443 .40968 L
s
.12068 .42669 m
.12443 .42669 L
s
.12068 .44369 m
.12443 .44369 L
s
.12068 .0185 m
.12443 .0185 L
s
.12068 .0015 m
.12443 .0015 L
s
.12068 .47771 m
.12443 .47771 L
s
.12068 .49472 m
.12443 .49472 L
s
.12068 .51172 m
.12443 .51172 L
s
.12068 .52873 m
.12443 .52873 L
s
.25 Mabswid
.12068 0 m
.12068 .5316 L
s
0 0 m
1 0 L
1 .5316 L
0 .5316 L
closepath
clip
newpath
.5 Mabswid
.97066 .44679 m
.97061 .44597 L
.97056 .44509 L
.97049 .44416 L
.97043 .44318 L
.97035 .44214 L
.97026 .44104 L
.97016 .43987 L
.97005 .43864 L
.96993 .43733 L
.96979 .43595 L
.96964 .43448 L
.96946 .43294 L
.96927 .4313 L
.96905 .42956 L
.96881 .42773 L
.96853 .42579 L
.96823 .42374 L
.96788 .42157 L
.9675 .41928 L
.96706 .41686 L
.96658 .41431 L
.96604 .41161 L
.96543 .40876 L
.96476 .40577 L
.964 .40261 L
.96316 .39928 L
.96222 .39578 L
.96116 .39209 L
.95999 .38823 L
.95869 .38417 L
.95723 .37991 L
.95562 .37546 L
.95383 .3708 L
.95184 .36594 L
.94964 .36088 L
.94721 .35561 L
.94452 .35014 L
.94157 .34448 L
.93832 .33863 L
.93475 .33261 L
.93085 .32643 L
.9266 .3201 L
.92198 .31364 L
.91696 .30709 L
.91154 .30045 L
.90571 .29377 L
.89946 .28708 L
.89278 .2804 L
.88568 .27378 L
Mistroke
.87818 .26724 L
.87027 .26082 L
.86199 .25456 L
.85336 .24847 L
.84441 .2426 L
.83518 .23695 L
.82571 .23154 L
.81603 .22637 L
.80621 .22143 L
.79627 .21673 L
.78625 .21223 L
.7762 .20791 L
.76614 .20373 L
.75609 .19966 L
.74607 .19564 L
.73609 .19164 L
.72614 .18759 L
.71621 .18345 L
.70628 .17918 L
.69631 .17472 L
.68626 .17004 L
.67609 .16511 L
.66573 .15989 L
.65512 .15437 L
.6442 .14855 L
.63288 .14242 L
.6211 .13601 L
.60876 .12933 L
.59579 .12243 L
.58212 .11536 L
.56765 .1082 L
.55233 .10104 L
.53609 .09396 L
.51888 .08711 L
.50065 .0806 L
.4814 .07459 L
.46113 .06923 L
.43985 .06471 L
.41763 .06119 L
.39456 .05885 L
.37074 .05786 L
.34635 .05838 L
.32156 .06056 L
.29659 .0645 L
.27169 .07029 L
.24712 .07795 L
.22317 .08748 L
.2001 .09882 L
.17819 .11185 L
.15768 .12641 L
Mistroke
.13878 .1423 L
.12167 .15927 L
.10646 .17706 L
.09323 .19538 L
.08198 .21397 L
.07268 .23254 L
.06525 .25084 L
.05957 .26867 L
.05549 .28584 L
.05285 .3022 L
.05146 .31765 L
.05114 .3321 L
.05174 .34554 L
.05308 .35794 L
.05502 .3693 L
.05741 .37967 L
.06016 .38909 L
.06315 .39759 L
.0663 .40524 L
.06954 .41209 L
.0728 .41821 L
.07605 .42366 L
.07923 .42848 L
.08233 .43275 L
.08531 .4365 L
.08815 .4398 L
.09085 .44269 L
.0934 .4452 L
.09579 .4474 L
.09802 .4493 L
.10009 .45094 L
.102 .45237 L
.10377 .45359 L
.1054 .45464 L
.10688 .45555 L
.10824 .45632 L
.10948 .45698 L
.11061 .45755 L
.11163 .45803 L
.11256 .45844 L
.11339 .45879 L
.11415 .45908 L
.11483 .45933 L
.11544 .45955 L
.11599 .45973 L
.11649 .45988 L
.11693 .46001 L
.11733 .46012 L
.11769 .46021 L
.11801 .46029 L
Mistroke
.11829 .46035 L
.11855 .46041 L
.11878 .46045 L
.11898 .46049 L
.11917 .46053 L
.11933 .46055 L
.11948 .46058 L
.11961 .4606 L
.11972 .46061 L
.11983 .46063 L
.11992 .46064 L
.12 .46065 L
.12008 .46066 L
.12014 .46066 L
.1202 .46067 L
.12025 .46068 L
.1203 .46068 L
.12034 .46068 L
.12038 .46069 L
.12041 .46069 L
.12044 .46069 L
.12047 .46069 L
.12049 .46069 L
.12051 .4607 L
.12053 .4607 L
.12054 .4607 L
.12056 .4607 L
.12057 .4607 L
.12058 .4607 L
.12059 .4607 L
.1206 .4607 L
.12061 .4607 L
.12062 .4607 L
.12063 .4607 L
.12063 .4607 L
.12064 .4607 L
.12064 .4607 L
.12065 .4607 L
.12065 .4607 L
.12065 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
Mistroke
Mfstroke
newpath
.97066 .44679 .00332 0 365.73 arc
s
newpath
.97035 .44214 .00438 0 365.73 arc
s
newpath
.96979 .43595 .00573 0 365.73 arc
s
newpath
.96881 .42773 .00738 0 365.73 arc
s
newpath
.96706 .41686 .00931 0 365.73 arc
s
newpath
.964 .40261 .01138 0 365.73 arc
s
newpath
.95869 .38417 .01338 0 365.73 arc
s
newpath
.94964 .36088 .01511 0 365.73 arc
s
newpath
.93475 .33261 .01642 0 365.73 arc
s
newpath
.91154 .30045 .01733 0 365.73 arc
s
newpath
.87818 .26724 .01791 0 365.73 arc
s
newpath
.83518 .23695 .01826 0 365.73 arc
s
newpath
.78625 .21223 .01847 0 365.73 arc
s
newpath
.73609 .19164 .01859 0 365.73 arc
s
newpath
.68626 .17004 .01868 0 365.73 arc
s
newpath
.63288 .14242 .01874 0 365.73 arc
s
newpath
.56765 .1082 .0188 0 365.73 arc
s
newpath
.4814 .07459 .01888 0 365.73 arc
s
newpath
.37074 .05786 .01901 0 365.73 arc
s
newpath
.24712 .07795 .01921 0 365.73 arc
s
newpath
.13878 .1423 .0195 0 365.73 arc
s
newpath
.07268 .23254 .01988 0 365.73 arc
s
newpath
.05146 .31765 .02025 0 365.73 arc
s
newpath
.05741 .37967 .02038 0 365.73 arc
s
newpath
.0728 .41821 .01989 0 365.73 arc
s
newpath
.08815 .4398 .0184 0 365.73 arc
s
newpath
.10009 .45094 .01574 0 365.73 arc
s
newpath
.10824 .45632 .01216 0 365.73 arc
s
newpath
.11339 .45879 .00837 0 365.73 arc
s
newpath
.11649 .45988 .00515 0 365.73 arc
s
newpath
.11829 .46035 .00291 0 365.73 arc
s
newpath
.11933 .46055 .00156 0 365.73 arc
s
newpath
.11992 .46064 .00082 0 365.73 arc
s
newpath
.12025 .46068 .00043 0 365.73 arc
s
newpath
.12044 .46069 .00023 0 365.73 arc
s
newpath
.12054 .4607 .00013 0 365.73 arc
s
newpath
.1206 .4607 7e-05 0 365.73 arc
s
newpath
.12064 .4607 4e-05 0 365.73 arc
s
newpath
.12066 .4607 2e-05 0 365.73 arc
s
newpath
.12067 .4607 1e-05 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.277855 0.477324 0.518944 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.120679 0.85038 0.460702 0.85038 [
[.29076 .4482 -7.2 -7.2 ]
[.29076 .4482 7.2 0 ]
[.46083 .4482 -7.2 -7.2 ]
[.46083 .4482 7.2 0 ]
[.63091 .4482 -7.2 -7.2 ]
[.63091 .4482 7.2 0 ]
[.80098 .4482 -7.2 -7.2 ]
[.80098 .4482 7.2 0 ]
[.97106 .4482 -2.4 -7.2 ]
[.97106 .4482 2.4 0 ]
[.10818 .03551 -19.2 -3.6 ]
[.10818 .03551 0 3.6 ]
[.10818 .12055 -19.2 -3.6 ]
[.10818 .12055 0 3.6 ]
[.10818 .20559 -19.2 -3.6 ]
[.10818 .20559 0 3.6 ]
[.10818 .29063 -19.2 -3.6 ]
[.10818 .29063 0 3.6 ]
[.10818 .37566 -19.2 -3.6 ]
[.10818 .37566 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .5316 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29076 .4607 m
.29076 .46695 L
s
[(0.2)] .29076 .4482 0 1 Mshowa
.46083 .4607 m
.46083 .46695 L
s
[(0.4)] .46083 .4482 0 1 Mshowa
.63091 .4607 m
.63091 .46695 L
s
[(0.6)] .63091 .4482 0 1 Mshowa
.80098 .4607 m
.80098 .46695 L
s
[(0.8)] .80098 .4482 0 1 Mshowa
.97106 .4607 m
.97106 .46695 L
s
[(1)] .97106 .4482 0 1 Mshowa
.125 Mabswid
.1632 .4607 m
.1632 .46445 L
s
.20572 .4607 m
.20572 .46445 L
s
.24824 .4607 m
.24824 .46445 L
s
.33327 .4607 m
.33327 .46445 L
s
.37579 .4607 m
.37579 .46445 L
s
.41831 .4607 m
.41831 .46445 L
s
.50335 .4607 m
.50335 .46445 L
s
.54587 .4607 m
.54587 .46445 L
s
.58839 .4607 m
.58839 .46445 L
s
.67343 .4607 m
.67343 .46445 L
s
.71595 .4607 m
.71595 .46445 L
s
.75846 .4607 m
.75846 .46445 L
s
.8435 .4607 m
.8435 .46445 L
s
.88602 .4607 m
.88602 .46445 L
s
.92854 .4607 m
.92854 .46445 L
s
.07816 .4607 m
.07816 .46445 L
s
.03564 .4607 m
.03564 .46445 L
s
.25 Mabswid
0 .4607 m
1 .4607 L
s
.12068 .03551 m
.12693 .03551 L
s
[(-0.5)] .10818 .03551 1 0 Mshowa
.12068 .12055 m
.12693 .12055 L
s
[(-0.4)] .10818 .12055 1 0 Mshowa
.12068 .20559 m
.12693 .20559 L
s
[(-0.3)] .10818 .20559 1 0 Mshowa
.12068 .29063 m
.12693 .29063 L
s
[(-0.2)] .10818 .29063 1 0 Mshowa
.12068 .37566 m
.12693 .37566 L
s
[(-0.1)] .10818 .37566 1 0 Mshowa
.125 Mabswid
.12068 .05252 m
.12443 .05252 L
s
.12068 .06953 m
.12443 .06953 L
s
.12068 .08653 m
.12443 .08653 L
s
.12068 .10354 m
.12443 .10354 L
s
.12068 .13756 m
.12443 .13756 L
s
.12068 .15456 m
.12443 .15456 L
s
.12068 .17157 m
.12443 .17157 L
s
.12068 .18858 m
.12443 .18858 L
s
.12068 .2226 m
.12443 .2226 L
s
.12068 .2396 m
.12443 .2396 L
s
.12068 .25661 m
.12443 .25661 L
s
.12068 .27362 m
.12443 .27362 L
s
.12068 .30763 m
.12443 .30763 L
s
.12068 .32464 m
.12443 .32464 L
s
.12068 .34165 m
.12443 .34165 L
s
.12068 .35866 m
.12443 .35866 L
s
.12068 .39267 m
.12443 .39267 L
s
.12068 .40968 m
.12443 .40968 L
s
.12068 .42669 m
.12443 .42669 L
s
.12068 .44369 m
.12443 .44369 L
s
.12068 .0185 m
.12443 .0185 L
s
.12068 .0015 m
.12443 .0015 L
s
.12068 .47771 m
.12443 .47771 L
s
.12068 .49472 m
.12443 .49472 L
s
.12068 .51172 m
.12443 .51172 L
s
.12068 .52873 m
.12443 .52873 L
s
.25 Mabswid
.12068 0 m
.12068 .5316 L
s
0 0 m
1 0 L
1 .5316 L
0 .5316 L
closepath
clip
newpath
.5 Mabswid
.94433 .31218 m
.94116 .30394 L
.93764 .29532 L
.93372 .28631 L
.92937 .27691 L
.92453 .26712 L
.91917 .25696 L
.91324 .24643 L
.90668 .23554 L
.89945 .22432 L
.89148 .2128 L
.88273 .20101 L
.87314 .189 L
.86266 .17682 L
.85124 .16453 L
.83882 .15221 L
.82537 .13995 L
.81086 .12783 L
.79527 .11595 L
.77858 .10444 L
.76079 .0934 L
.74194 .08296 L
.72205 .07325 L
.70118 .06438 L
.67941 .05649 L
.65683 .04967 L
.63356 .04405 L
.60972 .03969 L
.58546 .03668 L
.56094 .03506 L
.53631 .03486 L
.51174 .03607 L
.48739 .0387 L
.46342 .04267 L
.43997 .04795 L
.41719 .05443 L
.39518 .06203 L
.37405 .07063 L
.35388 .08011 L
.33473 .09035 L
.31664 .10123 L
.29965 .11261 L
.28374 .12439 L
.26893 .13645 L
.25519 .14867 L
.24249 .16098 L
.23079 .17327 L
.22004 .18548 L
.21021 .19753 L
.20123 .20938 L
Mistroke
.19305 .22097 L
.18562 .23227 L
.17887 .24324 L
.17277 .25386 L
.16725 .26412 L
.16227 .274 L
.15779 .28349 L
.15375 .2926 L
.15012 .30131 L
.14685 .30965 L
.14392 .3176 L
.1413 .32518 L
.13894 .3324 L
.13683 .33927 L
.13494 .3458 L
.13325 .352 L
.13174 .35788 L
.13039 .36346 L
.12918 .36874 L
.1281 .37375 L
.12713 .37849 L
.12627 .38297 L
.12549 .38721 L
.1248 .39122 L
.12418 .39501 L
.12363 .39859 L
.12313 .40197 L
.12268 .40516 L
.12228 .40817 L
.12192 .41101 L
.12159 .41369 L
.12129 .41622 L
.12102 .4186 L
.12078 .42085 L
.12055 .42297 L
.12034 .42496 L
.12014 .42683 L
.11996 .4286 L
.11979 .43026 L
.11962 .43183 L
.11946 .4333 L
.11931 .43468 L
.11915 .43598 L
.119 .43721 L
.11885 .43836 L
.11869 .43945 L
.11853 .44047 L
.11836 .44144 L
.11819 .44235 L
.11801 .44322 L
Mistroke
.11782 .44404 L
.11763 .44482 L
.11742 .44556 L
.11721 .44628 L
.11699 .44697 L
.11676 .44764 L
.11652 .44829 L
.11628 .44893 L
.11604 .44957 L
.1158 .4502 L
.11555 .45083 L
.11532 .45146 L
.11509 .4521 L
.11488 .45274 L
.11469 .4534 L
.11452 .45406 L
.11438 .45473 L
.11428 .45541 L
.11421 .45609 L
.11419 .45677 L
.11421 .45745 L
.11429 .45811 L
.11441 .45876 L
.11459 .45939 L
.11482 .45999 L
.11509 .46055 L
.11541 .46107 L
.11577 .46153 L
.11617 .46194 L
.11659 .46229 L
.11703 .46258 L
.11748 .46281 L
.11793 .46297 L
.11837 .46306 L
.11879 .4631 L
.11919 .46309 L
.11955 .46303 L
.11988 .46293 L
.12017 .4628 L
.12042 .46265 L
.12062 .46248 L
.12079 .4623 L
.12092 .46213 L
.12101 .46195 L
.12108 .46179 L
.12112 .46164 L
.12114 .4615 L
.12114 .46137 L
.12113 .46126 L
.12112 .46116 L
Mistroke
.12109 .46108 L
.12106 .46101 L
.12103 .46095 L
.121 .4609 L
.12097 .46086 L
.12094 .46083 L
.12091 .4608 L
.12089 .46078 L
.12086 .46077 L
.12084 .46075 L
.12082 .46074 L
.12081 .46073 L
.12079 .46073 L
.12078 .46072 L
.12077 .46072 L
.12076 .46071 L
.12075 .46071 L
.12074 .46071 L
.12073 .46071 L
.12073 .46071 L
.12072 .46071 L
.12072 .4607 L
.12071 .4607 L
.12071 .4607 L
.1207 .4607 L
.1207 .4607 L
.1207 .4607 L
.1207 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12069 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
.12068 .4607 L
Mistroke
Mfstroke
newpath
.94433 .31218 .00399 0 365.73 arc
s
newpath
.92453 .26712 .00533 0 365.73 arc
s
newpath
.89148 .2128 .00711 0 365.73 arc
s
newpath
.83882 .15221 .00948 0 365.73 arc
s
newpath
.76079 .0934 .01262 0 365.73 arc
s
newpath
.65683 .04967 .01677 0 365.73 arc
s
newpath
.53631 .03486 .0222 0 365.73 arc
s
newpath
.41719 .05443 .02918 0 365.73 arc
s
newpath
.31664 .10123 .03794 0 365.73 arc
s
newpath
.24249 .16098 .04846 0 365.73 arc
s
newpath
.19305 .22097 .06029 0 365.73 arc
s
newpath
.16227 .274 .07237 0 365.73 arc
s
newpath
.14392 .3176 .08329 0 365.73 arc
s
newpath
.13325 .352 .09179 0 365.73 arc
s
newpath
.12713 .37849 .09722 0 365.73 arc
s
newpath
.12363 .39859 .09945 0 365.73 arc
s
newpath
.12159 .41369 .09846 0 365.73 arc
s
newpath
.12034 .42496 .09399 0 365.73 arc
s
newpath
.11946 .4333 .0856 0 365.73 arc
s
newpath
.11869 .43945 .0732 0 365.73 arc
s
newpath
.11782 .44404 .05787 0 365.73 arc
s
newpath
.11676 .44764 .04205 0 365.73 arc
s
newpath
.11555 .45083 .02838 0 365.73 arc
s
newpath
.11452 .45406 .01817 0 365.73 arc
s
newpath
.11421 .45745 .01121 0 365.73 arc
s
newpath
.11509 .46055 .00673 0 365.73 arc
s
newpath
.11703 .46258 .00395 0 365.73 arc
s
newpath
.11919 .46309 .00228 0 365.73 arc
s
newpath
.12062 .46248 .0013 0 365.73 arc
s
newpath
.12112 .46164 .00074 0 365.73 arc
s
newpath
.12109 .46108 .00042 0 365.73 arc
s
newpath
.12094 .46083 .00023 0 365.73 arc
s
newpath
.12082 .46074 .00013 0 365.73 arc
s
newpath
.12076 .46071 7e-05 0 365.73 arc
s
newpath
.12072 .46071 4e-05 0 365.73 arc
s
newpath
.1207 .4607 2e-05 0 365.73 arc
s
newpath
.12069 .4607 1e-05 0 365.73 arc
s
newpath
.12069 .4607 1e-05 0 365.73 arc
s
newpath
.12068 .4607 0 0 365.73 arc
s
newpath
.12068 .4607 0 0 365.73 arc
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.277855 0.97619 0.518944 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.120679 0.85038 0.460702 0.85038 [
[.29076 .4482 -7.2 -7.2 ]
[.29076 .4482 7.2 0 ]
[.46083 .4482 -7.2 -7.2 ]
[.46083 .4482 7.2 0 ]
[.63091 .4482 -7.2 -7.2 ]
[.63091 .4482 7.2 0 ]
[.80098 .4482 -7.2 -7.2 ]
[.80098 .4482 7.2 0 ]
[.97106 .4482 -2.4 -7.2 ]
[.97106 .4482 2.4 0 ]
[.10818 .03551 -19.2 -3.6 ]
[.10818 .03551 0 3.6 ]
[.10818 .12055 -19.2 -3.6 ]
[.10818 .12055 0 3.6 ]
[.10818 .20559 -19.2 -3.6 ]
[.10818 .20559 0 3.6 ]
[.10818 .29063 -19.2 -3.6 ]
[.10818 .29063 0 3.6 ]
[.10818 .37566 -19.2 -3.6 ]
[.10818 .37566 0 3.6 ]
[ 0 0 0 0 ]
[ 1 .5316 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.29076 .4607 m
.29076 .46695 L
s
[(0.2)] .29076 .4482 0 1 Mshowa
.46083 .4607 m
.46083 .46695 L
s
[(0.4)] .46083 .4482 0 1 Mshowa
.63091 .4607 m
.63091 .46695 L
s
[(0.6)] .63091 .4482 0 1 Mshowa
.80098 .4607 m
.80098 .46695 L
s
[(0.8)] .80098 .4482 0 1 Mshowa
.97106 .4607 m
.97106 .46695 L
s
[(1)] .97106 .4482 0 1 Mshowa
.125 Mabswid
.1632 .4607 m
.1632 .46445 L
s
.20572 .4607 m
.20572 .46445 L
s
.24824 .4607 m
.24824 .46445 L
s
.33327 .4607 m
.33327 .46445 L
s
.37579 .4607 m
.37579 .46445 L
s
.41831 .4607 m
.41831 .46445 L
s
.50335 .4607 m
.50335 .46445 L
s
.54587 .4607 m
.54587 .46445 L
s
.58839 .4607 m
.58839 .46445 L
s
.67343 .4607 m
.67343 .46445 L
s
.71595 .4607 m
.71595 .46445 L
s
.75846 .4607 m
.75846 .46445 L
s
.8435 .4607 m
.8435 .46445 L
s
.88602 .4607 m
.88602 .46445 L
s
.92854 .4607 m
.92854 .46445 L
s
.07816 .4607 m
.07816 .46445 L
s
.03564 .4607 m
.03564 .46445 L
s
.25 Mabswid
0 .4607 m
1 .4607 L
s
.12068 .03551 m
.12693 .03551 L
s
[(-0.5)] .10818 .03551 1 0 Mshowa
.12068 .12055 m
.12693 .12055 L
s
[(-0.4)] .10818 .12055 1 0 Mshowa
.12068 .20559 m
.12693 .20559 L
s
[(-0.3)] .10818 .20559 1 0 Mshowa
.12068 .29063 m
.12693 .29063 L
s
[(-0.2)] .10818 .29063 1 0 Mshowa
.12068 .37566 m
.12693 .37566 L
s
[(-0.1)] .10818 .37566 1 0 Mshowa
.125 Mabswid
.12068 .05252 m
.12443 .05252 L
s
.12068 .06953 m
.12443 .06953 L
s
.12068 .08653 m
.12443 .08653 L
s
.12068 .10354 m
.12443 .10354 L
s
.12068 .13756 m
.12443 .13756 L
s
.12068 .15456 m
.12443 .15456 L
s
.12068 .17157 m
.12443 .17157 L
s
.12068 .18858 m
.12443 .18858 L
s
.12068 .2226 m
.12443 .2226 L
s
.12068 .2396 m
.12443 .2396 L
s
.12068 .25661 m
.12443 .25661 L
s
.12068 .27362 m
.12443 .27362 L
s
.12068 .30763 m
.12443 .30763 L
s
.12068 .32464 m
.12443 .32464 L
s
.12068 .34165 m
.12443 .34165 L
s
.12068 .35866 m
.12443 .35866 L
s
.12068 .39267 m
.12443 .39267 L
s
.12068 .40968 m
.12443 .40968 L
s
.12068 .42669 m
.12443 .42669 L
s
.12068 .44369 m
.12443 .44369 L
s
.12068 .0185 m
.12443 .0185 L
s
.12068 .0015 m
.12443 .0015 L
s
.12068 .47771 m
.12443 .47771 L
s
.12068 .49472 m
.12443 .49472 L
s
.12068 .51172 m
.12443 .51172 L
s
.12068 .52873 m
.12443 .52873 L
s
.25 Mabswid
.12068 0 m
.12068 .5316 L
s
0 0 m
1 0 L
1 .5316 L
0 .5316 L
closepath
clip
newpath
.5 Mabswid
.12008 .45744 m
.12001 .45726 L
.11993 .45707 L
.11984 .45687 L
.11974 .45666 L
.11963 .45645 L
.11951 .45623 L
.11938 .456 L
.11923 .45576 L
.11907 .45551 L
.11889 .45526 L
.1187 .455 L
.11848 .45474 L
.11825 .45448 L
.11799 .45421 L
.11771 .45394 L
.11741 .45368 L
.11708 .45342 L
.11673 .45316 L
.11636 .45292 L
.11596 .45268 L
.11554 .45246 L
.11509 .45226 L
.11462 .45207 L
.11413 .45191 L
.11363 .45177 L
.1131 .45167 L
.11257 .45159 L
.11202 .45154 L
.11147 .45152 L
.11092 .45154 L
.11037 .45159 L
.10982 .45168 L
.10929 .45179 L
.10876 .45194 L
.10825 .45212 L
.10776 .45232 L
.10728 .45255 L
.10683 .4528 L
.1064 .45306 L
.106 .45335 L
.10562 .45365 L
.10526 .45396 L
.10493 .45428 L
.10462 .4546 L
.10434 .45493 L
.10408 .45526 L
.10384 .4556 L
.10363 .45593 L
.10343 .45627 L
Mistroke
.10325 .4566 L
.10309 .45693 L
.10294 .45726 L
.10281 .45758 L
.10269 .4579 L
.10259 .45822 L
.1025 .45853 L
.10242 .45885 L
.10235 .45916 L
.10229 .45946 L
.10223 .45977 L
.10219 .46007 L
.10216 .46038 L
.10213 .46069 L
.10211 .46099 L
.10209 .4613 L
.10209 .46161 L
.10209 .46193 L
.1021 .46225 L
.10211 .46257 L
.10213 .4629 L
.10216 .46324 L
.1022 .46358 L
.10225 .46394 L
.1023 .4643 L
.10237 .46468 L
.10244 .46506 L
.10253 .46546 L
.10263 .46587 L
.10275 .4663 L
.10287 .46674 L
.10302 .46719 L
.10319 .46767 L
.10337 .46816 L
.10358 .46866 L
.10381 .46919 L
.10407 .46973 L
.10436 .47029 L
.10468 .47086 L
.10504 .47146 L
.10544 .47207 L
.10588 .47269 L
.10637 .47333 L
.10692 .47397 L
.10751 .47462 L
.10817 .47528 L
.10889 .47593 L
.10968 .47658 L
.11055 .47721 L
.11148 .47782 L
Mistroke
.1125 .4784 L
.1136 .47894 L
.11477 .47944 L
.11603 .47987 L
.11737 .48022 L
.11879 .48049 L
.12027 .48066 L
.12182 .48071 L
.12342 .48063 L
.12506 .48041 L
.12672 .48003 L
.12838 .47949 L
.13003 .47878 L
.13163 .47789 L
.13317 .47682 L
.13461 .47557 L
.13594 .47416 L
.13711 .47259 L
.13811 .47088 L
.13892 .46905 L
.1395 .46713 L
.13986 .46515 L
.13996 .46314 L
.13981 .46114 L
.13941 .45919 L
.13877 .45732 L
.1379 .45557 L
.13681 .45398 L
.13555 .45258 L
.13413 .45139 L
.13261 .45043 L
.13101 .44971 L
.12938 .44924 L
.12776 .44902 L
.1262 .44902 L
.12472 .44923 L
.12336 .44963 L
.12213 .45018 L
.12106 .45085 L
.12015 .45161 L
.11941 .45243 L
.11883 .45327 L
.1184 .45411 L
.11811 .45492 L
.11793 .45568 L
.11785 .45639 L
.11786 .45704 L
.11793 .45762 L
.11804 .45813 L
.11819 .45857 L
Mistroke
.11836 .45895 L
.11854 .45927 L
.11873 .45954 L
.11891 .45976 L
.11908 .45995 L
.11925 .4601 L
.1194 .46022 L
.11954 .46032 L
.11967 .4604 L
.11978 .46046 L
.11988 .46051 L
.11998 .46055 L
.12006 .46058 L
.12013 .46061 L
.1202 .46063 L
.12025 .46064 L
.1203 .46065 L
.12035 .46066 L
.12039 .46067 L
.12042 .46068 L
.12045 .46068 L
.12048 .46069 L
.1205 .46069 L
.12052 .46069 L
.12054 .46069 L
.12055 .4607 L
.12057 .4607 L
.12058 .4607 L
.12059 .4607 L
.1206 .4607 L
.12061 .4607 L
.12062 .4607 L
.12062 .4607 L
.12063 .4607 L
.12064 .4607 L
.12064 .4607 L
.12065 .4607 L
.12065 .4607 L
.12065 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12066 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
.12067 .4607 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{379.375, 205.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSize->8,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005k0000cB000`400?l00000o`00003oooooooml
ooooo`00oooooomlooooo`00ool0001lo`00000000?o0000ooooooooool0oooooomhooooo`7o0000
00000ol0003oooooooooo`3oooooogSooooo0Ol000000003o`000?oooooooooo0?ooooooN?ooool1
o`00000000?o0000ooooooooool0oooooomhooooo`7o000000000ol0003oooooooooo`0Kooooo`;o
0000^oooool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool06ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooo
oooo01_ooooo0_l0002kooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo
01_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol00003oooo
o`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3
o`0000Cooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool01_ooool4o`00
0004ooooool0003oooooo`0000Wooooo00Co0000oooooooooooooooo0_l0002Uooooo`Co000000Co
ooooo`000?oooooo00002Oooool00ol0003oooooooooo`02ooooo`;o0000:?ooool2o`0007?ooooo
0Ol000000003o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool3o`0000?ooooo00?o
0000ooooooooool0ZOooool00ol0003oooooo`000007ooooo`?o00001?ooool00ol0003ooooooooo
o`0Uooooo`;o00000_ooool00ol0003oooooooooo`1`ooooo`7o000000000ol0003oooooooooo`0;
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Koooool1o`00000000?o0000oooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`?o00000oooool2o`000:_ooooo00?o0000oooo
ooooool01_ooool3o`0000Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00cooooo0ol0001Pooooo`7o000000000ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool04Oooool4o`0000Sooooo5Ol00006ooooo`05
o`000?ooooooooooooooool00000Goooool1o`00000000?o0000ooooooooool06oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool4o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo0Ol000000003
o`000?oooooooooo01_ooooo0_l0002kooooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooooooo1Ol0000<ooooo`;o00000_ooool2o`0000_ooooo1?l00003ooooo`03o`000?oooooooooo
05cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool04?ooool2o`0000ko
oooo00?o0000ooooooooool01?l0001Nooooo`7o000000000ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool03oooool2o`0000Cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`02ooooo`?o0000G?ooool1o`00000000?o0000ooooooooool06ooo
ool2o`000;_ooooo00?o0000ooooooooool03Oooool2o`000004ooooool0003o0000ooooo`;o0000
8oooool2o`000003ooooool0003o000000?ooooo0ol00005ooooo`?o0000DOooool1o`00000000?o
0000ooooooooool06oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00_ooooo0_l0
0005ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool3o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool0C_ooool1o`00000000?o0000ooooooooool06oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Wooooo0_l0000kooooo`?o00000_ooool0
0ol0003oooooooooo`1>ooooo`7o000000000ol0003oooooooooo`0Kooooo`;o0000^oooool00ol0
003oooooooooo`07ooooo`;o0000?Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo04gooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000[?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`;o0000?oooool01ol0003ooooooooooooooooo0000ooooool00000Coooool1o`00000000?o
0000ooooooooool01_ooool4o`000004ooooool0003oooooo`0000Oooooo0ol00003ooooo`;o0000
YOooool4o`000004ooooool0003oooooo`0000Oooooo0ol00004ooooo`;o00001Oooool00ol0003o
ooooooooo`10ooooo`04o`000?ooooooooooooooo`?o0000C_ooool1o`00000000?o0000oooooooo
ool02oooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool0ZOooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool0
00000_l000000ooooooo0000ooooo`13ooooo`04o`000?oooooo0000o`0000;ooooo0_l00003oooo
o`?o0000A_ooool1o`00000000?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`;o
00000oooool00ol0003oooooooooo`2Yooooo`03o`000?oooooo000000Sooooo0_l00004ooooo`;o
00000oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Cooooo0ol00003ooooo`03
o`000?oooooooooo04?ooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooooooool2o`000:_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000Coooool2o`0000;ooooo00?o0000oooo
ooooool0@oooool1o`00000000?o0000ooooooooool06oooool00ol0003oooooooooo`2iooooo`;o
00000_ooool01?l0003oooooooooool0001=ooooo`03o`000?oooooooooo00;o000000?oooooo`00
0?ooool0@oooool1o`00000000?o0000ooooooooool06oooool00ol0003oooooooooo`2iooooo`;o
000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00;o
oooo0_l00014ooooo`7o000000000ol0003oooooooooo`0Kooooo`;o0000^oooool3o`0000;ooooo
00?o0000ooooooooool0COooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000ol0000looooo`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool00ol0001Aooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo03Wooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0^Ooo
ool2o`0005cooooo0ol00003ooooo`03o`000?oooooooooo03Wooooo0Ol000000003o`000?oooooo
oooo01_ooooo0_l0002iooooo`03o`000?oooooo000005cooooo00?o0000ooooooooool00_l00000
0ooooooo0000ooooo`03ooooo`;o0000=Oooool1o`00000000?o0000ooooooooool06oooool00ol0
003oooooooooo`2gooooo`04o`000?ooooooooooo`0005cooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo00Co0000oooooooooooo0000=?ooool1o`00000000?o0000ooooooooool06oooool0
0ol0003oooooooooo`2gooooo`04o`000?ooooooooooo`0005gooooo0_l000000ooooooo0000o`00
0002ooooo`;o00001?ooool00ol0003oooooooooo`0aooooo`7o000000000ol0003oooooooooo`0K
ooooo`;o0000]oooool01Ol0003ooooooooooooooooo000005oooooo00?o0000ooooooooool00_oo
ool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo037ooooo0Ol000000003o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo06;ooooo00Co0000oooooooooooooooo1?l00003ooooo`Co0000:oooool1o`00000000?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o0000
0oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
oooo0ol00004ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool00oooool2o`000003
ooooool0003ooooo00?ooooo00?o0000ooooooooool0:?ooool1o`00000000?o0000ooooooooool0
1_ooool4o`000004ooooool0003oooooo`0000Wooooo00Co0000oooooooooooooooo0_l0002Uoooo
o`Co000000Coooooo`000?oooooo00002?ooool2o`0000Cooooo0_l0001Tooooo`?o000000?ooooo
o`000?l000000_ooool3o`0000?ooooo00?o0000ooooooooool0:?ooool1o`00000000?o0000oooo
ooooool02oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ZOooool00ol0003oooooo`000005ooooo`Co00001Oooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`0Yoooo
o`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooo
ooooooooo`00002[ooooo`03o`000?oooooo000000?ooooo0_l00002ooooo`?o00001?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`?o00008oooool1o`00
000000?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`?o00000oooool2o`000:_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04o`0000Cooooo00?o0000oooooooo
ool0K?ooool2o`000004ooooool0003o0000ooooo`Co00000oooool00ol0003oooooooooo`0Poooo
o`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:kooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`03ooooo`?o00000_ooool00ol0003oooooooooo`0Pooooo`7o000000000ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo01oooooo0Ol000000003o`000?oooooooooo01_ooooo0_l0002`oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1coooo
o`03o`000?oooooooooo00;ooooo0ol0000Qooooo`7o000000000ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo0:oooooo0_l00002ooooo`;o00001Oooool00ol0003oooooooooo`1dooooo`;o
00000oooool2o`0000;ooooo0ol0000Looooo`7o000000000ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo0;3ooooo0ol00007ooooo`03o`000?oooooooooo07Kooooo1?l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo01Wooooo0Ol000000003o`000?oooooooooo01_ooooo0_l0
002aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0O?ooool2o`0000;ooooo00?o
0000ooooooooool06Oooool1o`00000000?o0000ooooooooool06oooool00ol0003oooooooooo`2_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Noooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo01Sooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000
ooooooooool0[oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07_ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Hooooo`7o000000000ol0003oooooooooo`0K
ooooo`;o0000/?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07cooooo00?o0000
ooooooooool00_l0000Kooooo`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0ol00003ooooo`03o`000?oooooooooo0:[ooooo00Co0000
oooooooooooooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`1looooo`;o000000Go
ooooo`000?l0003o0000ooooo`03o`0001Kooooo0Ol000000003o`000?oooooooooo00Kooooo1?l0
00001?oooooo0000ooooool00008ooooo`03o`000?oooooooooo00;ooooo0_l0002Uooooo`Co0000
00Coooooo`000?oooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo0_l0001oooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Coooo
o`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooo
ooooooooo`00002[ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo08;ooooo0_l00002ooooo`03o`000?oooooooooo
01?ooooo0Ol000000003o`000?oooooooooo00_ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo00000:_ooooo00?o0000ooooool000001?l00005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0POooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo01;ooooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool3o`00
00?ooooo0_l0002[ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`?o00001?ooool00ol0
003oooooooooo`21ooooo`07o`000?ooooooooooooooool0003oooooo`00000Dooooo`7o00000000
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:[ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Wooooo00?o0000ooooooooool0POooool3o`000003ooooool0003o000001Gooooo
0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0Z_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooo000000?o00004_ooool1o`00000000?o0000ooooooooool06oooool2o`000:_ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Q_ooool01Ol0003ooooooooooooooooo0000017ooooo0Ol000000003o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Zoooool2o`000004ooooool0003oooooo`0000Wooooo00?o0000oooooooo
ool0QOooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00oooooo0Ol000000003o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0[Oooool4o`0000Wooooo00?o0000ooooooooool0
QOooool01_l0003oooooooooool0003oooooo`00017ooooo0Ol000000003o`000?oooooooooo01_o
oooo0_l0002_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0QOooool01_l0003o
ooooooooool0003oooooo`00017ooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0[_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Gooooo1ol0000@oooo
o`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`28ooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`7o
000000000ol0003oooooooooo`0Kooooo`;o0000[oooool3o`0000Wooooo00?o0000ooooooooool0
R?ooool01?l0003oooooo`000?ooool2o`0000kooooo0Ol000000003o`000?oooooooooo01_ooooo
00?o0000ooooooooool0[?ooool3o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`28ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool03?ooool1o`00000000?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o0000
0oooool00ol0003oooooooooo`2Zooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?oo
ool00ol00004ooooo`03o`000?oooooooooo08Sooooo0_l000000ooooooo0000o`00000?ooooo`7o
000000000ol0003oooooooooo`06ooooo`Co000000Coooooo`000?oooooo00002?ooool00ol0003o
ooooooooo`02ooooo`;o0000YOooool4o`000004ooooool0003oooooo`0000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Gooooo0_l0002;ooooo`;o000000?oooooo`000?ooool03Ooo
ool1o`00000000?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ZOooool00ol0003oooooo`000003ooooo`06o`000?oooooo
ooooo`000?oooooo00001Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo000000?o0000
3Oooool1o`00000000?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ZOooool01?l0003oooooo`000?l00002ooooo`06o`00
0?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`29ooooo`06o`000?oooooooooo
o`000?oooooo00003Oooool1o`00000000?o0000ooooooooool03?ooool00ol0003oooooooooo`06
ooooo`;o00001?ooool2o`000:_ooooo00?o0000ooooool000001Ol000000ooooooo0000o`000005
ooooo`03o`000?oooooooooo08[ooooo1Ol0000=ooooo`7o000000000ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo0:oooooo1Ol00006ooooo`03o`000?oooooooooo08_ooooo0_l000000ooo
oooo0000ooooo`0<ooooo`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0:oo
oooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Roooool01?l0003o
ooooo`000?l0000=ooooo`7o000000000ol0003oooooooooo`0Aooooo`Co00001_ooool2o`000;3o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08_o
oooo1?l0000=ooooo`7o000000000ol0003oooooooooo`0?ooooo`;o00001?ooool3o`0000?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o
00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0000Eooooo`?o00007_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00004Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol0000Dooooo`Go00003?ooool1o`00000000?o0000ooooooooool03Ooo
ool2o`0000Sooooo0_l00002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000Oooooo0ol0000@ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool000004?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000001Kooooo00?o0000ooooooooool07Oooool01?l0003oooooooooooooool4o`0000Cooooo
00?o0000ooooooooool04oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool000001oooool3o`00013ooooo00?o0000ooooool000001oooool00ol0003ooooo
o`00000@ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000005Oooool3o`0000gooooo
0Ol000000003o`000?oooooooooo00cooooo0_l0000:ooooo`;o000000?oooooo`000?l000005?oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000001ooo
ool00ol0003oooooo`00000@ooooo`03o`000?oooooo000000Oooooo0ol0000@ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo0000013ooooo00?o0000ooooool000001oooool3o`00013ooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0Dooooo`Co00003?ooool1o`00000000?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`?o00005Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool000002?ooool2o`00013ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000005_ooool0
0ol0003oooooooooo`0Nooooo`;o000000?oooooo`000?l000001?l00002ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
000000Sooooo0_l0000@ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooo`000007ooooo`03o`000?oooooo000001Gooooo1?l0000<ooooo`7o000000000ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0_l0000Fooooo`03o`000?oooooooooo
00Kooooo0ol0000Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`;o00004Oooool00ol0003oooooooooo`06ooooo`?o00005Oooool2o`00
02;ooooo0_l000001?oooooo0000ooooooooool2o`000003ooooool0003ooooo01Gooooo00?o0000
ooooooooool01_ooool3o`00017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo0_l0000Aooooo`03o`000?oooooooooo00Kooooo0ol0000E
ooooo`?o00003Oooool1o`00000000?o0000ooooooooool02_ooool2o`0000kooooo0ol0002boooo
o`03o`000?oooooooooo00Oo0000Soooool2o`0000gooooo0Ol000000003o`000?oooooooooo00[o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2booooo`;o000000?oooooo`000?l0
00001?l0002@ooooo`03o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo00Kooooo
[?l0000Aooooojco00002?ooool1o`00000000?o0000ooooooooool02_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Ko00001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool3o`0001[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Uooooo`?o000000?oooooo`000?ooool06oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00_ooooo0Ol000000003o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03_ooool3o`000;[ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo00000;[ooooo00?o0000oooooooo
ool0W?ooool1o`00000000?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooo00000;[ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0=ooooo`?o0000^_ooool00ol0003oooooooooo`2Looooo`7o00000000
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0002kooooo`03o`000?oooooo
oooo09cooooo0Ol000000003o`000?oooooooooo00cooooo0_l0000=ooooo`;o0000^oooool00ol0
003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0=ooooo`;o00003?ooool2o`000;_o
oooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`;o0000_?ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003ooooooooo
o`0@ooooo`?o00001?ooool3o`000003ooooool0003ooooo0;_ooooo00?o0000ooooooooool0W?oo
ool1o`00000000?o0000ooooooooool04oooool4o`0000Cooooo0_l0002kooooo`03o`000?oooooo
oooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`3oooooogSooooo0Ol000000003o`00
0?oooooooooo0?ooooooN?ooool1o`00000000?o0000ooooooooool0oooooomhooooo`7o00000000
0ol0003oooooooooo`3oooooogSooooo0Ol000000003o`000?oooooooooo0?ooooooN?ooool1o`00
000000?o0000ooooooooool0oooooomhooooo`7o000000000ol0003oooooooooo`3oooooogSooooo
0Ol000000003o`000?oooooooooo0?ooooooN?ooool1o`00000000?o0000ooooooooool06oooool2
o`000;_ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool06oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@oooool3o`0007Cooooo00?o0000ooooooooool0W?ooool1o`000000
00?o0000ooooooooool06oooool2o`0004;ooooo0_l00003ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool06oooool00ol0003ooooooooo
o`0_ooooo`?o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00000oooool00ol0003oooooooooo`0]ooooo`;o00000ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003ooooo
ooooo`2Looooo`7o000000000ol0003oooooooooo`06ooooo`Co000000Coooooo`000?oooooo0000
2Oooool01?l0003oooooooooooooool2o`0002gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08oooooa7o00002?ooool4o`0004Wooooo1?l000001?oooooo0000ooooool00009oooo
o`03o`000?oooooooooo00;ooooo0_l0002Mooooo`7o000000000ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000Oooooo0ol00003ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`000008o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`Go00000oooool01Ol0003ooooooooooooooooo000004gooooo00?o0000oooo
ool000001oooool3o`0000Cooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000oooooooo
ool02oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`04ooooo`?o00003?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo1?l00003ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool3o`0000?ooooo0_l0000/ooooo`04o`00
0?ooooooooooooooo`?o00000_ooool2o`0000_ooooo0ol00002ooooo`;o00003_ooool00ol0003o
ooooo`000003o`0004kooooo00?o0000ooooooooool01_ooool3o`0000Cooooo00?o0000oooooooo
ool0W?ooool1o`00000000?o0000ooooooooool06oooool00ol0003oooooooooo`0[ooooo`04o`00
0?oooooo0000o`0000Kooooo00?o0000ooooooooool03?ooool2o`00013ooooo00?o0000oooooooo
ool00_ooool4o`0005_ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Looooo`Go00002Oooool3o`0000Oooooo00?o0000ooooooooool0
7oooool5o`0000Cooooo0ol0001Hooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oo
oooooooo01_ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`?o000000?o
ooooo`000?ooool01oooool00ol0003oooooooooo`0[ooooo`;o0000E_ooool00ol0003ooooooooo
o`2Looooo`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool01_ooool01?l0003oooooooooool00005ooooo`;o00001?ooool2o`00033ooooo0ol0
001Cooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`07ooooo`;o00002?ooool4o`0003Gooooo1Ol0001>
ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo0_l0000Joooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooool00000@oooool01?l0003oooooooooool0001=
ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooo000000;o0000COooool00ol0003oooooooooo`2Looooo`7o000000000ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool2o`0000Go
oooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000004gooooo00?o0000oooo
ooooool0W?ooool1o`00000000?o0000ooooooooool06oooool2o`0001Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo1_l0001;ooooo`03
o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4?ooool4o`0000Cooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo0000013ooooo0_l00004ooooo`?o000000Coooooo`000?oooooo00002Oooool00ol0003o
ooooooooo`19ooooo`;o0000>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003ooooo
ooooo`06ooooo`Co000000Coooooo`000?oooooo00001oooool3o`0000?ooooo0_l0000=ooooo`;o
00002Oooool3o`0000[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0_ooooo`Co
000000Coooooo`000?oooooo00001oooool3o`0000Cooooo0_l0002Mooooo`7o000000000ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000o`000006ooooo`;o
0000Coooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000000Oooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0;ooooo`03o`00
0?oooooo000000Sooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooo`000003ooooo`;o00000_ooool2o`0005;ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooo`000008ooooo`;o00001?ooool00ol0003oooooooooo`2Looooo`7o0000
00000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo
0_l0000;ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000004ooooo`;o
0000EOooool4o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
FOooool2o`000003ooooool0003ooooo03oooooo00?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool06oooool2o`0000_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Wooooo00Co0000ooooool0003o0000@?ooool00ol0003ooooo
ooooo`2Looooo`7o000000000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo0_l0
00000ooooooo0000ooooo`0oooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01Oooool9o`0000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooo000003oooooo00?o0000ooooooooool0W?ooool1
o`00000000?o0000ooooooooool06oooool2o`0000Gooooo00?o0000ooooooooool00oooool01?l0
003oooooooooooooool2o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2Looooo`7o000000000ol0003oooooooooo`0Kooooo`;o00000_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0W?ooool1o`000000
00?o0000ooooooooool06oooool01?l0003oooooooooool0000;ooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`;o0000IOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo09co
oooo0Ol000000003o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool3o`0000?ooooo00Co0000oooooooooooo00002oooool2o`0000Cooooo00Go0000oooo
ooooooooooooo`00001Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool3o`0000Cooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000
ooooooooool01_ooool4o`000004ooooool0003oooooo`0000Wooooo00Co0000oooooooooooooooo
3Ol00002ooooo`04o`000?oooooo0000o`0000?ooooo0ol0001Zooooo`;o00008_ooool4o`000004
ooooool0003oooooo`0000Wooooo00?o0000ooooooooool00_ooool2o`0009gooooo0Ol000000003
o`000?oooooooooo00_ooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`?o
00002_ooool2o`0000Cooooo1?l0001[ooooo`Co00009_ooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
2oooool00ol0003oooooo`000009ooooo`07o`000?ooooooooooooooool0003oooooo`00000:oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool0JOooool3o`0002Kooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09cooooo0Ol000000003
o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool3o`000003ooooool0003o000000?o
00002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0J_ooool2o`00
02Oooooo00?o0000ooooooooool01_ooool3o`0000Cooooo00?o0000ooooooooool0W?ooool1o`00
000000?o0000ooooooooool06?ooool01_l0003oooooooooool0003oooooo`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00So00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
09cooooo0Ol000000003o`000?oooooooooo01Oooooo00?o0000ooooool000000ol000000ooooooo
0000ooooo`03ooooo`;o000000?oooooo`000?ooool01Oooool01Ol0003ooooooooooooooooo0000
06oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003o
ooooooooo`0Gooooo`;o00000_ooool01?l0003oooooooooool00006ooooo`?o00001Oooool01Ol0
003ooooooooooooooooo0000073ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2L
ooooo`7o000000000ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool0001`ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
001booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000
ooooooooool05Oooool?o`0000Kooooo00Co0000oooooooooooooooo0_l0001cooooo`?o0000<_oo
ool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0Dooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool00oooool5o`0000Cooooo00?o0000ooooool000000_l0001d
ooooo`?o0000<_ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0Coooo
o`Co00001?ooool2o`0000Gooooo0ol000000ooooooo0000ooooo`02ooooo`;o00000_ooool00ol0
003oooooooooo`1cooooo`;o0000<_ooool00ol0003oooooooooo`2Looooo`7o000000000ol0003o
ooooooooo`0Booooo`;o00000_ooool00ol0003oooooooooo`09o`0000?ooooo1Ol000001Ooooooo
0000oooooooooooo000007Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Loooo
o`7o000000000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0ol000000ooooooo
0000o`000002o`0000;ooooo00?o0000ooooooooool00oooool3o`0000Cooooo00Oo0000oooooooo
ooooooooo`000?oooooo000007Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003oooooooooo`2Looooo`7o00000000
0ol0003oooooooooo`06ooooo`Co000000Coooooo`000?oooooo00000oooool6o`0000Cooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0_l0001gooooo`03
o`000?oooooooooo01Wooooo1?l000001?oooooo0000ooooool00008ooooo`03o`000?oooooooooo
00?ooooo0_l0002Mooooo`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oooooo000000?o
oooo0_l00003ooooo`;o000000?oooooo`000?l000001Ol000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09cooooo0Ol000000003o`000?oooooooooo00_ooooo00?o0000ooooool000000_ooool2o`0000?o
oooo1?l00002ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`;o00000_ooool01?l0003o
ooooooooool0001iooooo`03o`000?oooooooooo01gooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo00co
oooo00Go0000oooooooooooo0000ooooo`08o`0000;ooooo0_l00002ooooo`04o`000?oooooooooo
ooooo`;o00000oooool01_l0003oooooooooool0003oooooo`0007Wooooo0_l0000Oooooo`03o`00
0?oooooooooo00Kooooo0ol00004ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oo
oooooooo00oooooo0ol00005ooooo`Wo00001Oooool01_l0003ooooooooooooooooo0000ooooo`?o
0000NOooool2o`0002oooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool0
3_ooool4o`0000;ooooo0ol00002ooooo`03o`000?oooooo000000?ooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l0002Zooooo`03o`000?oooooooooo09cooooo0Ol000000003o`00
0?oooooooooo00kooooo1_l00006ooooo`?o000000?oooooo`000?ooool00oooool2o`0000;ooooo
00?o0000ooooooooool01?l0002Zooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oo
oooooooo00kooooo0_l000000ooooooo0000ooooo`02ooooo`go00000oooool00ol0003ooooooooo
o`02o`000004ooooool0003o0000o`000:[ooooo00?o0000ooooooooool0W?ooool1o`00000000?o
0000ooooooooool03Oooool2o`000006ooooool0003oooooo`000?oooooo00001_ooool4o`0000?o
oooo0_l00002ooooo`?o00000_ooool3o`000:[ooooo00?o0000ooooooooool0W?ooool1o`000000
00?o0000ooooooooool03?ooool3o`000003ooooool0003ooooo00;o00001oooool;o`000005oooo
ool0003oooooo`000?ooool00ol0002Zooooo`03o`000?oooooooooo09cooooo0Ol000000003o`00
0?oooooooooo00cooooo0_l000000ooooooo0000ooooo`02o`0000;ooooo1ol000000ooooooo0000
ooooo`02o`0000Cooooo00Oo0000oooooooooooo0000ooooool0003ooooo00;o0000Z_ooool00ol0
003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0<ooooo`?o000000Coooooo`000?oo
oooooooo0_l00006ooooo`?o00000oooool2o`0000?ooooo00Ko0000ooooool0003oooooo`000?oo
ool2o`000:[ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool03?ooool2
o`000004ooooool0003oooooooooo`;o00001oooool00ol0003oooooo`000005ooooo`08o`000?oo
ooooooooooooool0003oooooo`000?ooool3o`000:[ooooo00?o0000ooooooooool0W?ooool1o`00
000000?o0000ooooooooool03?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00co
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`0009[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooooooool3o`0000Cooooo00?o0000ooooooooool0W?oo
ool1o`00000000?o0000ooooooooool01_ooool4o`000003ooooool0003o000000;o000000?ooooo
o`000?ooool00_ooool3o`0000Cooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`02
o`000004ooooool0003o0000o`0009Cooooo1?l000001?oooooo0000ooooool00008ooooo`03o`00
0?oooooooooo00?ooooo0_l0002Mooooo`7o000000000ol0003oooooooooo`0;ooooo`03o`000?oo
oooo000000;o00000oooool01?l0003oooooooooool00004ooooo`;o00001Oooool01_l0003ooooo
oooooooooooo0000ooooo`;o000000Coooooo`000?l0003o0000VOooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000oooo
ooooool02oooool5o`0000;ooooo00Co0000oooooooooooooooo2Ol00004ooooo`03o`000?oooooo
oooo00;o000000?oooooo`000?ooool00ol0002Iooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2Looooo`7o000000000ol0003oooooooooo`0;oooo
o`;o000000?oooooo`000?l000000_ooool00ol0003oooooooooo`03o`000003ooooool0003o0000
00;o00000_ooool2o`0000?ooooo0_l00002ooooo`04o`000?oooooo0000ooooo`;o0000V_ooool0
0ol0003oooooooooo`06ooooo`;o00001Oooool00ol0003oooooooooo`2Looooo`7o000000000ol0
003oooooooooo`0:ooooo`?o000000?oooooo`000?ooool00_l00002ooooo`03o`000?oooooooooo
00Cooooo1?l000000ooooooo0000o`000004o`0000;ooooo00?o0000ooooool000000_l0002[oooo
o`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo00[ooooo0ol000001?oooooo
0000ooooool00003ooooo`03o`000?oooooooooo00?ooooo1?l000001?oooooo0000ooooool00004
ooooo`03o`000?oooooooooo00Co0000Zoooool00ol0003oooooooooo`2Looooo`7o000000000ol0
003oooooooooo`0:ooooo`Co000000Koooooo`000?oooooo0000ooooool00003ooooo`?o000000Go
ooooo`000?l0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooo`000?l0002[ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo00[o
oooo1?l000001?oooooo0000ooooooooool2o`0000;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`00
002[ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo00[ooooo1?l00000
1?oooooo0000ooooooooool2o`000004ooooool0003oooooooooo`Co00001?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?oooooo0000ooooo`;o00001Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooooooo`?o00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0ol0
000Eooooo`?o0000:_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0ol0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`00017ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool3o`0001Go
oooo0ol0000=ooooo`7o000000000ol0003oooooooooo`0:ooooo`?o000000Goooooo`000?l0003o
ooooo`000002ooooo`Co00000oooool3o`0000;ooooo00Co0000oooooooooooooooo1?l000000ooo
oooo0000o`000002o`0000Cooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooo000000Oooooo0ol0000@ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ool000004?ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000001Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooo`000007ooooo`?o00004?ooool00ol0003oooooo`000007oooo
o`03o`000?oooooo0000013ooooo00?o0000ooooool000001oooool00ol0003oooooo`00000Foooo
o`03o`000?oooooooooo00cooooo0Ol000000003o`000?oooooooooo00[ooooo0ol000001Ooooooo
0000oooooooooooo000000;ooooo00?o0000ooooooooool00ol000001Ooooooo0000oooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000003o`0000Cooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000004?ooool00ol0003oooooo`000007ooooo`?o00004?ooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooo0000013ooooo00?o0000ooooool000001oooool3o`00013ooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00cooooo0Ol0
00000003o`000?oooooooooo00_ooooo0_l000001ooooooo0000o`000?oooooo0000ooooool00000
0_ooool00ol0003oooooo`000003o`0000;ooooo00?o0000ooooooooool01?l00002ooooo`03o`00
0?oooooo000000?o00001?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool000002?ooool2o`00013ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000005_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooo000000Sooooo0_l0000@ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000001Kooooo
00?o0000ooooooooool03?ooool1o`00000000?o0000ooooooooool02oooool2o`000003ooooool0
003ooooo00;o000000Soooooo`000?ooooooooooo`000?oooooo0000ooooo`So00000_ooool02?l0
003oooooooooool0003oooooo`000?oooooo00001_ooool00ol0003oooooooooo`06ooooo`?o0000
4_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool2o`00017ooooo00?o0000ooooooooool01_ooool3o`0001Gooooo0_l0000[ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01_ooool3o`00017ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo0_l0000Aooooo`03o`00
0?oooooooooo00Kooooo0ol0000Eooooo`;o00003_ooool1o`00000000?o0000ooooooooool02ooo
ool4o`0000;ooooo00So0000ooooool0003oooooo`000?oooooo0000ooooo`Co00000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00Go0000ZOooool6o`0009cooooo0Ol000000003
o`000?oooooooooo00cooooo0ol00002ooooo`Go000000?oooooo`000?l000001Ol000001?oooooo
0000ooooool00002ooooo`05o`000?oooooo0000o`000?ooool00ol0002Xooooo`;o000000Cooooo
o`000?l0003ooooo0_l0002Kooooo`7o000000000ol0003oooooooooo`06ooooojco00004Ooooon/
o`0000Sooooo0Ol000000003o`000?oooooooooo00gooooo00?o0000ooooool000000_l00002oooo
o`Wo000000Coooooo`000?oooooooooo1?l000000ooooooo0000o`000003o`0000gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`;o00000_ooool01?l0003oooooooooool0
000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool1o`00000000?o0000
ooooooooool03Oooool2o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool02_l0
00001_oooooo0000oooooooooooo0000ooooo`;o0000Zoooool2o`000004ooooool0003oooooo`00
09cooooo0Ol000000003o`000?oooooooooo00gooooo1?l000000ooooooo0000ooooo`02ooooo`04
o`000?ooooooooooooooo`?o000000?oooooo`000?l000000_ooool01Ol0003oooooo`000?l0003o
oooo00;o0000[Oooool4o`0009gooooo0Ol000000003o`000?oooooooooo00kooooo0ol00002oooo
o`;o00000_ooool3o`000004ooooool0003o0000o`0000?ooooo00Go0000ooooool0003o0000oooo
o`02o`000;3ooooo00?o0000ooooooooool0W?ooool1o`00000000?o0000ooooooooool03oooool4
o`000003ooooool0003o000000;o00000_ooool2o`0000?ooooo1Ol000000ooooooo0000o`00002a
ooooo`03o`000?oooooooooo09cooooo0Ol000000003o`000?oooooooooo017ooooo00Go0000oooo
ool0003o0000ooooo`09o`0000?ooooo1?l0002booooo`03o`000?oooooooooo09cooooo0Ol00000
0003o`000?oooooooooo01;ooooo2ol00003ooooo`Go0000/oooool00ol0003oooooooooo`2Loooo
o`7o000000000ol0003oooooooooo`0Dooooo`oo0000]Oooool00ol0003oooooooooo`2Looooo`7o
000000000ol0003oooooooooo`0Gooooo`_o0000]_ooool00ol0003oooooooooo`2Looooo`7o0000
00000ol0003oooooooooo`0Iooooo`Co0000^oooool00ol0003oooooooooo`2Looooo`7o00000000
0ol0003oooooooooo`0Kooooo`;o0000^oooool00ol0003oooooooooo`2Looooo`7o000000000ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0W?ooool1o`00
000000?o0000ooooooooool0oooooomhooooo`7o000000000ol0003oooooooooo`3oooooogSooooo
0Ol000000003o`000?oooooooooo0?ooooooN?ooool1o`00000000?o0000ooooooooool0oooooomh
ooooo`7o0000003oo`0007co0000003oooooogcooooo0000\
\>"],
  ImageRangeCache->{{{0, 378.375}, {204.375, 0}} -> {-0.0507047, -0.0359265, \
0.00555378, 0.00555378}, {{9.125, 180.562}, {197.875, 106.688}} -> {-0.20983, \
-0.58806, 0.00688885, 0.00688885}, {{197.75, 369.188}, {197.875, 106.688}} -> \
{-1.50924, -0.58806, 0.00688885, 0.00688885}, {{9.125, 180.562}, {97.625, \
6.4375}} -> {-0.20983, -1.27867, 0.00688885, 0.00688885}, {{197.75, 369.188}, \
{97.625, 6.4375}} -> {-1.50924, -1.27867, 0.00688885, 0.00688885}},
  CellTags->"2.5"]
}, Open  ]],

Cell["\<\
Clearly, the interaction present in loop 2 has been greatly \
improved over the bandwidth of interest. However, some high-frequency \
(transient) interaction remains in loop 1.\
\>", "Text",
  CellTags->"2.5"],

Cell["\<\
These are the resulting variations in the top temperature (solid \
lines) and the bottom temperature (dashed lines) for separate changes of one \
degree C in each system input, which confirm the interaction levels predicted \
by the Nyquist array.\
\>", "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SimulationPlot[q, UnitStep[1], {t, 8000}, 
        PlotRange \[Rule] 
          All, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[ .001], 
            Dashing[{0.015}]}];\)\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"2.5"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.000119048 0.0682196 0.541469 [
[.2619 .05572 -9.6 -7.2 ]
[.2619 .05572 9.6 0 ]
[.5 .05572 -9.6 -7.2 ]
[.5 .05572 9.6 0 ]
[.7381 .05572 -9.6 -7.2 ]
[.7381 .05572 9.6 0 ]
[.97619 .05572 -9.6 -7.2 ]
[.97619 .05572 9.6 0 ]
[.01131 .17651 -14.4 -3.6 ]
[.01131 .17651 0 3.6 ]
[.01131 .28481 -14.4 -3.6 ]
[.01131 .28481 0 3.6 ]
[.01131 .3931 -14.4 -3.6 ]
[.01131 .3931 0 3.6 ]
[.01131 .50139 -14.4 -3.6 ]
[.01131 .50139 0 3.6 ]
[.01131 .60969 -4.8 -3.6 ]
[.01131 .60969 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .06822 m
.2619 .07447 L
s
[(2000)] .2619 .05572 0 1 Mshowa
.5 .06822 m
.5 .07447 L
s
[(4000)] .5 .05572 0 1 Mshowa
.7381 .06822 m
.7381 .07447 L
s
[(6000)] .7381 .05572 0 1 Mshowa
.97619 .06822 m
.97619 .07447 L
s
[(8000)] .97619 .05572 0 1 Mshowa
.125 Mabswid
.08333 .06822 m
.08333 .07197 L
s
.14286 .06822 m
.14286 .07197 L
s
.20238 .06822 m
.20238 .07197 L
s
.32143 .06822 m
.32143 .07197 L
s
.38095 .06822 m
.38095 .07197 L
s
.44048 .06822 m
.44048 .07197 L
s
.55952 .06822 m
.55952 .07197 L
s
.61905 .06822 m
.61905 .07197 L
s
.67857 .06822 m
.67857 .07197 L
s
.79762 .06822 m
.79762 .07197 L
s
.85714 .06822 m
.85714 .07197 L
s
.91667 .06822 m
.91667 .07197 L
s
.25 Mabswid
0 .06822 m
1 .06822 L
s
.02381 .17651 m
.03006 .17651 L
s
[(0.2)] .01131 .17651 1 0 Mshowa
.02381 .28481 m
.03006 .28481 L
s
[(0.4)] .01131 .28481 1 0 Mshowa
.02381 .3931 m
.03006 .3931 L
s
[(0.6)] .01131 .3931 1 0 Mshowa
.02381 .50139 m
.03006 .50139 L
s
[(0.8)] .01131 .50139 1 0 Mshowa
.02381 .60969 m
.03006 .60969 L
s
[(1)] .01131 .60969 1 0 Mshowa
.125 Mabswid
.02381 .09529 m
.02756 .09529 L
s
.02381 .12237 m
.02756 .12237 L
s
.02381 .14944 m
.02756 .14944 L
s
.02381 .20359 m
.02756 .20359 L
s
.02381 .23066 m
.02756 .23066 L
s
.02381 .25773 m
.02756 .25773 L
s
.02381 .31188 m
.02756 .31188 L
s
.02381 .33895 m
.02756 .33895 L
s
.02381 .36603 m
.02756 .36603 L
s
.02381 .42017 m
.02756 .42017 L
s
.02381 .44725 m
.02756 .44725 L
s
.02381 .47432 m
.02756 .47432 L
s
.02381 .52847 m
.02756 .52847 L
s
.02381 .55554 m
.02756 .55554 L
s
.02381 .58261 m
.02756 .58261 L
s
.02381 .04115 m
.02756 .04115 L
s
.02381 .01407 m
.02756 .01407 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(1) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .06822 m
.06244 .15681 L
.10458 .23765 L
.14415 .30038 L
.18221 .35071 L
.22272 .39532 L
.26171 .43099 L
.30316 .46241 L
.34309 .48745 L
.3815 .50751 L
.42237 .52525 L
.46172 .53942 L
.49955 .55079 L
.53984 .56089 L
.57861 .56896 L
.61984 .57609 L
.65954 .58177 L
.69774 .58633 L
.73838 .59037 L
.77751 .59359 L
.81909 .59643 L
.85916 .59869 L
.89771 .6005 L
.93871 .6021 L
.97619 .60332 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .06822 m
.02846 .04178 L
.02952 .03534 L
.03068 .02942 L
.0317 .02517 L
.03279 .02161 L
.03408 .0185 L
.03527 .01657 L
.03635 .01548 L
.03754 .01485 L
.0388 .01472 L
.03951 .01483 L
.04016 .01503 L
.04142 .01565 L
.04262 .01644 L
.06244 .03431 L
.07289 .04164 L
.08259 .04702 L
.09323 .05168 L
.10458 .05553 L
.11487 .05824 L
.12599 .06052 L
.1365 .06219 L
.14616 .06341 L
.16499 .06512 L
.17567 .0658 L
.18565 .06631 L
.1961 .06672 L
.206 .06703 L
.22456 .06745 L
.23421 .0676 L
.24447 .06773 L
.26289 .0679 L
.27226 .06797 L
.28236 .06802 L
.30064 .06809 L
.31021 .06811 L
.32068 .06814 L
.33161 .06816 L
.34178 .06817 L
.3523 .06818 L
.36224 .06819 L
.38082 .0682 L
.39054 .0682 L
.40084 .06821 L
.41929 .06821 L
.42873 .06821 L
.43886 .06821 L
.45718 .06822 L
.46731 .06822 L
Mistroke
.47835 .06822 L
.48878 .06822 L
.49845 .06822 L
.50905 .06822 L
.51902 .06822 L
.53764 .06822 L
.54742 .06822 L
.55775 .06822 L
.57624 .06822 L
.58574 .06822 L
.59592 .06822 L
.61426 .06822 L
.62446 .06822 L
.63554 .06822 L
.64601 .06822 L
.65568 .06822 L
.67438 .06822 L
.68502 .06822 L
.69499 .06822 L
.70485 .06822 L
.71522 .06822 L
.73373 .06822 L
.7433 .06822 L
.75351 .06822 L
.77189 .06822 L
.78216 .06822 L
.79328 .06822 L
.80378 .06822 L
.81344 .06822 L
.83225 .06822 L
.84292 .06822 L
.8529 .06822 L
.86333 .06822 L
.87323 .06822 L
.89178 .06822 L
.90141 .06822 L
.91166 .06822 L
.93007 .06822 L
.93943 .06822 L
.94952 .06822 L
.96779 .06822 L
.97619 .06822 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003o5Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000Eooooo`03o`000?oooooooooo0?oooooo2Oooool001Go
oooo00?o0000ooooooooool0ooooool9ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo00?o
0000ooooooooool00_l0003oooooo`Oooooo000Eooooo`03o`000?oooooo00000?oooooo2Oooool0
01Gooooo00?o0000ooooool000001?ooool2o`000?oooooo0oooool001Gooooo00?o0000ooooool0
00001_ooool00ol0003oooooooooo`3oooooo`005Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0?kooooo000Eooooo`03o`000?oooooooooo03?ooooo0ol00003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo
0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0/ooooo`?o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool001Gooooo0_l0000eooooo`07o`000?ooooooooooooooool0003o
ooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000;Oooool3o`0000;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000002go
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooool00000;Oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooool000000_ooool00ol0003oooooo`000006ooooo`005Oooool2o`0000_ooooo
0ol0000Xooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002oooo
o`03o`000?oooooo000002gooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooool00000;Oooool3o`0000;ooooo00?o0000oooo
ool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000002kooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00
0006ooooo`005Oooool2o`0000kooooo00?o0000ooooooooool09Oooool01_l0003oooooooooool0
003oooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000^ooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`00000]ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000Kooooo000Eooooo`;o0000=?oo
ool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;Oooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`0Aooooo`Co0000loooool001Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3`
ooooo`005Oooool00ol0003oooooooooo`0Iooooo`Go0000j_ooool001Gooooo00?o0000oooooooo
ool08Oooool5o`0000?ooooo1Ol00003ooooo`Go0000Xoooool00ol0003oooooooooo`0/ooooo`00
3oooooooo`0000[o00002?ooool001Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`005Oooool2o`000?oooooo2_ooool001Gooooo0_l0003oooooo`[ooooo000Eooooo`03
o`000?oooooo00000?oooooo2Oooool001Gooooo00?o0000ooooool00000ooooool9ooooo`005Ooo
ool00ol0003oooooo`00003oooooo`Wooooo000Eooooo`;o000000?oooooo`000?ooool0ooooool7
ooooo`005Oooool01?l0003oooooooooool0003oooooo`Sooooo000Eooooo`05o`000?oooooooooo
ooooool00000ooooool7ooooo`005Oooool01Ol0003ooooooooooooooooo00000?oooooo1oooool0
01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Cooooo000Eooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool4ooooo`005Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo1?ooool001Gooooo0_l00004ooooo`03o`000?oo
oooooooo0?oooooo0oooool001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooo`?ooooo000Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool2oooo
o`005Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo0_ooool001Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`7ooooo000Eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0ooooool1ooooo`005Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo0Oooool001Gooooo0_l00007ooooo`03o`000?oooooooooo
0?oooooo000Eooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool001Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`3nooooo`005Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?kooooo000Eooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0oOooool001Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3moooo
o`001Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?cooooo0004ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool00oooool3o`0000Wooooo00?o0000ooooooooool0o?ooool000Cooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0noooool000Cooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0noooool000Gooooo00?o0000
ooooooooool01_ooool3o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3j
ooooo`005Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?[ooooo000Eooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0nOooool001Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`3hooooo`005Oooool2o`0000kooooo00?o0000ooooooooool0n?oo
ool001Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3gooooo`005Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0?Oooooo000Eooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0m_ooool001Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`3fooooo`005Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?Gooooo000E
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0mOooool001Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`3dooooo`005Oooool2o`0001;ooooo00?o0000oooooooo
ool0m?ooool001Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3cooooo`005Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0??ooooo000Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0l_ooool001Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`3aooooo`005Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?7o
oooo000Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0l?ooool001Gooooo0_l0
000Gooooo`03o`000?oooooooooo0>oooooo000Eooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0koooool001Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3^oooo
o`005Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0>gooooo000Eooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0kOooool001Gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`3/ooooo`001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0>cooooo0004ooooo`03o`000?oooooo000000Oooooo0ol00004ooooo`?o00006_ooool00ol0
003oooooooooo`3[ooooo`001?ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3Zooooo`001?ooool00ol0003ooooo
o`000008ooooo`;o00001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>[ooooo
0005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0>Wooooo000Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0j?ooool001Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`3Xoooo
o`005Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>Oooooo000Eooooo`;o0000
8?ooool00ol0003oooooooooo`3Vooooo`005Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo0>Gooooo000Eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0iOooool0
01Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Tooooo`005Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo0>?ooooo000Eooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0h_ooool001Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`3Qooooo`005Oooool2o`0002Gooooo00?o0000ooooooooool0hOooool001Gooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`3Pooooo`005Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo0=oooooo000Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
g_ooool001Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3Nooooo`005Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0=gooooo000Eooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0g?ooool001Gooooo0_l0000[ooooo`03o`000?oooooooooo0=_o
oooo000Eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0f_ooool001Gooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`3Iooooo`005Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo0=Sooooo000Eooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0eoooool001Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3Fooooo`00
5Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0=Gooooo0005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`3Dooooo`001?ooool00ol0003oooooo`000007ooooo`03o`000?oooooo
000000Cooooo0ol0000booooo`03o`000?oooooooooo0=?ooooo0004ooooo`03o`000?oooooo0000
00Oooooo0ol00004ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0d_ooool000Co
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0dOooool000Gooooo00?o0000ooooooooool01oooool2o`0000Cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3@ooooo`005Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo0<oooooo000Eooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0c_ooool001Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3=oooo
o`005Oooool2o`0003[ooooo00?o0000ooooooooool0c?ooool001Gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`3;ooooo`005Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0<[ooooo000Eooooo`03o`000?oooooooooo03cooooo0_l0003:ooooo`005Oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo0<Oooooo000Eooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0a_ooool001Gooooo00?o0000ooooooooool0@?ooool2o`000<Kooooo
000Eooooo`;o0000@oooool00ol0003oooooooooo`33ooooo`005Oooool00ol0003oooooooooo`13
ooooo`;o0000`oooool001Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`30oooo
o`005Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0;oooooo000Eooooo`03o`00
0?oooooooooo04Oooooo0_l0002oooooo`005Oooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo0;cooooo000Eooooo`03o`000?oooooooooo04[ooooo0_l0002looooo`005Oooool2o`00
04gooooo0_l0002jooooo`005Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0;Oo
oooo000Eooooo`03o`000?oooooooooo04oooooo0_l0002gooooo`005Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo0;Cooooo000Eooooo`03o`000?oooooooooo05;ooooo0_l0002d
ooooo`005Oooool00ol0003oooooooooo`1Dooooo`;o0000/_ooool000Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooooooool3o`0000Cooooo00?o0000ooooooooool0E_ooool2o`00
0;3ooooo0004ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000001?ooool3o`0005So
oooo0_l0002^ooooo`001?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0F_ooool2o`000:cooooo0004ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`1Looooo`;o0000Z_ooool000Gooooo00?o0000
ooooooooool01_ooool3o`0000Cooooo00?o0000ooooooooool0G_ooool2o`000:Sooooo000Eoooo
o`03o`000?oooooooooo063ooooo0ol0002Uooooo`005Oooool00ol0003oooooooooo`1Sooooo`;o
0000Xoooool001Gooooo00?o0000ooooooooool0IOooool2o`000:7ooooo000Eooooo`;o0000J?oo
ool3o`0009kooooo000Eooooo`03o`000?oooooooooo06[ooooo0ol0002Kooooo`005Oooool00ol0
003oooooooooo`1]ooooo`?o0000V?ooool001Gooooo00?o0000ooooooooool0L?ooool4o`0009Co
oooo000Eooooo`03o`000?oooooooooo07Cooooo0ol0002Aooooo`005Oooool00ol0003ooooooooo
o`1gooooo`?o0000S_ooool001Gooooo00?o0000ooooooooool0N_ooool4o`0008[ooooo000Eoooo
o`03o`000?oooooooooo07kooooo1?l00026ooooo`005Oooool2o`0008?ooooo0ol00023ooooo`00
5Oooool00ol0003oooooooooo`25ooooo`Go0000O_ooool001Gooooo00?o0000ooooooooool0R_oo
ool5o`0007Wooooo000Eooooo`03o`000?oooooooooo08oooooo1Ol0001dooooo`005Oooool00ol0
003oooooooooo`2Dooooo`Go0000Koooool001Gooooo00?o0000ooooooooool0VOooool6o`0006Wo
oooo000Eooooo`03o`000?oooooooooo09oooooo1Ol0001Tooooo`005Oooool2o`000:Gooooo1ol0
001Mooooo`005Oooool00ol0003oooooooooo`2[ooooo`_o0000D_ooool001Gooooo00?o0000oooo
ooooool0]_ooool;o`0004Oooooo000Eooooo`03o`000?oooooooooo0<7ooooo5Ol0000booooo`00
5Oooool00ol0003oooooooooo`3Fooooo`[o0000:?ooool001Gooooo00?o0000ooooooooool0h?oo
oolJo`0000kooooo000>ooooo`?o00001?ooool00ol0003oooooooooo`3oooooo`Wooooo000?oooo
o`03o`000?oooooooooo00?ooooo0ol0003oooooo`Wooooo000?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0ooooool9ooooo`003oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo2Oooool000kooooo0_l0003ooooooa7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo002<ooooo`?o0000TOooool008gooooo00?o0000ooooooooool0T?oo
ool008?ooooo0ol00002ooooo`03o`000?oooooo000000;ooooo0ol00002ooooo`?o00000_ooool3
o`0000Kooooo0ol0001mooooo`00Q?ooool01ol0003ooooooooooooooooo0000ooooool000000_oo
ool02?l0003oooooooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo07cooooo0024ooooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0O?ooool008Cooooo00?o0000ooooooooool01?l000000ooooooo0000
o`000002o`000006ooooool0003o0000ooooool0003ooooo1?l00007ooooo`03o`000?oooooooooo
07cooooo0023ooooo`?o00004Oooool00ol0003oooooooooo`06ooooo`;o0000O_ooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-681.536, -0.125996, \
31.7274, 0.00697562}},
  CellTags->"2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8  scalefont  setfont
% Scaling calculations
0.0238095 0.000119048 0.0270173 0.576302 [
[.2619 .01452 -9.6 -7.2 ]
[.2619 .01452 9.6 0 ]
[.5 .01452 -9.6 -7.2 ]
[.5 .01452 9.6 0 ]
[.7381 .01452 -9.6 -7.2 ]
[.7381 .01452 9.6 0 ]
[.97619 .01452 -9.6 -7.2 ]
[.97619 .01452 9.6 0 ]
[.01131 .14228 -14.4 -3.6 ]
[.01131 .14228 0 3.6 ]
[.01131 .25754 -14.4 -3.6 ]
[.01131 .25754 0 3.6 ]
[.01131 .3728 -14.4 -3.6 ]
[.01131 .3728 0 3.6 ]
[.01131 .48806 -14.4 -3.6 ]
[.01131 .48806 0 3.6 ]
[.01131 .60332 -4.8 -3.6 ]
[.01131 .60332 0 3.6 ]
[.5 .63053 -18.625 0 ]
[.5 .63053 18.625 10 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .02702 m
.2619 .03327 L
s
[(2000)] .2619 .01452 0 1 Mshowa
.5 .02702 m
.5 .03327 L
s
[(4000)] .5 .01452 0 1 Mshowa
.7381 .02702 m
.7381 .03327 L
s
[(6000)] .7381 .01452 0 1 Mshowa
.97619 .02702 m
.97619 .03327 L
s
[(8000)] .97619 .01452 0 1 Mshowa
.125 Mabswid
.08333 .02702 m
.08333 .03077 L
s
.14286 .02702 m
.14286 .03077 L
s
.20238 .02702 m
.20238 .03077 L
s
.32143 .02702 m
.32143 .03077 L
s
.38095 .02702 m
.38095 .03077 L
s
.44048 .02702 m
.44048 .03077 L
s
.55952 .02702 m
.55952 .03077 L
s
.61905 .02702 m
.61905 .03077 L
s
.67857 .02702 m
.67857 .03077 L
s
.79762 .02702 m
.79762 .03077 L
s
.85714 .02702 m
.85714 .03077 L
s
.91667 .02702 m
.91667 .03077 L
s
.25 Mabswid
0 .02702 m
1 .02702 L
s
.02381 .14228 m
.03006 .14228 L
s
[(0.2)] .01131 .14228 1 0 Mshowa
.02381 .25754 m
.03006 .25754 L
s
[(0.4)] .01131 .25754 1 0 Mshowa
.02381 .3728 m
.03006 .3728 L
s
[(0.6)] .01131 .3728 1 0 Mshowa
.02381 .48806 m
.03006 .48806 L
s
[(0.8)] .01131 .48806 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .05583 m
.02756 .05583 L
s
.02381 .08465 m
.02756 .08465 L
s
.02381 .11346 m
.02756 .11346 L
s
.02381 .17109 m
.02756 .17109 L
s
.02381 .19991 m
.02756 .19991 L
s
.02381 .22872 m
.02756 .22872 L
s
.02381 .28635 m
.02756 .28635 L
s
.02381 .31517 m
.02756 .31517 L
s
.02381 .34398 m
.02756 .34398 L
s
.02381 .40161 m
.02756 .40161 L
s
.02381 .43043 m
.02756 .43043 L
s
.02381 .45924 m
.02756 .45924 L
s
.02381 .51687 m
.02756 .51687 L
s
.02381 .54569 m
.02756 .54569 L
s
.02381 .5745 m
.02756 .5745 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -79.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Input) show
91.500 11.000 moveto
(2) show
96.250 11.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .02702 m
.02499 .03269 L
.02605 .02733 L
.02721 .02083 L
.02846 .01714 L
.02961 .01566 L
.03068 .01506 L
.0317 .01482 L
.03279 .01472 L
.03395 .01472 L
.0352 .01475 L
.03638 .01481 L
.03746 .01486 L
.04262 .01514 L
.06244 .01619 L
.10458 .01813 L
.14429 .01963 L
.18248 .02084 L
.22313 .0219 L
.26226 .02276 L
.30384 .02351 L
.34391 .02411 L
.38246 .02459 L
.42346 .02501 L
.46295 .02535 L
.50092 .02562 L
.54134 .02586 L
.58025 .02605 L
.62161 .02622 L
.66146 .02636 L
.69979 .02646 L
.74057 .02656 L
.77984 .02664 L
.81759 .0267 L
.85779 .02675 L
.89648 .0268 L
.93762 .02684 L
.97619 .02687 L
s
.5 Mabswid
[ .015 ] 0 setdash
.02381 .02702 m
.02846 .19393 L
.03068 .27869 L
.03279 .33973 L
.03398 .36672 L
.03527 .39075 L
.03754 .42232 L
.03882 .43573 L
.04018 .44732 L
.04262 .46325 L
.04496 .47465 L
.04749 .48432 L
.05205 .49802 L
.06244 .52128 L
.07373 .54029 L
.08445 .55425 L
.09407 .56412 L
.10458 .57264 L
.11471 .5791 L
.12425 .58393 L
.13525 .58832 L
.14523 .59144 L
.15499 .59386 L
.1653 .59588 L
.18378 .59849 L
.19325 .59944 L
.20341 .60026 L
.22175 .60133 L
.23192 .60175 L
.24299 .6021 L
.25344 .60237 L
.26311 .60256 L
.28177 .60283 L
.2924 .60294 L
.30238 .60302 L
.31221 .60308 L
.32256 .60313 L
.34106 .6032 L
.35061 .60322 L
.3608 .60324 L
.37917 .60327 L
.38941 .60328 L
.40052 .60329 L
.411 .60329 L
.42067 .6033 L
.43943 .60331 L
.4501 .60331 L
.46007 .60331 L
.47048 .60331 L
.48036 .60331 L
Mistroke
.4989 .60332 L
.50851 .60332 L
.51874 .60332 L
.53714 .60332 L
.54745 .60332 L
.55859 .60332 L
.56911 .60332 L
.57878 .60332 L
.59764 .60332 L
.60834 .60332 L
.61832 .60332 L
.62879 .60332 L
.63871 .60332 L
.65728 .60332 L
.66696 .60332 L
.67722 .60332 L
.69566 .60332 L
.70505 .60332 L
.71517 .60332 L
.73346 .60332 L
.74306 .60332 L
.75354 .60332 L
.76448 .60332 L
.77465 .60332 L
.7852 .60332 L
.79515 .60332 L
.81375 .60332 L
.8235 .60332 L
.8338 .60332 L
.85227 .60332 L
.86173 .60332 L
.87188 .60332 L
.89021 .60332 L
.90037 .60332 L
.91142 .60332 L
.92187 .60332 L
.93154 .60332 L
.95018 .60332 L
.9608 .60332 L
.97077 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00C?ooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool2o`0000?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_ooooo0ol00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`006?ooool00ol0003oooooooooo`0booooo`07o`000?ooooooooooooooool0003oooooo`000002
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000;?ooool3o`0000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000002cooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool00000;?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000008ooooo`006?ooool00ol0003oooooooooo`0coooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooo000002cooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool00000;?ooool3o`0000;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooo000002gooooo00Oo0000oooooooooooooooo
o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000008ooooo`00
6?ooool00ol0003oooooooooo`0cooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000002gooooo0_l00002ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`00000/ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
02cooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooool000002?ooool001Sooooo00?o0000ooooooooool0<Oooool3o`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02go
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;?ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02_ooooo0ol00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`006?ooool@o`000?Sooooo000Hooooo`03o`00
0?oooooooooo00gooooo7ol0003Iooooo`006?ooool00ol0003oooooooooo`0/ooooocko0000Vooo
ool0017oooooool00006o`0000[ooooo000Hooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool001Sooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`00
6?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_oo
ool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3ooooo
o`Kooooo000Hooooo`;o0000ooooool7ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo
000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6
ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oo
oooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003ooooooooo
o`3oooooo`Kooooo000Hooooo`;o0000ooooool7ooooo`006?ooool00ol0003oooooooooo`3ooooo
o`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0
ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooo
oooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool2o`000?oo
oooo1oooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003ooooooooo
o`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000oooo
ooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`00
0?oooooooooo0?oooooo1_ooool000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ooooool3o`0000Gooooo00?o0000ooooooooool0ooooool6ooooo`001_ooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo00Cooooo0_l0003oooooo`Oooooo0006ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`Kooooo0006oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
o`Kooooo0007ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo0?oo
oooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003ooooooooo
o`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo0_l0003ooooo
o`Oooooo000Hooooo`;o0000ooooool7ooooo`006?ooool2o`000?oooooo1oooool001Sooooo00?o
0000ooooooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hoooo
o`03o`000?oooooooooo0?oooooo1_ooool001Sooooo0_l0003oooooo`Oooooo000Hooooo`;o0000
ooooool7ooooo`006?ooool2o`000?oooooo1oooool001Sooooo0_l0003oooooo`Oooooo000Hoooo
o`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`00
6?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`;o0000ooooool7ooooo`006?ooool2
o`000?oooooo1oooool001Sooooo0_l0003oooooo`Oooooo000Hooooo`;o0000ooooool7ooooo`00
6?ooool2o`000?oooooo1oooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool0
0ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001So
oooo0_l0003oooooo`Oooooo0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`;o0000ooooool7ooooo`001_ooool00ol0003oooooo`00
0007ooooo`?o00001Oooool2o`000?oooooo1oooool000Kooooo00?o0000ooooool000001oooool0
0ol0003oooooo`000005ooooo`;o0000ooooool7ooooo`001_ooool00ol0003oooooo`000008oooo
o`;o00001Oooool2o`000?oooooo1oooool000Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0
ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`;o0000ooooool7
ooooo`006?ooool2o`000?oooooo1oooool001Sooooo0_l0003oooooo`Oooooo000Hooooo`;o0000
ooooool7ooooo`006?ooool2o`000?oooooo1oooool001Sooooo00?o0000ooooooooool0ooooool6
ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oo
oooo1_ooool001Sooooo00?o0000ooooool00000ooooool6ooooo`006?ooool3o`000?oooooo1_oo
ool001Sooooo00?o0000ooooool00000ooooool6ooooo`006?ooool00ol0003oooooo`00003ooooo
o`Kooooo000Hooooo`03o`000?oooooo00000?oooooo1_ooool001Sooooo00?o0000ooooooooool0
ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooo
00000?oooooo1_ooool001Sooooo0ol0003oooooo`Kooooo000Hooooo`03o`000?oooooo00000?oo
oooo1_ooool001Sooooo00?o0000ooooool00000ooooool6ooooo`006?ooool00ol0003oooooo`00
003oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000oooo
ooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo0007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooool00000
ooooool6ooooo`001_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Gooooo0ol0
003oooooo`Kooooo0006ooooo`03o`000?oooooo000000Oooooo0ol00005ooooo`03o`000?oooooo
00000?oooooo1_ooool000Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo00000?oooooo1_ooool000Oooooo00?o0000ooooooooool01oooool2o`0000Go
oooo00?o0000ooooool00000ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo
000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000ooooooooool0ooooool6
ooooo`006?ooool2o`000003ooooool0003ooooo0?oooooo1?ooool001Sooooo00Co0000oooooooo
oooo0000ooooool5ooooo`006?ooool01?l0003oooooooooool0003oooooo`Gooooo000Hooooo`04
o`000?ooooooooooo`000?oooooo1Oooool001Sooooo00Co0000oooooooooooo0000ooooool5oooo
o`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo
1_ooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool2o`000003ooooool0003o
oooo0?oooooo1?ooool001Sooooo00Co0000oooooooooooo0000ooooool5ooooo`006?ooool01?l0
003oooooooooool0003oooooo`Gooooo000Hooooo`05o`000?ooooooooooooooool00000ooooool4
ooooo`006?ooool01Ol0003ooooooooooooooooo00000?oooooo1?ooool001Sooooo00?o0000oooo
ooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`;o0000
0_ooool00ol0003oooooooooo`3oooooo`;ooooo000Hooooo`05o`000?ooooooooooooooool00000
ooooool4ooooo`006?ooool01Ol0003ooooooooooooooooo00000?oooooo1?ooool001Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`7ooooo000Hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool1ooooo`006?ooool00ol0003oooooooooo`3ooooo
o`Kooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool000Oooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool3o`0000Gooooo00?o0000ooooooooool0ooooool6ooooo`00
1_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000Gooooo0_l00004ooooo`03o`00
0?oooooooooo0?oooooo0006ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo0006ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?kooooo0007ooooo`03o`000?oooooooooo00Kooooo0ol00005ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0o_ooool001Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3nooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oo
oooooooo0?oooooo1_ooool001Sooooo0_l00007ooooo`03o`000?oooooooooo0?cooooo000Hoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0noooool001Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3kooooo`006?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?[ooooo000Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0n_oo
ool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3ooooo
o`Kooooo000Hooooo`;o00002oooool00ol0003oooooooooo`3hooooo`006?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?Sooooo000Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0moooool001Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3f
ooooo`006?ooool00ol0003oooooooooo`3oooooo`Kooooo000Hooooo`03o`000?oooooooooo0?oo
oooo1_ooool001Sooooo00?o0000ooooooooool03oooool2o`000?Cooooo000Hooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0lOooool001Sooooo0_l0000Cooooo`03o`000?oooooo
oooo0?3ooooo000Hooooo`03o`000?oooooooooo0?oooooo1_ooool001Sooooo00?o0000oooooooo
ool05_ooool3o`000>cooooo000Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
jOooool001Sooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`0M
ooooo`Go0000hoooool0013ooooo0ol00005ooooo`03o`000?oooooooooo02Gooooo1?l0003Loooo
o`004Oooool00ol0003oooooooooo`04ooooo`;o0000;Oooool5o`0000?ooooo1Ol00003ooooo`Go
00000oooool4o`0000?ooooo1Ol00003ooooo`Go00000oooool5o`0000?ooooo1Ol00002ooooo`Go
00000oooool2o`0000;ooooo1Ol00003ooooo`Go00000oooool5o`0000?ooooo1Ol00003ooooo`Co
00000oooool5o`0000?ooooo1Ol00003ooooo`Go00000oooool5o`0000;ooooo1Ol00003ooooo`Go
00000oooool5o`0000?ooooo1Ol00003ooooo`Co00000oooool5o`0000?ooooo1Ol00003ooooo`;o
00004?ooool0017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Kooooo
000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool6ooooo`004?ooool2
o`0000Kooooo00?o0000ooooooooool0ooooool6ooooo`006?ooool00ol0003oooooooooo`3ooooo
o`Kooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo002<oooo
o`?o0000TOooool008gooooo00?o0000ooooooooool0T?ooool008?ooooo0ol00002ooooo`03o`00
0?oooooo000000;ooooo0ol00002ooooo`?o00000_ooool3o`0000Kooooo0ol0001mooooo`00Q?oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool02?l0003oooooooooool0003ooooo
o`000?oooooo00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07cooooo0024
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`08o`000?ooooooooooo`000?oo
oooo0000ooooool00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Noooool0
08Cooooo00?o0000ooooooooool01?l000000ooooooo0000o`000002o`000006ooooool0003o0000
ooooool0003ooooo1?l00008ooooo`03o`000?oooooooooo07_ooooo0023ooooo`?o00004Oooool0
0ol0003oooooooooo`06ooooo`?o0000OOooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-778.781, -0.0698708, \
32.3939, 0.00669168}},
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]],

Cell["\<\
You should note that these time responses are those of the \
forward-path transfer-function matrix representation of the system; that is, \
the open-loop plant plus its series compensators. As the interaction in the \
system has been significantly reduced, you can now add further single-loop \
tuning compensators, as required, to meet the overall system time response \
specifications, and close the feedback loops with unity negative \
feedback.\
\>", "Text",
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 805}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"EnhancedPrintout",
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{804, 594},
WindowMargins->{{75, Automatic}, {Automatic, 62}},
PrintingCopies->1,
PrintingStartingPageNumber->6,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ 
          StyleBox[ "Polynomial Control Systems", FontSlant -> "Italic"]], 
        "Header"]}, {Cell[ 
        TextData[ {
          "2 Introduction: Controlling a Distillation Column\[LongDash]A Case \
Study of an Industrial Application"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PageFooters->{{Inherited, None, Inherited}, {Inherited, None, Inherited}},
PageFooterLines->{False, False},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True,
"FirstPageFace"->Left,
"PostScriptOutputFile":>FrontEnd`FileName[{"export", "home", "grad", \
"sarkiss", "NLCL", "New"}, "03_MatrixEquations.nb.ps", CharacterEncoding -> \
"MacintoshRoman"]},
ShowSelection->True,
TaggingRules:>{"PaginationCache" -> {{2006, 5, 2, 12, 55, \
33.563604`8.278443568587393}, {6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, \
7, 7, 7, 7, 8, 8, 8, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 9, 10, 10, 10, 10, 11, \
11, 11, 11, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 13, 13, 13, \
13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 14, 14, 14, 14, 14, 14, 14, 14, \
14, 14, 14, 14, 14, 14, 15, 15, 15, 15, 15, 15, 15, 15, 15, 16, 16, 16, 16, \
16, 16, 16, 16, 16, 16, 17, 17, 17, 17, 17, 17, 18, 18, 18, 18, 18, 18, 19, \
19, 19, 19, 19, 19, 19, 19, 19, 19, 20, 20, 20, 20, 20}, Automatic}},
SpanMaxSize->Infinity,
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "2.0"->{
    Cell[1776, 53, 142, 4, 61, "Section",
      CellTags->{"2.0", "c:1"}],
    Cell[1921, 59, 670, 12, 66, "Text",
      CellTags->"2.0"]},
  "c:1"->{
    Cell[1776, 53, 142, 4, 61, "Section",
      CellTags->{"2.0", "c:1"}]},
  "2.1"->{
    Cell[2616, 75, 77, 1, 36, "Subsection",
      CellTags->{"2.1", "c:2"}],
    Cell[2696, 78, 1194, 19, 110, "Text",
      CellTags->"2.1"],
    Cell[3893, 99, 78, 1, 40, "MathCaption",
      CellTags->"2.1"],
    Cell[3974, 102, 104, 3, 26, "Input",
      CellTags->"2.1"],
    Cell[4081, 107, 448, 8, 72, "MathCaption",
      CellTags->"2.1"],
    Cell[4554, 119, 363, 8, 79, "Input",
      CellTags->"2.1"],
    Cell[4920, 129, 1357, 33, 81, "Output",
      CellTags->"2.1"]},
  "c:2"->{
    Cell[2616, 75, 77, 1, 36, "Subsection",
      CellTags->{"2.1", "c:2"}]},
  "2.2"->{
    Cell[6326, 168, 92, 1, 36, "Subsection",
      CellTags->{"2.2", "c:3"}],
    Cell[6421, 171, 202, 7, 24, "Text",
      CellTags->"2.2"],
    Cell[6626, 180, 178, 5, 40, "MathCaption",
      CellTags->"2.2"],
    Cell[6829, 189, 112, 3, 26, "Input",
      CellTags->"2.2"],
    Cell[6944, 194, 420, 8, 41, "Output",
      CellTags->"2.2"],
    Cell[7379, 205, 143, 4, 40, "MathCaption",
      CellTags->"2.2"],
    Cell[7547, 213, 100, 3, 26, "Input",
      CellTags->"2.2"],
    Cell[7650, 218, 95, 3, 25, "Output",
      CellTags->"2.2"],
    Cell[7760, 224, 209, 5, 40, "MathCaption",
      CellTags->"2.2"],
    Cell[7994, 233, 232, 6, 42, "Input",
      CellTags->"2.2"],
    Cell[8251, 243, 22237, 595, 184, 6444, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.2"],
    Cell[30491, 840, 21158, 570, 184, 6233, 380, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.2"],
    Cell[51676, 1414, 314, 6, 36, "Text",
      CellTags->"2.2"]},
  "c:3"->{
    Cell[6326, 168, 92, 1, 36, "Subsection",
      CellTags->{"2.2", "c:3"}]},
  "2.3"->{
    Cell[52027, 1425, 87, 1, 36, "Subsection",
      CellTags->{"2.3", "c:4"}],
    Cell[52117, 1428, 635, 17, 54, "Text",
      CellTags->"2.3"],
    Cell[52755, 1447, 124, 4, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[52904, 1455, 99, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[53006, 1460, 2346, 54, 95, "Output",
      CellTags->"2.3"],
    Cell[55367, 1517, 98, 1, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[55490, 1522, 98, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[55591, 1527, 2195, 53, 52, "Output",
      CellTags->"2.3"],
    Cell[57801, 1583, 270, 8, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[58096, 1595, 90, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[58189, 1600, 81, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[58285, 1606, 474, 13, 39, "Text",
      CellTags->"2.3"],
    Cell[58762, 1621, 209, 6, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[58996, 1631, 101, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[59100, 1636, 3238, 68, 255, "Output",
      CellTags->"2.3"],
    Cell[62353, 1707, 422, 8, 50, "Text",
      CellTags->"2.3"],
    Cell[62778, 1717, 224, 6, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[63005, 1725, 1812, 29, 298, "Input",
      CellTags->"2.3"],
    Cell[64842, 1758, 94, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[64939, 1763, 4165, 78, 251, "Output",
      CellTags->"2.3"],
    Cell[69119, 1844, 102, 2, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[69246, 1850, 93, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[69342, 1855, 82, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[69461, 1863, 91, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[69555, 1868, 83, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[69653, 1874, 434, 10, 56, "MathCaption",
      CellTags->"2.3"],
    Cell[70112, 1888, 95, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[70210, 1893, 79, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[70304, 1899, 342, 11, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[70649, 1912, 111, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[70785, 1919, 95, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[70883, 1924, 4516, 88, 251, "Output",
      CellTags->"2.3"],
    Cell[75414, 2015, 368, 9, 38, "Text",
      CellTags->"2.3"],
    Cell[75785, 2026, 134, 4, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[75944, 2034, 103, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[76050, 2039, 135, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[76200, 2045, 360, 9, 56, "MathCaption",
      CellTags->"2.3"],
    Cell[76563, 2056, 112, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[76700, 2063, 94, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[76797, 2068, 3743, 78, 209, "Output",
      CellTags->"2.3"],
    Cell[80555, 2149, 234, 6, 40, "MathCaption",
      CellTags->"2.3"],
    Cell[80814, 2159, 93, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[80910, 2164, 82, 3, 25, "Output",
      CellTags->"2.3"],
    Cell[81029, 2172, 91, 3, 26, "Input",
      CellTags->"2.3"],
    Cell[81123, 2177, 82, 3, 25, "Output",
      CellTags->"2.3"]},
  "c:4"->{
    Cell[52027, 1425, 87, 1, 36, "Subsection",
      CellTags->{"2.3", "c:4"}]},
  "2.4"->{
    Cell[81254, 2186, 89, 1, 36, "Subsection",
      CellTags->{"2.4", "c:5"}],
    Cell[81346, 2189, 347, 9, 38, "Text",
      CellTags->"2.4"],
    Cell[81696, 2200, 163, 6, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[81862, 2208, 137, 4, 26, "Input",
      CellTags->"2.4"],
    Cell[82024, 2216, 95, 3, 26, "Input",
      CellTags->"2.4"],
    Cell[82122, 2221, 3311, 68, 209, "Output",
      CellTags->"2.4"],
    Cell[85448, 2292, 90, 1, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[85563, 2297, 126, 3, 30, "Input",
      CellTags->"2.4"],
    Cell[85692, 2302, 328, 6, 41, "Output",
      CellTags->"2.4"],
    Cell[86035, 2311, 230, 7, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[86290, 2322, 165, 4, 26, "Input",
      CellTags->"2.4"],
    Cell[86458, 2328, 295, 6, 25, "Output",
      CellTags->"2.4"],
    Cell[86768, 2337, 298, 8, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[87069, 2347, 153, 4, 26, "Input",
      CellTags->"2.4"],
    Cell[87247, 2355, 94, 3, 26, "Input",
      CellTags->"2.4"],
    Cell[87344, 2360, 666, 16, 55, "Output",
      CellTags->"2.4"],
    Cell[88025, 2379, 72, 1, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[88100, 2382, 119, 3, 26, "Input",
      CellTags->"2.4"],
    Cell[88244, 2389, 95, 3, 26, "Input",
      CellTags->"2.4"],
    Cell[88342, 2394, 3421, 69, 213, "Output",
      CellTags->"2.4"],
    Cell[91778, 2466, 142, 4, 40, "MathCaption",
      CellTags->"2.4"],
    Cell[91945, 2474, 160, 4, 30, "Input",
      CellTags->"2.4"],
    Cell[92108, 2480, 326, 6, 25, "Output",
      CellTags->"2.4"]},
  "c:5"->{
    Cell[81254, 2186, 89, 1, 36, "Subsection",
      CellTags->{"2.4", "c:5"}]},
  "2.5"->{
    Cell[92483, 2492, 77, 1, 36, "Subsection",
      CellTags->{"2.5", "c:6"}],
    Cell[92563, 2495, 840, 20, 70, "Text",
      CellTags->"2.5"],
    Cell[93406, 2517, 261, 6, 56, "MathCaption",
      CellTags->"2.5"],
    Cell[93692, 2527, 98, 3, 26, "Input",
      CellTags->"2.5"],
    Cell[93793, 2532, 400, 11, 41, "Output",
      CellTags->"2.5"],
    Cell[94208, 2546, 83, 1, 40, "MathCaption",
      CellTags->"2.5"],
    Cell[94316, 2551, 102, 3, 26, "Input",
      CellTags->"2.5"],
    Cell[94421, 2556, 65188, 2436, 197, 28931, 1983, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[159624, 4995, 353, 8, 36, "Text",
      CellTags->"2.5"],
    Cell[159980, 5005, 171, 6, 40, "MathCaption",
      CellTags->"2.5"],
    Cell[160176, 5015, 130, 3, 26, "Input",
      CellTags->"2.5"],
    Cell[160309, 5020, 926, 27, 42, "Output",
      CellTags->"2.5"],
    Cell[161250, 5050, 104, 2, 40, "MathCaption",
      CellTags->"2.5"],
    Cell[161379, 5056, 109, 3, 26, "Input",
      CellTags->"2.5"],
    Cell[161491, 5061, 1348, 33, 81, "Output",
      CellTags->"2.5"],
    Cell[162854, 5097, 210, 5, 56, "MathCaption",
      CellTags->"2.5"],
    Cell[163089, 5106, 154, 4, 26, "Input",
      CellTags->"2.5"],
    Cell[163246, 5112, 94487, 2604, 294, 25205, 1743, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[257748, 7719, 542, 9, 64, "Text",
      CellTags->"2.5"],
    Cell[258293, 7730, 211, 5, 56, "MathCaption",
      CellTags->"2.5"],
    Cell[258529, 7739, 233, 6, 42, "Input",
      CellTags->"2.5"],
    Cell[258787, 7749, 22000, 592, 184, 6445, 394, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[280790, 8343, 21159, 570, 184, 6233, 380, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[301976, 8917, 520, 10, 52, "Text",
      CellTags->"2.5"],
    Cell[302499, 8929, 254, 6, 56, "MathCaption",
      CellTags->"2.5"],
    Cell[302778, 8939, 157, 5, 26, "Input",
      CellTags->"2.5"],
    Cell[302938, 8946, 998, 27, 42, "Output",
      CellTags->"2.5"],
    Cell[303951, 8976, 136, 4, 40, "MathCaption",
      CellTags->"2.5"],
    Cell[304112, 8984, 129, 3, 26, "Input",
      CellTags->"2.5"],
    Cell[304244, 8989, 2238, 46, 87, "Output",
      CellTags->"2.5"],
    Cell[306497, 9038, 159, 4, 40, "MathCaption",
      CellTags->"2.5"],
    Cell[306681, 9046, 153, 4, 26, "Input",
      CellTags->"2.5"],
    Cell[306837, 9052, 71931, 2560, 212, 29572, 2031, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[378783, 11615, 219, 5, 36, "Text",
      CellTags->"2.5"],
    Cell[379005, 11622, 297, 6, 56, "MathCaption",
      CellTags->"2.5"],
    Cell[379327, 11632, 254, 6, 42, "Input",
      CellTags->"2.5"],
    Cell[379606, 11642, 19869, 542, 184, 6023, 365, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[399478, 12186, 18337, 527, 184, 6143, 371, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2.5"],
    Cell[417842, 12717, 491, 9, 50, "Text",
      CellTags->"2.5"]},
  "c:6"->{
    Cell[92483, 2492, 77, 1, 36, "Subsection",
      CellTags->{"2.5", "c:6"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"2.0", 420684, 12783},
  {"c:1", 420835, 12788},
  {"2.1", 420922, 12791},
  {"c:2", 421415, 12806},
  {"2.2", 421504, 12809},
  {"c:3", 422502, 12838},
  {"2.3", 422592, 12841},
  {"c:4", 425712, 12932},
  {"2.4", 425804, 12935},
  {"c:5", 427413, 12982},
  {"2.5", 427505, 12985},
  {"c:6", 430633, 13071}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 142, 4, 61, "Section",
  CellTags->{"2.0", "c:1"}],
Cell[1921, 59, 670, 12, 66, "Text",
  CellTags->"2.0"],

Cell[CellGroupData[{
Cell[2616, 75, 77, 1, 36, "Subsection",
  CellTags->{"2.1", "c:2"}],
Cell[2696, 78, 1194, 19, 110, "Text",
  CellTags->"2.1"],
Cell[3893, 99, 78, 1, 40, "MathCaption",
  CellTags->"2.1"],
Cell[3974, 102, 104, 3, 26, "Input",
  CellTags->"2.1"],
Cell[4081, 107, 448, 8, 72, "MathCaption",
  CellTags->"2.1"],

Cell[CellGroupData[{
Cell[4554, 119, 363, 8, 79, "Input",
  CellTags->"2.1"],
Cell[4920, 129, 1357, 33, 81, "Output",
  CellTags->"2.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6326, 168, 92, 1, 36, "Subsection",
  CellTags->{"2.2", "c:3"}],
Cell[6421, 171, 202, 7, 24, "Text",
  CellTags->"2.2"],
Cell[6626, 180, 178, 5, 40, "MathCaption",
  CellTags->"2.2"],

Cell[CellGroupData[{
Cell[6829, 189, 112, 3, 26, "Input",
  CellTags->"2.2"],
Cell[6944, 194, 420, 8, 41, "Output",
  CellTags->"2.2"]
}, Open  ]],
Cell[7379, 205, 143, 4, 40, "MathCaption",
  CellTags->"2.2"],

Cell[CellGroupData[{
Cell[7547, 213, 100, 3, 26, "Input",
  CellTags->"2.2"],
Cell[7650, 218, 95, 3, 25, "Output",
  CellTags->"2.2"]
}, Open  ]],
Cell[7760, 224, 209, 5, 40, "MathCaption",
  CellTags->"2.2"],

Cell[CellGroupData[{
Cell[7994, 233, 232, 6, 42, "Input",
  CellTags->"2.2"],

Cell[CellGroupData[{
Cell[8251, 243, 22237, 595, 184, 6444, 394, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.2"],
Cell[30491, 840, 21158, 570, 184, 6233, 380, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.2"]
}, Open  ]]
}, Open  ]],
Cell[51676, 1414, 314, 6, 36, "Text",
  CellTags->"2.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52027, 1425, 87, 1, 36, "Subsection",
  CellTags->{"2.3", "c:4"}],
Cell[52117, 1428, 635, 17, 54, "Text",
  CellTags->"2.3"],
Cell[52755, 1447, 124, 4, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[52904, 1455, 99, 3, 26, "Input",
  CellTags->"2.3"],
Cell[53006, 1460, 2346, 54, 95, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[55367, 1517, 98, 1, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[55490, 1522, 98, 3, 26, "Input",
  CellTags->"2.3"],
Cell[55591, 1527, 2195, 53, 52, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[57801, 1583, 270, 8, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[58096, 1595, 90, 3, 26, "Input",
  CellTags->"2.3"],
Cell[58189, 1600, 81, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[58285, 1606, 474, 13, 39, "Text",
  CellTags->"2.3"],
Cell[58762, 1621, 209, 6, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[58996, 1631, 101, 3, 26, "Input",
  CellTags->"2.3"],
Cell[59100, 1636, 3238, 68, 255, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[62353, 1707, 422, 8, 50, "Text",
  CellTags->"2.3"],
Cell[62778, 1717, 224, 6, 40, "MathCaption",
  CellTags->"2.3"],
Cell[63005, 1725, 1812, 29, 298, "Input",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[64842, 1758, 94, 3, 26, "Input",
  CellTags->"2.3"],
Cell[64939, 1763, 4165, 78, 251, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[69119, 1844, 102, 2, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[69246, 1850, 93, 3, 26, "Input",
  CellTags->"2.3"],
Cell[69342, 1855, 82, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69461, 1863, 91, 3, 26, "Input",
  CellTags->"2.3"],
Cell[69555, 1868, 83, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[69653, 1874, 434, 10, 56, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[70112, 1888, 95, 3, 26, "Input",
  CellTags->"2.3"],
Cell[70210, 1893, 79, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[70304, 1899, 342, 11, 40, "MathCaption",
  CellTags->"2.3"],
Cell[70649, 1912, 111, 3, 26, "Input",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[70785, 1919, 95, 3, 26, "Input",
  CellTags->"2.3"],
Cell[70883, 1924, 4516, 88, 251, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[75414, 2015, 368, 9, 38, "Text",
  CellTags->"2.3"],
Cell[75785, 2026, 134, 4, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[75944, 2034, 103, 3, 26, "Input",
  CellTags->"2.3"],
Cell[76050, 2039, 135, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[76200, 2045, 360, 9, 56, "MathCaption",
  CellTags->"2.3"],
Cell[76563, 2056, 112, 3, 26, "Input",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[76700, 2063, 94, 3, 26, "Input",
  CellTags->"2.3"],
Cell[76797, 2068, 3743, 78, 209, "Output",
  CellTags->"2.3"]
}, Open  ]],
Cell[80555, 2149, 234, 6, 40, "MathCaption",
  CellTags->"2.3"],

Cell[CellGroupData[{
Cell[80814, 2159, 93, 3, 26, "Input",
  CellTags->"2.3"],
Cell[80910, 2164, 82, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81029, 2172, 91, 3, 26, "Input",
  CellTags->"2.3"],
Cell[81123, 2177, 82, 3, 25, "Output",
  CellTags->"2.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81254, 2186, 89, 1, 36, "Subsection",
  CellTags->{"2.4", "c:5"}],
Cell[81346, 2189, 347, 9, 38, "Text",
  CellTags->"2.4"],
Cell[81696, 2200, 163, 6, 40, "MathCaption",
  CellTags->"2.4"],
Cell[81862, 2208, 137, 4, 26, "Input",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[82024, 2216, 95, 3, 26, "Input",
  CellTags->"2.4"],
Cell[82122, 2221, 3311, 68, 209, "Output",
  CellTags->"2.4"]
}, Open  ]],
Cell[85448, 2292, 90, 1, 40, "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[85563, 2297, 126, 3, 30, "Input",
  CellTags->"2.4"],
Cell[85692, 2302, 328, 6, 41, "Output",
  CellTags->"2.4"]
}, Open  ]],
Cell[86035, 2311, 230, 7, 40, "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[86290, 2322, 165, 4, 26, "Input",
  CellTags->"2.4"],
Cell[86458, 2328, 295, 6, 25, "Output",
  CellTags->"2.4"]
}, Open  ]],
Cell[86768, 2337, 298, 8, 40, "MathCaption",
  CellTags->"2.4"],
Cell[87069, 2347, 153, 4, 26, "Input",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[87247, 2355, 94, 3, 26, "Input",
  CellTags->"2.4"],
Cell[87344, 2360, 666, 16, 55, "Output",
  CellTags->"2.4"]
}, Open  ]],
Cell[88025, 2379, 72, 1, 40, "MathCaption",
  CellTags->"2.4"],
Cell[88100, 2382, 119, 3, 26, "Input",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[88244, 2389, 95, 3, 26, "Input",
  CellTags->"2.4"],
Cell[88342, 2394, 3421, 69, 213, "Output",
  CellTags->"2.4"]
}, Open  ]],
Cell[91778, 2466, 142, 4, 40, "MathCaption",
  CellTags->"2.4"],

Cell[CellGroupData[{
Cell[91945, 2474, 160, 4, 30, "Input",
  CellTags->"2.4"],
Cell[92108, 2480, 326, 6, 25, "Output",
  CellTags->"2.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[92483, 2492, 77, 1, 36, "Subsection",
  CellTags->{"2.5", "c:6"}],
Cell[92563, 2495, 840, 20, 70, "Text",
  CellTags->"2.5"],
Cell[93406, 2517, 261, 6, 56, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[93692, 2527, 98, 3, 26, "Input",
  CellTags->"2.5"],
Cell[93793, 2532, 400, 11, 41, "Output",
  CellTags->"2.5"]
}, Open  ]],
Cell[94208, 2546, 83, 1, 40, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[94316, 2551, 102, 3, 26, "Input",
  CellTags->"2.5"],
Cell[94421, 2556, 65188, 2436, 197, 28931, 1983, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"2.5"]
}, Open  ]],
Cell[159624, 4995, 353, 8, 36, "Text",
  CellTags->"2.5"],
Cell[159980, 5005, 171, 6, 40, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[160176, 5015, 130, 3, 26, "Input",
  CellTags->"2.5"],
Cell[160309, 5020, 926, 27, 42, "Output",
  CellTags->"2.5"]
}, Open  ]],
Cell[161250, 5050, 104, 2, 40, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[161379, 5056, 109, 3, 26, "Input",
  CellTags->"2.5"],
Cell[161491, 5061, 1348, 33, 81, "Output",
  CellTags->"2.5"]
}, Open  ]],
Cell[162854, 5097, 210, 5, 56, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[163089, 5106, 154, 4, 26, "Input",
  CellTags->"2.5"],
Cell[163246, 5112, 94487, 2604, 294, 25205, 1743, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"2.5"]
}, Open  ]],
Cell[257748, 7719, 542, 9, 64, "Text",
  CellTags->"2.5"],
Cell[258293, 7730, 211, 5, 56, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[258529, 7739, 233, 6, 42, "Input",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[258787, 7749, 22000, 592, 184, 6445, 394, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.5"],
Cell[280790, 8343, 21159, 570, 184, 6233, 380, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]],
Cell[301976, 8917, 520, 10, 52, "Text",
  CellTags->"2.5"],
Cell[302499, 8929, 254, 6, 56, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[302778, 8939, 157, 5, 26, "Input",
  CellTags->"2.5"],
Cell[302938, 8946, 998, 27, 42, "Output",
  CellTags->"2.5"]
}, Open  ]],
Cell[303951, 8976, 136, 4, 40, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[304112, 8984, 129, 3, 26, "Input",
  CellTags->"2.5"],
Cell[304244, 8989, 2238, 46, 87, "Output",
  CellTags->"2.5"]
}, Open  ]],
Cell[306497, 9038, 159, 4, 40, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[306681, 9046, 153, 4, 26, "Input",
  CellTags->"2.5"],
Cell[306837, 9052, 71931, 2560, 212, 29572, 2031, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"2.5"]
}, Open  ]],
Cell[378783, 11615, 219, 5, 36, "Text",
  CellTags->"2.5"],
Cell[379005, 11622, 297, 6, 56, "MathCaption",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[379327, 11632, 254, 6, 42, "Input",
  CellTags->"2.5"],

Cell[CellGroupData[{
Cell[379606, 11642, 19869, 542, 184, 6023, 365, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.5"],
Cell[399478, 12186, 18337, 527, 184, 6143, 371, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]],
Cell[417842, 12717, 491, 9, 50, "Text",
  CellTags->"2.5"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

